Class: Aws::GeoRoutes::Types::CalculateIsolinesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:arrival_time, :departure_time, :snapped_destination, :snapped_origin]

Instance Attribute Summary collapse

Instance Attribute Details

#arrival_timeString

Time of arrival at the destination, used for traffic calculations. This attribute is returned only if the ‘Destination` and `ArrivalTime` attributes were provided in the request.

Time format: ‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`

Examples:

‘2020-04-22T17:57:24Z`

‘2020-04-22T17:57:24+02:00`

Returns:

  • (String)


303
304
305
306
307
308
309
310
311
312
313
# File 'lib/aws-sdk-georoutes/types.rb', line 303

class CalculateIsolinesResponse < Struct.new(
  :arrival_time,
  :departure_time,
  :isoline_geometry_format,
  :isolines,
  :pricing_bucket,
  :snapped_destination,
  :snapped_origin)
  SENSITIVE = [:arrival_time, :departure_time, :snapped_destination, :snapped_origin]
  include Aws::Structure
end

#departure_timeString

Time of departure from the origin, used for traffic calculations. This attribute is returned when ‘Origin` was provided in the request and either a specific departure time was requested (`DepartureTime`) or `DepartNow` was set to true.

Time format: ‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`

Examples:

‘2020-04-22T17:57:24Z`

‘2020-04-22T17:57:24+02:00`

Returns:

  • (String)


303
304
305
306
307
308
309
310
311
312
313
# File 'lib/aws-sdk-georoutes/types.rb', line 303

class CalculateIsolinesResponse < Struct.new(
  :arrival_time,
  :departure_time,
  :isoline_geometry_format,
  :isolines,
  :pricing_bucket,
  :snapped_destination,
  :snapped_origin)
  SENSITIVE = [:arrival_time, :departure_time, :snapped_destination, :snapped_origin]
  include Aws::Structure
end

#isoline_geometry_formatString

The format of the returned geometries, matching the format specified in the request. Either ‘ FlexiblePolyline` for compact encoding or `Simple` for GeoJSON-compatible coordinates.

Default value:‘FlexiblePolyline`

Returns:

  • (String)


303
304
305
306
307
308
309
310
311
312
313
# File 'lib/aws-sdk-georoutes/types.rb', line 303

class CalculateIsolinesResponse < Struct.new(
  :arrival_time,
  :departure_time,
  :isoline_geometry_format,
  :isolines,
  :pricing_bucket,
  :snapped_destination,
  :snapped_origin)
  SENSITIVE = [:arrival_time, :departure_time, :snapped_destination, :snapped_origin]
  include Aws::Structure
end

#isolinesArray<Types::Isoline>

Reachable areas, or isolines, for each threshold specified in the request.

Returns:



303
304
305
306
307
308
309
310
311
312
313
# File 'lib/aws-sdk-georoutes/types.rb', line 303

class CalculateIsolinesResponse < Struct.new(
  :arrival_time,
  :departure_time,
  :isoline_geometry_format,
  :isolines,
  :pricing_bucket,
  :snapped_destination,
  :snapped_origin)
  SENSITIVE = [:arrival_time, :departure_time, :snapped_destination, :snapped_origin]
  include Aws::Structure
end

#pricing_bucketString

The pricing bucket applied to this calculation. Different buckets apply based on the travel mode and thresholds used.

Returns:

  • (String)


303
304
305
306
307
308
309
310
311
312
313
# File 'lib/aws-sdk-georoutes/types.rb', line 303

class CalculateIsolinesResponse < Struct.new(
  :arrival_time,
  :departure_time,
  :isoline_geometry_format,
  :isolines,
  :pricing_bucket,
  :snapped_destination,
  :snapped_origin)
  SENSITIVE = [:arrival_time, :departure_time, :snapped_destination, :snapped_origin]
  include Aws::Structure
end

#snapped_destinationArray<Float>

The actual point on the road network used for calculations, which may differ from the requested destination if ‘Destination` was not directly on a road.

Returns:

  • (Array<Float>)


303
304
305
306
307
308
309
310
311
312
313
# File 'lib/aws-sdk-georoutes/types.rb', line 303

class CalculateIsolinesResponse < Struct.new(
  :arrival_time,
  :departure_time,
  :isoline_geometry_format,
  :isolines,
  :pricing_bucket,
  :snapped_destination,
  :snapped_origin)
  SENSITIVE = [:arrival_time, :departure_time, :snapped_destination, :snapped_origin]
  include Aws::Structure
end

#snapped_originArray<Float>

The actual point on the road network used for calculations, which may differ from the requested origin if ‘Origin` was not directly on a road.

Returns:

  • (Array<Float>)


303
304
305
306
307
308
309
310
311
312
313
# File 'lib/aws-sdk-georoutes/types.rb', line 303

class CalculateIsolinesResponse < Struct.new(
  :arrival_time,
  :departure_time,
  :isoline_geometry_format,
  :isolines,
  :pricing_bucket,
  :snapped_destination,
  :snapped_origin)
  SENSITIVE = [:arrival_time, :departure_time, :snapped_destination, :snapped_origin]
  include Aws::Structure
end