Class: Aws::GeoRoutes::Types::CalculateRouteMatrixRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:allow, :depart_now, :departure_time, :key]

Instance Attribute Summary collapse

Instance Attribute Details

#allowTypes::RouteMatrixAllowOptions

Features that are allowed while calculating a route.



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#avoidTypes::RouteMatrixAvoidanceOptions

Features that are avoided while calculating a route. Avoidance is on a best-case basis. If an avoidance can’t be satisfied for a particular case, it violates the avoidance and the returned response produces a notice for the violation. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only `TollRoads`, `Ferries`, and `ControlledAccessHighways`.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#depart_nowBoolean

Uses the current time as the time of departure.

Returns:

  • (Boolean)


498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#departure_timeString

Time of departure from the origin.

Time format:‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`

Examples:

‘2020-04-22T17:57:24Z`

‘2020-04-22T17:57:24+02:00`

Returns:

  • (String)


498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#destinationsArray<Types::RouteMatrixDestination>

List of destinations for the route in World Geodetic System (WGS 84) format: [longitude, latitude].

<note markdown=“1”> Route calculations are billed for each origin and destination pair. If you use a large matrix of origins and destinations, your costs will increase accordingly. For more information, see [Routes pricing] in the *Amazon Location Service Developer Guide*.

</note>

The maximum number of destinations depends on the routing boundary configuration:

  • With ‘RoutingBoundary.Geometry` set: maximum 500 destinations

  • With ‘RoutingBoundary.Unbounded` set to `true`: maximum 100 destinations

  • For [GrabMaps] customers in ‘ap-southeast-1` and `ap-southeast-5`: maximum 350 destinations

The total matrix size (origins × destinations) must not exceed:

  • With ‘RoutingBoundary.Geometry`: 160,000

  • With ‘RoutingBoundary.Unbounded`: 100

  • For [GrabMaps] customers in ‘ap-southeast-1` and `ap-southeast-5`: 122,500

[1]: docs.aws.amazon.com/location/latest/developerguide/routes-pricing.html [2]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#excludeTypes::RouteMatrixExclusionOptions

Features to be strictly excluded while calculating the route. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#keyString

Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.

Returns:

  • (String)


498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#optimize_routing_forString

Controls the trade-off between finding the shortest travel time (‘FastestRoute`) and the shortest distance (`ShortestRoute`) when calculating reachable areas.

Default value: ‘FastestRoute`

Returns:

  • (String)


498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#originsArray<Types::RouteMatrixOrigin>

List of origins for the route in World Geodetic System (WGS 84) format: [longitude, latitude].

<note markdown=“1”> Route calculations are billed for each origin and destination pair. Using a large amount of Origins in a request can lead you to incur unexpected charges. For more information, see [Routes pricing] in the *Amazon Location Service Developer Guide*.

</note>

The maximum number of origins depends on the routing boundary configuration:

  • With ‘RoutingBoundary.Geometry` set: maximum 500 origins

  • With ‘RoutingBoundary.Unbounded` set to `true`: maximum 15 origins

  • For [GrabMaps] customers in ‘ap-southeast-1` and `ap-southeast-5`: maximum 350 origins

The total matrix size (origins × destinations) must not exceed:

  • With ‘RoutingBoundary.Geometry`: 160,000

  • With ‘RoutingBoundary.Unbounded`: 100

  • For [GrabMaps] customers in ‘ap-southeast-1` and `ap-southeast-5`: 122,500

[1]: docs.aws.amazon.com/location/latest/developerguide/routes-pricing.html [2]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#routing_boundaryTypes::RouteMatrixBoundary

Boundary within which the matrix is to be calculated. All data, origins and destinations outside the boundary are considered invalid. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only `Unbounded` set to `true`.

Default value: ‘Unbounded set to true`

<note markdown=“1”> When ‘AutoCircle` is set in the request, the response routing boundary will return `Circle` derived from the `AutoCircle` settings.

</note>

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#trafficTypes::RouteMatrixTrafficOptions

Traffic related options. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#travel_modeString

Specifies the mode of transport when calculating a route. Used in estimating the speed of travel and road compatibility. For

GrabMaps][1

customers, ‘ap-southeast-1` and `ap-southeast-5`

regions support only ‘Car`, `Pedestrian`, and `Scooter`.

Default value: ‘Car`

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end

#travel_mode_optionsTypes::RouteMatrixTravelModeOptions

Travel mode related options for the provided travel mode. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/aws-sdk-georoutes/types.rb', line 498

class CalculateRouteMatrixRequest < Struct.new(
  :allow,
  :avoid,
  :depart_now,
  :departure_time,
  :destinations,
  :exclude,
  :key,
  :optimize_routing_for,
  :origins,
  :routing_boundary,
  :traffic,
  :travel_mode,
  :travel_mode_options)
  SENSITIVE = [:allow, :depart_now, :departure_time, :key]
  include Aws::Structure
end