Class: Aws::GeoRoutes::Types::CalculateRouteMatrixResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_countInteger

The count of error results in the route matrix. If this number is 0, all routes were calculated successfully.

Returns:

  • (Integer)


546
547
548
549
550
551
552
553
# File 'lib/aws-sdk-georoutes/types.rb', line 546

class CalculateRouteMatrixResponse < Struct.new(
  :error_count,
  :pricing_bucket,
  :route_matrix,
  :routing_boundary)
  SENSITIVE = []
  include Aws::Structure
end

#pricing_bucketString

The pricing bucket for which the query is charged at.

Returns:

  • (String)


546
547
548
549
550
551
552
553
# File 'lib/aws-sdk-georoutes/types.rb', line 546

class CalculateRouteMatrixResponse < Struct.new(
  :error_count,
  :pricing_bucket,
  :route_matrix,
  :routing_boundary)
  SENSITIVE = []
  include Aws::Structure
end

#route_matrixArray<Array<Types::RouteMatrixEntry>>

The calculated route matrix containing the results for all pairs of Origins to Destination positions. Each row corresponds to one entry in Origins. Each entry in the row corresponds to the route from that entry in Origins to an entry in Destination positions.

Returns:



546
547
548
549
550
551
552
553
# File 'lib/aws-sdk-georoutes/types.rb', line 546

class CalculateRouteMatrixResponse < Struct.new(
  :error_count,
  :pricing_bucket,
  :route_matrix,
  :routing_boundary)
  SENSITIVE = []
  include Aws::Structure
end

#routing_boundaryTypes::RouteMatrixBoundary

Boundary within which the matrix is to be calculated. All data, origins and destinations outside the boundary are considered invalid.

<note markdown=“1”> When ‘AutoCircle` is set in the request, the response routing boundary will return `Circle` derived from the `AutoCircle` settings.

</note>


546
547
548
549
550
551
552
553
# File 'lib/aws-sdk-georoutes/types.rb', line 546

class CalculateRouteMatrixResponse < Struct.new(
  :error_count,
  :pricing_bucket,
  :route_matrix,
  :routing_boundary)
  SENSITIVE = []
  include Aws::Structure
end