Class: Aws::GeoRoutes::Types::CalculateRoutesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::CalculateRoutesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#leg_geometry_format ⇒ String
Specifies the format of the geometry returned for each leg of the route.
-
#notices ⇒ Array<Types::RouteResponseNotice>
Notices are additional information returned that indicate issues that occurred during route calculation.
-
#pricing_bucket ⇒ String
The pricing bucket for which the query is charged at.
-
#routes ⇒ Array<Types::Route>
The path from the origin to the destination.
Instance Attribute Details
#leg_geometry_format ⇒ String
Specifies the format of the geometry returned for each leg of the route.
853 854 855 856 857 858 859 860 |
# File 'lib/aws-sdk-georoutes/types.rb', line 853 class CalculateRoutesResponse < Struct.new( :leg_geometry_format, :notices, :pricing_bucket, :routes) SENSITIVE = [] include Aws::Structure end |
#notices ⇒ Array<Types::RouteResponseNotice>
Notices are additional information returned that indicate issues that occurred during route calculation. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
853 854 855 856 857 858 859 860 |
# File 'lib/aws-sdk-georoutes/types.rb', line 853 class CalculateRoutesResponse < Struct.new( :leg_geometry_format, :notices, :pricing_bucket, :routes) SENSITIVE = [] include Aws::Structure end |
#pricing_bucket ⇒ String
The pricing bucket for which the query is charged at.
853 854 855 856 857 858 859 860 |
# File 'lib/aws-sdk-georoutes/types.rb', line 853 class CalculateRoutesResponse < Struct.new( :leg_geometry_format, :notices, :pricing_bucket, :routes) SENSITIVE = [] include Aws::Structure end |
#routes ⇒ Array<Types::Route>
The path from the origin to the destination.
853 854 855 856 857 858 859 860 |
# File 'lib/aws-sdk-georoutes/types.rb', line 853 class CalculateRoutesResponse < Struct.new( :leg_geometry_format, :notices, :pricing_bucket, :routes) SENSITIVE = [] include Aws::Structure end |