Class: Aws::GeoRoutes::Types::Circle

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Geometry defined as a circle. The circle defines the routing boundary area. Any waypoints outside the circle will result in a route matrix entry error.

You can specify a ‘Circle` directly in the request, or it will be auto-derived when `AutoCircle` is used. When `AutoCircle` is set in the request, the response routing boundary will return `Circle` derived from the `AutoCircle` settings.

Constant Summary collapse

SENSITIVE =
[:center, :radius]

Instance Attribute Summary collapse

Instance Attribute Details

#centerArray<Float>

Center of the Circle in World Geodetic System (WGS 84) format: [longitude, latitude].

Example: ‘[-123.1174, 49.2847]` represents the position with longitude `-123.1174` and latitude `49.2847`.

Returns:

  • (Array<Float>)


931
932
933
934
935
936
# File 'lib/aws-sdk-georoutes/types.rb', line 931

class Circle < Struct.new(
  :center,
  :radius)
  SENSITIVE = [:center, :radius]
  include Aws::Structure
end

#radiusFloat

Radius of the Circle.

Unit: ‘meters`

Valid Range: Minimum value of 0. Maximum value of 200000.

Returns:

  • (Float)


931
932
933
934
935
936
# File 'lib/aws-sdk-georoutes/types.rb', line 931

class Circle < Struct.new(
  :center,
  :radius)
  SENSITIVE = [:center, :radius]
  include Aws::Structure
end