Class: Aws::GeoRoutes::Types::IsolineAvoidanceOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Specifies features of the road network to avoid when calculating reachable areas. These preferences guide route calculations but may be overridden when no reasonable alternative exists. For example, if avoiding toll roads would make an area unreachable, toll roads may still be used.

Avoidance options include physical features (like ferries and tunnels), road characteristics (like dirt roads and highways), and regulated areas (like congestion zones). They can be combined to match specific routing needs, such as avoiding both toll roads and ferries.

Constant Summary collapse

SENSITIVE =
[:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]

Instance Attribute Summary collapse

Instance Attribute Details

#areasArray<Types::IsolineAvoidanceArea>

Specifies geographic areas to avoid where possible. Routes may still pass through these areas if no reasonable alternative exists.

Returns:



1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#car_shuttle_trainsBoolean

Indicates a preference to avoid car shuttle trains (auto trains) where possible. These may still be included if no reasonable alternative route exists.

Returns:

  • (Boolean)


1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#controlled_access_highwaysBoolean

Indicates a preference to avoid controlled-access highways (such as interstate highways or motorways) where possible. If a viable route cannot be calculated using only local roads, controlled-access highways may still be included.

Returns:

  • (Boolean)


1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#dirt_roadsBoolean

Indicates a preference to avoid unpaved or dirt roads where possible. Routes may still include dirt roads if no reasonable paved alternative exists.

Returns:

  • (Boolean)


1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#ferriesBoolean

Indicates a preference to avoid ferries where possible. If a viable route cannot be calculated without using ferries, they may still be included.

Returns:

  • (Boolean)


1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#seasonal_closureBoolean

Indicates a preference to avoid roads that may be subject to seasonal closures where possible. These roads may still be included if no reasonable year-round alternative exists.

Returns:

  • (Boolean)


1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#toll_roadsBoolean

Indicates a preference to avoid toll roads where possible. If a viable route cannot be calculated without using toll roads, they may still be included.

Returns:

  • (Boolean)


1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#toll_transpondersBoolean

Indicates a preference to avoid roads that require electronic toll collection transponders where possible. These roads may still be included if no viable alternative route exists.

Returns:

  • (Boolean)


1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#truck_road_typesArray<String>

For truck travel modes, indicates specific road classification types in Sweden (‘ BK1` through `BK4`) and Mexico (`A2, A4, B2, B4, C, D, ET2, ET4`) to avoid where possible. These road types may still be used if no reasonable alternative exists.

<note markdown=“1”> There are currently no other supported values as of 26th April 2024.

</note>

Returns:

  • (Array<String>)


1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#tunnelsBoolean

Indicates a preference to avoid tunnels where possible. If a viable route cannot be calculated without using tunnels, they may still be included.

Returns:

  • (Boolean)


1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#u_turnsBoolean

Indicates a preference to avoid U-turns where possible. U-turns may still be included if necessary to reach certain areas or when no reasonable alternative exists.

Returns:

  • (Boolean)


1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end

#zone_categoriesArray<Types::IsolineAvoidanceZoneCategory>

Indicates types of regulated zones (such as congestion pricing or environmental zones) to avoid where possible. Routes may still pass through these zones if no reasonable alternative exists.



1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-georoutes/types.rb', line 1209

class IsolineAvoidanceOptions < Struct.new(
  :areas,
  :car_shuttle_trains,
  :controlled_access_highways,
  :dirt_roads,
  :ferries,
  :seasonal_closure,
  :toll_roads,
  :toll_transponders,
  :truck_road_types,
  :tunnels,
  :u_turns,
  :zone_categories)
  SENSITIVE = [:car_shuttle_trains, :controlled_access_highways, :dirt_roads, :ferries, :seasonal_closure, :toll_roads, :toll_transponders, :truck_road_types, :tunnels, :u_turns]
  include Aws::Structure
end