Class: Aws::GeoRoutes::Types::IsolineConnectionGeometry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Represents the geometry of connections between non-contiguous parts of an isoline. These connections can be provided in either coordinate pairs (LineString) or encoded (Polyline) format, matching the format specified in the request.

Constant Summary collapse

SENSITIVE =
[:line_string, :polyline]

Instance Attribute Summary collapse

Instance Attribute Details

#line_stringArray<Array<Float>>

A series of ‘[longitude, latitude]` coordinate pairs defining the connection path when `Simple` geometry format is requested. These coordinates can be directly used as the coordinates array in a GeoJSON LineString without transformation.

<note markdown=“1”> LineString and Polyline are mutually exclusive properties.

</note>

Returns:

  • (Array<Array<Float>>)


1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-georoutes/types.rb', line 1302

class IsolineConnectionGeometry < Struct.new(
  :line_string,
  :polyline)
  SENSITIVE = [:line_string, :polyline]
  include Aws::Structure
end

#polylineString

An encoded representation of the connection path when ‘FlexiblePolyline` geometry format is requested. This provides a more compact representation suitable for transmission and storage. To convert to GeoJSON, first decode to obtain coordinate pairs, then use those coordinates as the coordinates array in a GeoJSON LineString.

<note markdown=“1”> LineString and Polyline are mutually exclusive properties.

</note>

Returns:

  • (String)


1302
1303
1304
1305
1306
1307
# File 'lib/aws-sdk-georoutes/types.rb', line 1302

class IsolineConnectionGeometry < Struct.new(
  :line_string,
  :polyline)
  SENSITIVE = [:line_string, :polyline]
  include Aws::Structure
end