Class: Aws::GeoRoutes::Types::IsolineGranularityOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::IsolineGranularityOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Controls the detail level and smoothness of generated isolines. More detailed isolines provide better visual representation of reachable areas but require more processing time and result in larger responses.
Constant Summary collapse
- SENSITIVE =
[:max_resolution]
Instance Attribute Summary collapse
-
#max_points ⇒ Integer
The maximum number of points used to define each isoline.
-
#max_resolution ⇒ Integer
The maximum distance in meters between points along the isoline.
Instance Attribute Details
#max_points ⇒ Integer
The maximum number of points used to define each isoline. Higher values create smoother, more detailed shapes.
1416 1417 1418 1419 1420 1421 |
# File 'lib/aws-sdk-georoutes/types.rb', line 1416 class IsolineGranularityOptions < Struct.new( :max_points, :max_resolution) SENSITIVE = [:max_resolution] include Aws::Structure end |
#max_resolution ⇒ Integer
The maximum distance in meters between points along the isoline. Smaller values create more detailed shapes.
Unit: ‘meters`
1416 1417 1418 1419 1420 1421 |
# File 'lib/aws-sdk-georoutes/types.rb', line 1416 class IsolineGranularityOptions < Struct.new( :max_points, :max_resolution) SENSITIVE = [:max_resolution] include Aws::Structure end |