Class: Aws::GeoRoutes::Types::IsolineScooterOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::IsolineScooterOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Vehicle characteristics that affect which roads and paths can be used when calculating reachable areas for scooters. This includes areas such as bike lanes, shared paths, and roads where scooters are permitted.
Constant Summary collapse
- SENSITIVE =
[:engine_type, :license_plate, :max_speed, :occupancy]
Instance Attribute Summary collapse
-
#engine_type ⇒ String
The type of engine powering the vehicle, which may affect route calculation due to road restrictions or vehicle characteristics.
-
#license_plate ⇒ Types::IsolineVehicleLicensePlate
License plate information used in regions where road access or routing restrictions are based on license plate numbers.
-
#max_speed ⇒ Float
The maximum speed of the vehicle in kilometers per hour.
-
#occupancy ⇒ Integer
The number of occupants in the vehicle.
Instance Attribute Details
#engine_type ⇒ String
The type of engine powering the vehicle, which may affect route calculation due to road restrictions or vehicle characteristics.
-
‘INTERNAL_COMBUSTION`—Standard gasoline or diesel engine.
-
‘ELECTRIC`—Battery electric vehicle.
-
‘PLUGIN_HYBRID`—Combination of electric and internal combustion engines with plug-in charging capability.
1548 1549 1550 1551 1552 1553 1554 1555 |
# File 'lib/aws-sdk-georoutes/types.rb', line 1548 class IsolineScooterOptions < Struct.new( :engine_type, :license_plate, :max_speed, :occupancy) SENSITIVE = [:engine_type, :license_plate, :max_speed, :occupancy] include Aws::Structure end |
#license_plate ⇒ Types::IsolineVehicleLicensePlate
License plate information used in regions where road access or routing restrictions are based on license plate numbers.
1548 1549 1550 1551 1552 1553 1554 1555 |
# File 'lib/aws-sdk-georoutes/types.rb', line 1548 class IsolineScooterOptions < Struct.new( :engine_type, :license_plate, :max_speed, :occupancy) SENSITIVE = [:engine_type, :license_plate, :max_speed, :occupancy] include Aws::Structure end |
#max_speed ⇒ Float
The maximum speed of the vehicle in kilometers per hour. When specified, routes will not include roads with higher speed limits. Valid values range from 3.6 km/h (1 m/s) to 252 km/h (70 m/s).
Unit: ‘kilometers per hour`
1548 1549 1550 1551 1552 1553 1554 1555 |
# File 'lib/aws-sdk-georoutes/types.rb', line 1548 class IsolineScooterOptions < Struct.new( :engine_type, :license_plate, :max_speed, :occupancy) SENSITIVE = [:engine_type, :license_plate, :max_speed, :occupancy] include Aws::Structure end |
#occupancy ⇒ Integer
The number of occupants in the vehicle. This can affect route calculations by enabling the use of high-occupancy vehicle (HOV) lanes where minimum occupancy requirements are met.
Default value: ‘1`
1548 1549 1550 1551 1552 1553 1554 1555 |
# File 'lib/aws-sdk-georoutes/types.rb', line 1548 class IsolineScooterOptions < Struct.new( :engine_type, :license_plate, :max_speed, :occupancy) SENSITIVE = [:engine_type, :license_plate, :max_speed, :occupancy] include Aws::Structure end |