Class: Aws::GeoRoutes::Types::IsolineShapeGeometry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Represents the shape of a reachable area. The geometry can be provided either as coordinate pairs (‘Polygon`) or in encoded format (`PolylinePolygon`), matching the format specified in the request.

Constant Summary collapse

SENSITIVE =
[:polyline_polygon]

Instance Attribute Summary collapse

Instance Attribute Details

#polygonArray<Array<Array<Float>>>

A series of coordinate rings defining the reachable area when Simple geometry format is requested. Each ring is a list of ‘[longitude, latitude]` coordinate pairs. The first ring defines the outer boundary; subsequent rings define holes representing unreachable areas.

<note markdown=“1”> Polygon and PolylinePolygon are mutually exclusive properties.

</note>

Returns:

  • (Array<Array<Array<Float>>>)


1543
1544
1545
1546
1547
1548
# File 'lib/aws-sdk-georoutes/types.rb', line 1543

class IsolineShapeGeometry < Struct.new(
  :polygon,
  :polyline_polygon)
  SENSITIVE = [:polyline_polygon]
  include Aws::Structure
end

#polyline_polygonArray<String>

An encoded representation of the reachable area when FlexiblePolyline geometry format is requested. Provides a compact representation suitable for transmission and storage. The first string defines the outer boundary; subsequent strings define holes representing unreachable areas. For more information on polyline encoding, see [github.com/aws-geospatial/polyline][1].

<note markdown=“1”> Polygon and PolylinePolygon are mutually exclusive properties.

</note>

[1]: github.com/aws-geospatial/polyline

Returns:

  • (Array<String>)


1543
1544
1545
1546
1547
1548
# File 'lib/aws-sdk-georoutes/types.rb', line 1543

class IsolineShapeGeometry < Struct.new(
  :polygon,
  :polyline_polygon)
  SENSITIVE = [:polyline_polygon]
  include Aws::Structure
end