Class: Aws::GeoRoutes::Types::LocalizedString

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

The localized string.

Constant Summary collapse

SENSITIVE =
[:value]

Instance Attribute Summary collapse

Instance Attribute Details

#languageString

A list of BCP 47 compliant language codes for the results to be rendered in. The request uses the regional default as the fallback if the requested language can’t be provided.

Returns:

  • (String)


2001
2002
2003
2004
2005
2006
# File 'lib/aws-sdk-georoutes/types.rb', line 2001

class LocalizedString < Struct.new(
  :language,
  :value)
  SENSITIVE = [:value]
  include Aws::Structure
end

#valueString

The value of the localized string.

Returns:

  • (String)


2001
2002
2003
2004
2005
2006
# File 'lib/aws-sdk-georoutes/types.rb', line 2001

class LocalizedString < Struct.new(
  :language,
  :value)
  SENSITIVE = [:value]
  include Aws::Structure
end