Class: Aws::GeoRoutes::Types::OptimizeWaypointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::OptimizeWaypointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:departure_time, :destination, :key, :origin]
Instance Attribute Summary collapse
-
#avoid ⇒ Types::WaypointOptimizationAvoidanceOptions
Features that are avoided.
-
#clustering ⇒ Types::WaypointOptimizationClusteringOptions
Clustering allows you to specify how nearby waypoints can be clustered to improve the optimized sequence.
-
#departure_time ⇒ String
Departure time from the waypoint.
-
#destination ⇒ Array<Float>
The final position for the route in the World Geodetic System (WGS 84) format: ‘[longitude, latitude]`.
-
#destination_options ⇒ Types::WaypointOptimizationDestinationOptions
Destination related options.
-
#driver ⇒ Types::WaypointOptimizationDriverOptions
Driver related options.
-
#exclude ⇒ Types::WaypointOptimizationExclusionOptions
Features to be strictly excluded while calculating the route.
-
#key ⇒ String
Optional: The API key to be used for authorization.
-
#optimize_sequencing_for ⇒ String
Specifies the optimization criteria for the calculated sequence.
-
#origin ⇒ Array<Float>
The start position for the route in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#origin_options ⇒ Types::WaypointOptimizationOriginOptions
Origin related options.
-
#traffic ⇒ Types::WaypointOptimizationTrafficOptions
Traffic-related options.
-
#travel_mode ⇒ String
Specifies the mode of transport when calculating a route.
-
#travel_mode_options ⇒ Types::WaypointOptimizationTravelModeOptions
Travel mode related options for the provided travel mode.
-
#waypoints ⇒ Array<Types::WaypointOptimizationWaypoint>
List of waypoints between the ‘Origin` and `Destination`, in World Geodetic System (WGS 84) format: [longitude, latitude].
Instance Attribute Details
#avoid ⇒ Types::WaypointOptimizationAvoidanceOptions
Features that are avoided. Avoidance is on a best-case basis. If an avoidance can’t be satisfied for a particular case, this setting is ignored.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#clustering ⇒ Types::WaypointOptimizationClusteringOptions
Clustering allows you to specify how nearby waypoints can be clustered to improve the optimized sequence.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#departure_time ⇒ String
Departure time from the waypoint.
Time format:‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`
Examples:
‘2020-04-22T17:57:24Z`
‘2020-04-22T17:57:24+02:00`
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#destination ⇒ Array<Float>
The final position for the route in the World Geodetic System (WGS 84) format: ‘[longitude, latitude]`.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#destination_options ⇒ Types::WaypointOptimizationDestinationOptions
Destination related options.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#driver ⇒ Types::WaypointOptimizationDriverOptions
Driver related options.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#exclude ⇒ Types::WaypointOptimizationExclusionOptions
Features to be strictly excluded while calculating the route.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#key ⇒ String
Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#optimize_sequencing_for ⇒ String
Specifies the optimization criteria for the calculated sequence.
Default value: ‘FastestRoute`.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#origin ⇒ Array<Float>
The start position for the route in World Geodetic System (WGS 84) format: [longitude, latitude].
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#origin_options ⇒ Types::WaypointOptimizationOriginOptions
Origin related options.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#traffic ⇒ Types::WaypointOptimizationTrafficOptions
Traffic-related options.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#travel_mode ⇒ String
Specifies the mode of transport when calculating a route. Used in estimating the speed of travel and road compatibility.
Default value: ‘Car`
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#travel_mode_options ⇒ Types::WaypointOptimizationTravelModeOptions
Travel mode related options for the provided travel mode.
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |
#waypoints ⇒ Array<Types::WaypointOptimizationWaypoint>
List of waypoints between the ‘Origin` and `Destination`, in World Geodetic System (WGS 84) format: [longitude, latitude].
The maximum number of waypoints allowed per request:
-
Maximum 50 waypoints per request
-
Maximum 20 waypoints when using constraints (‘AccessHours`, `AppointmentTime`, `ServiceDuration`, `Heading`, `SideOfStreet`, `Before`)
2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2099 class OptimizeWaypointsRequest < Struct.new( :avoid, :clustering, :departure_time, :destination, :destination_options, :driver, :exclude, :key, :optimize_sequencing_for, :origin, :origin_options, :traffic, :travel_mode, :travel_mode_options, :waypoints) SENSITIVE = [:departure_time, :destination, :key, :origin] include Aws::Structure end |