Class: Aws::GeoRoutes::Types::RoadSnapTravelModeOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RoadSnapTravelModeOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Travel mode related options for the provided travel mode.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#truck ⇒ Types::RoadSnapTruckOptions
Travel mode options when the provided travel mode is ‘Truck`.
Instance Attribute Details
#truck ⇒ Types::RoadSnapTruckOptions
Travel mode options when the provided travel mode is ‘Truck`.
2273 2274 2275 2276 2277 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2273 class RoadSnapTravelModeOptions < Struct.new( :truck) SENSITIVE = [] include Aws::Structure end |