Class: Aws::GeoRoutes::Types::RoadSnapTruckOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RoadSnapTruckOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Travel mode options when the provided travel mode is ‘Truck`.
Constant Summary collapse
- SENSITIVE =
[:gross_weight, :hazardous_cargos, :height, :length, :tunnel_restriction_code, :width]
Instance Attribute Summary collapse
-
#gross_weight ⇒ Integer
Gross weight of the vehicle including trailers, and goods at capacity.
-
#hazardous_cargos ⇒ Array<String>
List of Hazardous cargos contained in the vehicle.
-
#height ⇒ Integer
Height of the vehicle.
-
#length ⇒ Integer
Length of the vehicle.
-
#trailer ⇒ Types::RoadSnapTrailerOptions
Trailer options corresponding to the vehicle.
-
#tunnel_restriction_code ⇒ String
The tunnel restriction code.
-
#width ⇒ Integer
Width of the vehicle in centimeters.
Instance Attribute Details
#gross_weight ⇒ Integer
Gross weight of the vehicle including trailers, and goods at capacity.
Unit: ‘kilograms`
2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2401 class RoadSnapTruckOptions < Struct.new( :gross_weight, :hazardous_cargos, :height, :length, :trailer, :tunnel_restriction_code, :width) SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :tunnel_restriction_code, :width] include Aws::Structure end |
#hazardous_cargos ⇒ Array<String>
List of Hazardous cargos contained in the vehicle.
2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2401 class RoadSnapTruckOptions < Struct.new( :gross_weight, :hazardous_cargos, :height, :length, :trailer, :tunnel_restriction_code, :width) SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :tunnel_restriction_code, :width] include Aws::Structure end |
#height ⇒ Integer
Height of the vehicle.
Unit: ‘centimeters`
2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2401 class RoadSnapTruckOptions < Struct.new( :gross_weight, :hazardous_cargos, :height, :length, :trailer, :tunnel_restriction_code, :width) SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :tunnel_restriction_code, :width] include Aws::Structure end |
#length ⇒ Integer
Length of the vehicle.
Unit: ‘centimeters`
2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2401 class RoadSnapTruckOptions < Struct.new( :gross_weight, :hazardous_cargos, :height, :length, :trailer, :tunnel_restriction_code, :width) SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :tunnel_restriction_code, :width] include Aws::Structure end |
#trailer ⇒ Types::RoadSnapTrailerOptions
Trailer options corresponding to the vehicle.
2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2401 class RoadSnapTruckOptions < Struct.new( :gross_weight, :hazardous_cargos, :height, :length, :trailer, :tunnel_restriction_code, :width) SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :tunnel_restriction_code, :width] include Aws::Structure end |
#tunnel_restriction_code ⇒ String
The tunnel restriction code.
Tunnel categories in this list indicate the restrictions which apply to certain tunnels in Great Britain. They relate to the types of dangerous goods that can be transported through them.
-
*Tunnel Category B*
-
*Risk Level*: Limited risk
-
Restrictions: Few restrictions
-
-
*Tunnel Category C*
-
*Risk Level*: Medium risk
-
Restrictions: Some restrictions
-
-
*Tunnel Category D*
-
*Risk Level*: High risk
-
Restrictions: Many restrictions occur
-
-
*Tunnel Category E*
-
*Risk Level*: Very high risk
-
Restrictions: Restricted tunnel
-
2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2401 class RoadSnapTruckOptions < Struct.new( :gross_weight, :hazardous_cargos, :height, :length, :trailer, :tunnel_restriction_code, :width) SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :tunnel_restriction_code, :width] include Aws::Structure end |
#width ⇒ Integer
Width of the vehicle in centimeters.
2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2401 class RoadSnapTruckOptions < Struct.new( :gross_weight, :hazardous_cargos, :height, :length, :trailer, :tunnel_restriction_code, :width) SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :tunnel_restriction_code, :width] include Aws::Structure end |