Class: Aws::GeoRoutes::Types::RouteDestinationOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteDestinationOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Options related to the destination.
Constant Summary collapse
- SENSITIVE =
[:avoid_actions_for_distance, :avoid_u_turns, :heading, :stop_duration]
Instance Attribute Summary collapse
-
#avoid_actions_for_distance ⇒ Integer
The distance in meters from the destination point within which certain routing actions (such as U-turns or left turns across traffic) are restricted.
-
#avoid_u_turns ⇒ Boolean
Avoid U-turns for calculation on highways and motorways.
-
#heading ⇒ Float
GPS Heading at the position.
-
#matching ⇒ Types::RouteMatchingOptions
Options to configure matching the provided position to the road network.
-
#side_of_street ⇒ Types::RouteSideOfStreetOptions
Options to configure matching the provided position to a side of the street.
-
#stop_duration ⇒ Integer
Duration of the stop.
Instance Attribute Details
#avoid_actions_for_distance ⇒ Integer
The distance in meters from the destination point within which certain routing actions (such as U-turns or left turns across traffic) are restricted. This helps generate more practical routes by avoiding potentially dangerous maneuvers near the endpoint.
2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2893 class RouteDestinationOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :stop_duration] include Aws::Structure end |
#avoid_u_turns ⇒ Boolean
Avoid U-turns for calculation on highways and motorways.
2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2893 class RouteDestinationOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :stop_duration] include Aws::Structure end |
#heading ⇒ Float
GPS Heading at the position.
2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2893 class RouteDestinationOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :stop_duration] include Aws::Structure end |
#matching ⇒ Types::RouteMatchingOptions
Options to configure matching the provided position to the road network.
2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2893 class RouteDestinationOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :stop_duration] include Aws::Structure end |
#side_of_street ⇒ Types::RouteSideOfStreetOptions
Options to configure matching the provided position to a side of the street.
2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2893 class RouteDestinationOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :stop_duration] include Aws::Structure end |
#stop_duration ⇒ Integer
Duration of the stop.
Unit: ‘seconds`
2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/aws-sdk-georoutes/types.rb', line 2893 class RouteDestinationOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :stop_duration] include Aws::Structure end |