Class: Aws::GeoRoutes::Types::RouteExclusionOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Specifies strict exclusion options for the route calculation. This setting mandates that the router will avoid any routes that include the specified options, rather than merely attempting to minimize them.

Constant Summary collapse

SENSITIVE =
[:countries]

Instance Attribute Summary collapse

Instance Attribute Details

#countriesArray<String>

List of countries to be avoided defined by two-letter or three-letter country codes.

Returns:

  • (Array<String>)


3007
3008
3009
3010
3011
# File 'lib/aws-sdk-georoutes/types.rb', line 3007

class RouteExclusionOptions < Struct.new(
  :countries)
  SENSITIVE = [:countries]
  include Aws::Structure
end