Class: Aws::GeoRoutes::Types::RouteFerryNotice
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteFerryNotice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Notices are additional information returned that indicate issues that occurred during route calculation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
Code corresponding to the issue.
-
#impact ⇒ String
Impact corresponding to the issue.
Instance Attribute Details
#code ⇒ String
Code corresponding to the issue.
3227 3228 3229 3230 3231 3232 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3227 class RouteFerryNotice < Struct.new( :code, :impact) SENSITIVE = [] include Aws::Structure end |
#impact ⇒ String
Impact corresponding to the issue. While Low impact notices can be safely ignored, High impact notices must be evaluated further to determine the impact.
3227 3228 3229 3230 3231 3232 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3227 class RouteFerryNotice < Struct.new( :code, :impact) SENSITIVE = [] include Aws::Structure end |