Class: Aws::GeoRoutes::Types::RouteFerryTravelOnlySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteFerryTravelOnlySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Summarized details for the leg including travel steps only. The Distance for the travel only portion of the journey is the same as the Distance within the Overview summary.
Constant Summary collapse
- SENSITIVE =
[:duration]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
Total duration in free flowing traffic, which is the best case or shortest duration possible to cover the leg.
Instance Attribute Details
#duration ⇒ Integer
Total duration in free flowing traffic, which is the best case or shortest duration possible to cover the leg.
Unit: ‘seconds`
3369 3370 3371 3372 3373 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3369 class RouteFerryTravelOnlySummary < Struct.new( :duration) SENSITIVE = [:duration] include Aws::Structure end |