Class: Aws::GeoRoutes::Types::RouteIntermodalOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Options related to intermodal routing.

<note markdown=“1”> Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

</note>

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Constant Summary collapse

SENSITIVE =
[:accessibility_attributes]

Instance Attribute Summary collapse

Instance Attribute Details

#accessibility_attributesArray<String>

Accessibility attributes to consider when calculating the route.

Returns:

  • (Array<String>)


3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
# File 'lib/aws-sdk-georoutes/types.rb', line 3457

class RouteIntermodalOptions < Struct.new(
  :accessibility_attributes,
  :max_transfers,
  :pedestrian,
  :rental,
  :taxi,
  :transit,
  :vehicle)
  SENSITIVE = [:accessibility_attributes]
  include Aws::Structure
end

#max_transfersInteger

Maximum number of transfers allowed when calculating the route.

Returns:

  • (Integer)


3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
# File 'lib/aws-sdk-georoutes/types.rb', line 3457

class RouteIntermodalOptions < Struct.new(
  :accessibility_attributes,
  :max_transfers,
  :pedestrian,
  :rental,
  :taxi,
  :transit,
  :vehicle)
  SENSITIVE = [:accessibility_attributes]
  include Aws::Structure
end

#pedestrianTypes::RouteIntermodalPedestrianOptions

Options for the pedestrian leg of the intermodal route.



3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
# File 'lib/aws-sdk-georoutes/types.rb', line 3457

class RouteIntermodalOptions < Struct.new(
  :accessibility_attributes,
  :max_transfers,
  :pedestrian,
  :rental,
  :taxi,
  :transit,
  :vehicle)
  SENSITIVE = [:accessibility_attributes]
  include Aws::Structure
end

#rentalTypes::RouteIntermodalRentalOptions

Options for the rental leg of the intermodal route.



3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
# File 'lib/aws-sdk-georoutes/types.rb', line 3457

class RouteIntermodalOptions < Struct.new(
  :accessibility_attributes,
  :max_transfers,
  :pedestrian,
  :rental,
  :taxi,
  :transit,
  :vehicle)
  SENSITIVE = [:accessibility_attributes]
  include Aws::Structure
end

#taxiTypes::RouteIntermodalTaxiOptions

Options for the taxi leg of the intermodal route.



3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
# File 'lib/aws-sdk-georoutes/types.rb', line 3457

class RouteIntermodalOptions < Struct.new(
  :accessibility_attributes,
  :max_transfers,
  :pedestrian,
  :rental,
  :taxi,
  :transit,
  :vehicle)
  SENSITIVE = [:accessibility_attributes]
  include Aws::Structure
end

#transitTypes::RouteIntermodalTransitOptions

Options for the transit leg of the intermodal route.



3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
# File 'lib/aws-sdk-georoutes/types.rb', line 3457

class RouteIntermodalOptions < Struct.new(
  :accessibility_attributes,
  :max_transfers,
  :pedestrian,
  :rental,
  :taxi,
  :transit,
  :vehicle)
  SENSITIVE = [:accessibility_attributes]
  include Aws::Structure
end

#vehicleTypes::RouteIntermodalVehicleOptions

Options for the vehicle leg of the intermodal route.



3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
# File 'lib/aws-sdk-georoutes/types.rb', line 3457

class RouteIntermodalOptions < Struct.new(
  :accessibility_attributes,
  :max_transfers,
  :pedestrian,
  :rental,
  :taxi,
  :transit,
  :vehicle)
  SENSITIVE = [:accessibility_attributes]
  include Aws::Structure
end