Class: Aws::GeoRoutes::Types::RouteIntermodalRentalOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteIntermodalRentalOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Options for the rental leg of the intermodal route.
Constant Summary collapse
- SENSITIVE =
[:allowed_modes, :enabled_for, :excluded_modes]
Instance Attribute Summary collapse
-
#allowed_modes ⇒ Array<String>
Allowed rental transport modes when calculating the route.
-
#enabled_for ⇒ Array<String>
Specifies the portion of the route for which this leg type is enabled.
-
#excluded_modes ⇒ Array<String>
Excluded rental transport modes when calculating the route.
Instance Attribute Details
#allowed_modes ⇒ Array<String>
Allowed rental transport modes when calculating the route. By default, all transport modes are allowed. Cannot be used together with ‘ExcludedModes`.
3524 3525 3526 3527 3528 3529 3530 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3524 class RouteIntermodalRentalOptions < Struct.new( :allowed_modes, :enabled_for, :excluded_modes) SENSITIVE = [:allowed_modes, :enabled_for, :excluded_modes] include Aws::Structure end |
#enabled_for ⇒ Array<String>
Specifies the portion of the route for which this leg type is enabled. By default, the leg type is enabled for all legs. Valid values:
-
‘FirstLeg` - Enable this leg type for the first non-pedestrian leg of the route.
-
‘LastLeg` - Enable this leg type for the last non-pedestrian leg of the route.
-
‘EntireRoute` - Enable this leg type for the entire route.
-
‘None` - Disable this leg type entirely.
3524 3525 3526 3527 3528 3529 3530 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3524 class RouteIntermodalRentalOptions < Struct.new( :allowed_modes, :enabled_for, :excluded_modes) SENSITIVE = [:allowed_modes, :enabled_for, :excluded_modes] include Aws::Structure end |
#excluded_modes ⇒ Array<String>
Excluded rental transport modes when calculating the route. By default, all transport modes are allowed. Cannot be used together with ‘AllowedModes`.
3524 3525 3526 3527 3528 3529 3530 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3524 class RouteIntermodalRentalOptions < Struct.new( :allowed_modes, :enabled_for, :excluded_modes) SENSITIVE = [:allowed_modes, :enabled_for, :excluded_modes] include Aws::Structure end |