Class: Aws::GeoRoutes::Types::RouteIntermodalTaxiOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Options for the taxi leg of the intermodal route.

Constant Summary collapse

SENSITIVE =
[:allowed_modes, :enabled_for, :excluded_modes]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_modesArray<String>

Allowed taxi transport modes when calculating the route. By default, all transport modes are allowed. Cannot be used together with ‘ExcludedModes`.

Returns:

  • (Array<String>)


3564
3565
3566
3567
3568
3569
3570
# File 'lib/aws-sdk-georoutes/types.rb', line 3564

class RouteIntermodalTaxiOptions < Struct.new(
  :allowed_modes,
  :enabled_for,
  :excluded_modes)
  SENSITIVE = [:allowed_modes, :enabled_for, :excluded_modes]
  include Aws::Structure
end

#enabled_forArray<String>

Specifies the portion of the route for which this leg type is enabled. By default, the leg type is enabled for all legs. Valid values:

  • ‘FirstLeg` - Enable this leg type for the first non-pedestrian leg of the route.

  • ‘LastLeg` - Enable this leg type for the last non-pedestrian leg of the route.

  • ‘EntireRoute` - Enable this leg type for the entire route.

  • ‘None` - Disable this leg type entirely.

Returns:

  • (Array<String>)


3564
3565
3566
3567
3568
3569
3570
# File 'lib/aws-sdk-georoutes/types.rb', line 3564

class RouteIntermodalTaxiOptions < Struct.new(
  :allowed_modes,
  :enabled_for,
  :excluded_modes)
  SENSITIVE = [:allowed_modes, :enabled_for, :excluded_modes]
  include Aws::Structure
end

#excluded_modesArray<String>

Excluded taxi transport modes when calculating the route. By default, all transport modes are allowed. Cannot be used together with ‘AllowedModes`.

Returns:

  • (Array<String>)


3564
3565
3566
3567
3568
3569
3570
# File 'lib/aws-sdk-georoutes/types.rb', line 3564

class RouteIntermodalTaxiOptions < Struct.new(
  :allowed_modes,
  :enabled_for,
  :excluded_modes)
  SENSITIVE = [:allowed_modes, :enabled_for, :excluded_modes]
  include Aws::Structure
end