Class: Aws::GeoRoutes::Types::RouteIntermodalTransitOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Options for the transit leg of the intermodal route.

Constant Summary collapse

SENSITIVE =
[:allowed_modes, :enabled_for, :excluded_modes]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_modesArray<String>

Allowed transit transport modes when calculating the route. By default, all transport modes are allowed. Cannot be used together with ‘ExcludedModes`.

Returns:

  • (Array<String>)


3604
3605
3606
3607
3608
3609
3610
# File 'lib/aws-sdk-georoutes/types.rb', line 3604

class RouteIntermodalTransitOptions < Struct.new(
  :allowed_modes,
  :enabled_for,
  :excluded_modes)
  SENSITIVE = [:allowed_modes, :enabled_for, :excluded_modes]
  include Aws::Structure
end

#enabled_forArray<String>

Specifies the portion of the route for which this leg type is enabled. By default, the leg type is enabled for all legs. Valid values:

  • ‘FirstLeg` - Enable this leg type for the first non-pedestrian leg of the route.

  • ‘LastLeg` - Enable this leg type for the last non-pedestrian leg of the route.

  • ‘EntireRoute` - Enable this leg type for the entire route.

  • ‘None` - Disable this leg type entirely.

Returns:

  • (Array<String>)


3604
3605
3606
3607
3608
3609
3610
# File 'lib/aws-sdk-georoutes/types.rb', line 3604

class RouteIntermodalTransitOptions < Struct.new(
  :allowed_modes,
  :enabled_for,
  :excluded_modes)
  SENSITIVE = [:allowed_modes, :enabled_for, :excluded_modes]
  include Aws::Structure
end

#excluded_modesArray<String>

Excluded transit transport modes when calculating the route. By default, all transport modes are allowed. Cannot be used together with ‘AllowedModes`.

Returns:

  • (Array<String>)


3604
3605
3606
3607
3608
3609
3610
# File 'lib/aws-sdk-georoutes/types.rb', line 3604

class RouteIntermodalTransitOptions < Struct.new(
  :allowed_modes,
  :enabled_for,
  :excluded_modes)
  SENSITIVE = [:allowed_modes, :enabled_for, :excluded_modes]
  include Aws::Structure
end