Class: Aws::GeoRoutes::Types::RouteLeg

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

A leg is a section of a route from one waypoint to the next. A leg could be of type Vehicle, Pedestrian or Ferry. Legs of different types could occur together within a single route. For example, a car employing the use of a Ferry will contain Vehicle legs corresponding to journey on land, and Ferry legs corresponding to the journey via Ferry.

Constant Summary collapse

SENSITIVE =
[:travel_mode, :type]

Instance Attribute Summary collapse

Instance Attribute Details

#ferry_leg_detailsTypes::RouteFerryLegDetails

FerryLegDetails is populated when the Leg type is Ferry, and provides additional information that is specific to ferry travel. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'lib/aws-sdk-georoutes/types.rb', line 3764

class RouteLeg < Struct.new(
  :ferry_leg_details,
  :geometry,
  :language,
  :pedestrian_leg_details,
  :travel_mode,
  :type,
  :vehicle_leg_details,
  :rental_leg_details,
  :taxi_leg_details,
  :transit_leg_details)
  SENSITIVE = [:travel_mode, :type]
  include Aws::Structure
end

#geometryTypes::RouteLegGeometry

Geometry of the area to be avoided.



3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'lib/aws-sdk-georoutes/types.rb', line 3764

class RouteLeg < Struct.new(
  :ferry_leg_details,
  :geometry,
  :language,
  :pedestrian_leg_details,
  :travel_mode,
  :type,
  :vehicle_leg_details,
  :rental_leg_details,
  :taxi_leg_details,
  :transit_leg_details)
  SENSITIVE = [:travel_mode, :type]
  include Aws::Structure
end

#languageString

List of languages for instructions within steps in the response. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (String)


3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'lib/aws-sdk-georoutes/types.rb', line 3764

class RouteLeg < Struct.new(
  :ferry_leg_details,
  :geometry,
  :language,
  :pedestrian_leg_details,
  :travel_mode,
  :type,
  :vehicle_leg_details,
  :rental_leg_details,
  :taxi_leg_details,
  :transit_leg_details)
  SENSITIVE = [:travel_mode, :type]
  include Aws::Structure
end

#pedestrian_leg_detailsTypes::RoutePedestrianLegDetails

Details related to the pedestrian leg.



3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'lib/aws-sdk-georoutes/types.rb', line 3764

class RouteLeg < Struct.new(
  :ferry_leg_details,
  :geometry,
  :language,
  :pedestrian_leg_details,
  :travel_mode,
  :type,
  :vehicle_leg_details,
  :rental_leg_details,
  :taxi_leg_details,
  :transit_leg_details)
  SENSITIVE = [:travel_mode, :type]
  include Aws::Structure
end

#rental_leg_detailsTypes::RouteRentalLegDetails

Details related to the rental leg.

<note markdown=“1”> Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

</note>

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'lib/aws-sdk-georoutes/types.rb', line 3764

class RouteLeg < Struct.new(
  :ferry_leg_details,
  :geometry,
  :language,
  :pedestrian_leg_details,
  :travel_mode,
  :type,
  :vehicle_leg_details,
  :rental_leg_details,
  :taxi_leg_details,
  :transit_leg_details)
  SENSITIVE = [:travel_mode, :type]
  include Aws::Structure
end

#taxi_leg_detailsTypes::RouteTaxiLegDetails

Details related to the taxi leg.

<note markdown=“1”> Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

</note>

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'lib/aws-sdk-georoutes/types.rb', line 3764

class RouteLeg < Struct.new(
  :ferry_leg_details,
  :geometry,
  :language,
  :pedestrian_leg_details,
  :travel_mode,
  :type,
  :vehicle_leg_details,
  :rental_leg_details,
  :taxi_leg_details,
  :transit_leg_details)
  SENSITIVE = [:travel_mode, :type]
  include Aws::Structure
end

#transit_leg_detailsTypes::RouteTransitLegDetails

Details related to the transit leg.



3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'lib/aws-sdk-georoutes/types.rb', line 3764

class RouteLeg < Struct.new(
  :ferry_leg_details,
  :geometry,
  :language,
  :pedestrian_leg_details,
  :travel_mode,
  :type,
  :vehicle_leg_details,
  :rental_leg_details,
  :taxi_leg_details,
  :transit_leg_details)
  SENSITIVE = [:travel_mode, :type]
  include Aws::Structure
end

#travel_modeString

Specifies the mode of transport when calculating a route. Used in estimating the speed of travel and road compatibility.

Default value: ‘Car`

Returns:

  • (String)


3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'lib/aws-sdk-georoutes/types.rb', line 3764

class RouteLeg < Struct.new(
  :ferry_leg_details,
  :geometry,
  :language,
  :pedestrian_leg_details,
  :travel_mode,
  :type,
  :vehicle_leg_details,
  :rental_leg_details,
  :taxi_leg_details,
  :transit_leg_details)
  SENSITIVE = [:travel_mode, :type]
  include Aws::Structure
end

#typeString

Type of the leg.

Returns:

  • (String)


3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'lib/aws-sdk-georoutes/types.rb', line 3764

class RouteLeg < Struct.new(
  :ferry_leg_details,
  :geometry,
  :language,
  :pedestrian_leg_details,
  :travel_mode,
  :type,
  :vehicle_leg_details,
  :rental_leg_details,
  :taxi_leg_details,
  :transit_leg_details)
  SENSITIVE = [:travel_mode, :type]
  include Aws::Structure
end

#vehicle_leg_detailsTypes::RouteVehicleLegDetails

Details related to the vehicle leg.



3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
3776
3777
# File 'lib/aws-sdk-georoutes/types.rb', line 3764

class RouteLeg < Struct.new(
  :ferry_leg_details,
  :geometry,
  :language,
  :pedestrian_leg_details,
  :travel_mode,
  :type,
  :vehicle_leg_details,
  :rental_leg_details,
  :taxi_leg_details,
  :transit_leg_details)
  SENSITIVE = [:travel_mode, :type]
  include Aws::Structure
end