Class: Aws::GeoRoutes::Types::RouteMatrixAvoidanceAreaGeometry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Geometry of the area to be avoided.

Constant Summary collapse

SENSITIVE =
[:bounding_box, :polyline_polygon]

Instance Attribute Summary collapse

Instance Attribute Details

#bounding_boxArray<Float>

Geometry defined as a bounding box. The first pair represents the X and Y coordinates (longitude and latitude,) of the southwest corner of the bounding box; the second pair represents the X and Y coordinates (longitude and latitude) of the northeast corner.

Returns:

  • (Array<Float>)


3971
3972
3973
3974
3975
3976
3977
# File 'lib/aws-sdk-georoutes/types.rb', line 3971

class RouteMatrixAvoidanceAreaGeometry < Struct.new(
  :bounding_box,
  :polygon,
  :polyline_polygon)
  SENSITIVE = [:bounding_box, :polyline_polygon]
  include Aws::Structure
end

#polygonArray<Array<Array<Float>>>

Geometry defined as a polygon with only one linear ring.

Returns:

  • (Array<Array<Array<Float>>>)


3971
3972
3973
3974
3975
3976
3977
# File 'lib/aws-sdk-georoutes/types.rb', line 3971

class RouteMatrixAvoidanceAreaGeometry < Struct.new(
  :bounding_box,
  :polygon,
  :polyline_polygon)
  SENSITIVE = [:bounding_box, :polyline_polygon]
  include Aws::Structure
end

#polyline_polygonArray<String>

A list of Isoline PolylinePolygon, for each isoline PolylinePolygon, it contains PolylinePolygon of the first linear ring (the outer ring) and from second item to the last item (the inner rings). For more information on polyline encoding, see [github.com/aws-geospatial/polyline][1].

[1]: github.com/aws-geospatial/polyline

Returns:

  • (Array<String>)


3971
3972
3973
3974
3975
3976
3977
# File 'lib/aws-sdk-georoutes/types.rb', line 3971

class RouteMatrixAvoidanceAreaGeometry < Struct.new(
  :bounding_box,
  :polygon,
  :polyline_polygon)
  SENSITIVE = [:bounding_box, :polyline_polygon]
  include Aws::Structure
end