Class: Aws::GeoRoutes::Types::RouteMatrixDestinationOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteMatrixDestinationOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Options related to the destination.
Constant Summary collapse
- SENSITIVE =
[:avoid_actions_for_distance, :heading]
Instance Attribute Summary collapse
-
#avoid_actions_for_distance ⇒ Integer
Avoids actions for the provided distance.
-
#heading ⇒ Float
GPS Heading at the position.
-
#matching ⇒ Types::RouteMatrixMatchingOptions
Options to configure matching the provided position to the road network.
-
#side_of_street ⇒ Types::RouteMatrixSideOfStreetOptions
Options to configure matching the provided position to a side of the street.
Instance Attribute Details
#avoid_actions_for_distance ⇒ Integer
Avoids actions for the provided distance. This is typically to consider for users in moving vehicles who may not have sufficient time to make an action at an origin or a destination.
4228 4229 4230 4231 4232 4233 4234 4235 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4228 class RouteMatrixDestinationOptions < Struct.new( :avoid_actions_for_distance, :heading, :matching, :side_of_street) SENSITIVE = [:avoid_actions_for_distance, :heading] include Aws::Structure end |
#heading ⇒ Float
GPS Heading at the position.
4228 4229 4230 4231 4232 4233 4234 4235 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4228 class RouteMatrixDestinationOptions < Struct.new( :avoid_actions_for_distance, :heading, :matching, :side_of_street) SENSITIVE = [:avoid_actions_for_distance, :heading] include Aws::Structure end |
#matching ⇒ Types::RouteMatrixMatchingOptions
Options to configure matching the provided position to the road network.
4228 4229 4230 4231 4232 4233 4234 4235 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4228 class RouteMatrixDestinationOptions < Struct.new( :avoid_actions_for_distance, :heading, :matching, :side_of_street) SENSITIVE = [:avoid_actions_for_distance, :heading] include Aws::Structure end |
#side_of_street ⇒ Types::RouteMatrixSideOfStreetOptions
Options to configure matching the provided position to a side of the street.
4228 4229 4230 4231 4232 4233 4234 4235 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4228 class RouteMatrixDestinationOptions < Struct.new( :avoid_actions_for_distance, :heading, :matching, :side_of_street) SENSITIVE = [:avoid_actions_for_distance, :heading] include Aws::Structure end |