Class: Aws::GeoRoutes::Types::RouteMatrixEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteMatrixEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
The calculated route matrix containing the results for all pairs of Origins to Destination positions. Each row corresponds to one entry in Origins. Each entry in the row corresponds to the route from that entry in Origins to an entry in Destination positions.
Constant Summary collapse
- SENSITIVE =
[:distance, :duration]
Instance Attribute Summary collapse
-
#distance ⇒ Integer
The total distance of travel for the route.
-
#duration ⇒ Integer
The expected duration of travel for the route.
-
#error ⇒ String
Error code that occurred during calculation of the route.
Instance Attribute Details
#distance ⇒ Integer
The total distance of travel for the route.
4258 4259 4260 4261 4262 4263 4264 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4258 class RouteMatrixEntry < Struct.new( :distance, :duration, :error) SENSITIVE = [:distance, :duration] include Aws::Structure end |
#duration ⇒ Integer
The expected duration of travel for the route.
Unit: ‘seconds`
4258 4259 4260 4261 4262 4263 4264 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4258 class RouteMatrixEntry < Struct.new( :distance, :duration, :error) SENSITIVE = [:distance, :duration] include Aws::Structure end |
#error ⇒ String
Error code that occurred during calculation of the route.
4258 4259 4260 4261 4262 4263 4264 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4258 class RouteMatrixEntry < Struct.new( :distance, :duration, :error) SENSITIVE = [:distance, :duration] include Aws::Structure end |