Class: Aws::GeoRoutes::Types::RouteMatrixExclusionOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteMatrixExclusionOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Specifies strict exclusion options for the route calculation. This setting mandates that the router will avoid any routes that include the specified options, rather than merely attempting to minimize them.
Constant Summary collapse
- SENSITIVE =
[:countries]
Instance Attribute Summary collapse
-
#countries ⇒ Array<String>
List of countries to be avoided defined by two-letter or three-letter country codes.
Instance Attribute Details
#countries ⇒ Array<String>
List of countries to be avoided defined by two-letter or three-letter country codes.
4277 4278 4279 4280 4281 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4277 class RouteMatrixExclusionOptions < Struct.new( :countries) SENSITIVE = [:countries] include Aws::Structure end |