Class: Aws::GeoRoutes::Types::RouteMatrixMatchingOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteMatrixMatchingOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Matching options.
Constant Summary collapse
- SENSITIVE =
[:name_hint, :on_road_threshold, :radius]
Instance Attribute Summary collapse
-
#name_hint ⇒ String
Attempts to match the provided position to a road similar to the provided name.
-
#on_road_threshold ⇒ Integer
If the distance to a highway/bridge/tunnel/sliproad is within threshold, the waypoint will be snapped to the highway/bridge/tunnel/sliproad.
-
#radius ⇒ Integer
Considers all roads within the provided radius to match the provided destination to.
-
#strategy ⇒ String
Strategy that defines matching of the position onto the road network.
Instance Attribute Details
#name_hint ⇒ String
Attempts to match the provided position to a road similar to the provided name.
4314 4315 4316 4317 4318 4319 4320 4321 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4314 class RouteMatrixMatchingOptions < Struct.new( :name_hint, :on_road_threshold, :radius, :strategy) SENSITIVE = [:name_hint, :on_road_threshold, :radius] include Aws::Structure end |
#on_road_threshold ⇒ Integer
If the distance to a highway/bridge/tunnel/sliproad is within threshold, the waypoint will be snapped to the highway/bridge/tunnel/sliproad.
Unit: ‘meters`
4314 4315 4316 4317 4318 4319 4320 4321 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4314 class RouteMatrixMatchingOptions < Struct.new( :name_hint, :on_road_threshold, :radius, :strategy) SENSITIVE = [:name_hint, :on_road_threshold, :radius] include Aws::Structure end |
#radius ⇒ Integer
Considers all roads within the provided radius to match the provided destination to. The roads that are considered are determined by the provided Strategy.
Unit: ‘meters`
4314 4315 4316 4317 4318 4319 4320 4321 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4314 class RouteMatrixMatchingOptions < Struct.new( :name_hint, :on_road_threshold, :radius, :strategy) SENSITIVE = [:name_hint, :on_road_threshold, :radius] include Aws::Structure end |
#strategy ⇒ String
Strategy that defines matching of the position onto the road network. MatchAny considers all roads possible, whereas MatchMostSignificantRoad matches to the most significant road.
4314 4315 4316 4317 4318 4319 4320 4321 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4314 class RouteMatrixMatchingOptions < Struct.new( :name_hint, :on_road_threshold, :radius, :strategy) SENSITIVE = [:name_hint, :on_road_threshold, :radius] include Aws::Structure end |