Class: Aws::GeoRoutes::Types::RouteMatrixOriginOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Origin related options.

Constant Summary collapse

SENSITIVE =
[:avoid_actions_for_distance, :heading]

Instance Attribute Summary collapse

Instance Attribute Details

#avoid_actions_for_distanceInteger

Avoids actions for the provided distance. This is typically to consider for users in moving vehicles who may not have sufficient time to make an action at an origin or a destination.

Returns:

  • (Integer)


4373
4374
4375
4376
4377
4378
4379
4380
# File 'lib/aws-sdk-georoutes/types.rb', line 4373

class RouteMatrixOriginOptions < Struct.new(
  :avoid_actions_for_distance,
  :heading,
  :matching,
  :side_of_street)
  SENSITIVE = [:avoid_actions_for_distance, :heading]
  include Aws::Structure
end

#headingFloat

GPS Heading at the position.

Returns:

  • (Float)


4373
4374
4375
4376
4377
4378
4379
4380
# File 'lib/aws-sdk-georoutes/types.rb', line 4373

class RouteMatrixOriginOptions < Struct.new(
  :avoid_actions_for_distance,
  :heading,
  :matching,
  :side_of_street)
  SENSITIVE = [:avoid_actions_for_distance, :heading]
  include Aws::Structure
end

#matchingTypes::RouteMatrixMatchingOptions

Options to configure matching the provided position to the road network.



4373
4374
4375
4376
4377
4378
4379
4380
# File 'lib/aws-sdk-georoutes/types.rb', line 4373

class RouteMatrixOriginOptions < Struct.new(
  :avoid_actions_for_distance,
  :heading,
  :matching,
  :side_of_street)
  SENSITIVE = [:avoid_actions_for_distance, :heading]
  include Aws::Structure
end

#side_of_streetTypes::RouteMatrixSideOfStreetOptions

Options to configure matching the provided position to a side of the street.



4373
4374
4375
4376
4377
4378
4379
4380
# File 'lib/aws-sdk-georoutes/types.rb', line 4373

class RouteMatrixOriginOptions < Struct.new(
  :avoid_actions_for_distance,
  :heading,
  :matching,
  :side_of_street)
  SENSITIVE = [:avoid_actions_for_distance, :heading]
  include Aws::Structure
end