Class: Aws::GeoRoutes::Types::RouteMatrixTrafficOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteMatrixTrafficOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Traffic related options.
Constant Summary collapse
- SENSITIVE =
[:flow_event_threshold_override]
Instance Attribute Summary collapse
-
#flow_event_threshold_override ⇒ Integer
Duration for which flow traffic is considered valid.
-
#usage ⇒ String
Determines if traffic should be used or ignored while calculating the route.
Instance Attribute Details
#flow_event_threshold_override ⇒ Integer
Duration for which flow traffic is considered valid. For this period, the flow traffic is used over historical traffic data. Flow traffic refers to congestion, which changes very quickly. Duration in seconds for which flow traffic event would be considered valid. While flow traffic event is valid it will be used over the historical traffic data.
4454 4455 4456 4457 4458 4459 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4454 class RouteMatrixTrafficOptions < Struct.new( :flow_event_threshold_override, :usage) SENSITIVE = [:flow_event_threshold_override] include Aws::Structure end |
#usage ⇒ String
Determines if traffic should be used or ignored while calculating the route.
Default value: ‘UseTrafficData`
4454 4455 4456 4457 4458 4459 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4454 class RouteMatrixTrafficOptions < Struct.new( :flow_event_threshold_override, :usage) SENSITIVE = [:flow_event_threshold_override] include Aws::Structure end |