Class: Aws::GeoRoutes::Types::RouteMatrixTravelModeOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Travel mode related options for the provided travel mode.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#carTypes::RouteMatrixCarOptions

Travel mode options when the provided travel mode is ‘Car`.



4047
4048
4049
4050
4051
4052
4053
# File 'lib/aws-sdk-georoutes/types.rb', line 4047

class RouteMatrixTravelModeOptions < Struct.new(
  :car,
  :scooter,
  :truck)
  SENSITIVE = []
  include Aws::Structure
end

#scooterTypes::RouteMatrixScooterOptions

Travel mode options when the provided travel mode is ‘Scooter`.

<note markdown=“1”> When travel mode is set to ‘Scooter`, then the avoidance option `ControlledAccessHighways` defaults to `true`.

</note>


4047
4048
4049
4050
4051
4052
4053
# File 'lib/aws-sdk-georoutes/types.rb', line 4047

class RouteMatrixTravelModeOptions < Struct.new(
  :car,
  :scooter,
  :truck)
  SENSITIVE = []
  include Aws::Structure
end

#truckTypes::RouteMatrixTruckOptions

Travel mode options when the provided travel mode is ‘Truck`.



4047
4048
4049
4050
4051
4052
4053
# File 'lib/aws-sdk-georoutes/types.rb', line 4047

class RouteMatrixTravelModeOptions < Struct.new(
  :car,
  :scooter,
  :truck)
  SENSITIVE = []
  include Aws::Structure
end