Class: Aws::GeoRoutes::Types::RouteMatrixTruckOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteMatrixTruckOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Travel mode options when the provided travel mode is ‘Truck`.
Constant Summary collapse
- SENSITIVE =
[:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
Instance Attribute Summary collapse
-
#axle_count ⇒ Integer
Total number of axles of the vehicle.
-
#gross_weight ⇒ Integer
Gross weight of the vehicle including trailers, and goods at capacity.
-
#hazardous_cargos ⇒ Array<String>
List of Hazardous cargo contained in the vehicle.
-
#height ⇒ Integer
Height of the vehicle.
-
#kpra_length ⇒ Integer
Kingpin to rear axle length of the vehicle.
-
#length ⇒ Integer
Length of the vehicle.
-
#license_plate ⇒ Types::RouteMatrixVehicleLicensePlate
The vehicle License Plate.
-
#max_speed ⇒ Float
Maximum speed.
-
#occupancy ⇒ Integer
The number of occupants in the vehicle.
-
#payload_capacity ⇒ Integer
Payload capacity of the vehicle and trailers attached.
-
#trailer ⇒ Types::RouteMatrixTrailerOptions
Trailer options corresponding to the vehicle.
-
#truck_type ⇒ String
The type of truck: ‘LightTruck` for smaller delivery vehicles, ` StraightTruck` for rigid body trucks, or `Tractor` for tractor-trailer combinations.
-
#tunnel_restriction_code ⇒ String
The tunnel restriction code.
-
#weight_per_axle ⇒ Integer
Heaviest weight per axle irrespective of the axle type or the axle group.
-
#weight_per_axle_group ⇒ Types::WeightPerAxleGroup
Specifies the total weight for the specified axle group.
-
#width ⇒ Integer
Width of the vehicle.
Instance Attribute Details
#axle_count ⇒ Integer
Total number of axles of the vehicle.
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#gross_weight ⇒ Integer
Gross weight of the vehicle including trailers, and goods at capacity.
Unit: ‘kilograms`
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#hazardous_cargos ⇒ Array<String>
List of Hazardous cargo contained in the vehicle.
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#height ⇒ Integer
Height of the vehicle.
Unit: ‘centimeters`
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#kpra_length ⇒ Integer
Kingpin to rear axle length of the vehicle
Unit: ‘centimeters`
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#length ⇒ Integer
Length of the vehicle.
Unit: ‘centimeters`
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#license_plate ⇒ Types::RouteMatrixVehicleLicensePlate
The vehicle License Plate.
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#max_speed ⇒ Float
Maximum speed
Unit: ‘kilometers per hour`
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#occupancy ⇒ Integer
The number of occupants in the vehicle.
Default value: ‘1`
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#payload_capacity ⇒ Integer
Payload capacity of the vehicle and trailers attached.
Unit: ‘kilograms`
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#trailer ⇒ Types::RouteMatrixTrailerOptions
Trailer options corresponding to the vehicle.
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#truck_type ⇒ String
The type of truck: ‘LightTruck` for smaller delivery vehicles, ` StraightTruck` for rigid body trucks, or `Tractor` for tractor-trailer combinations.
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#tunnel_restriction_code ⇒ String
The tunnel restriction code.
Tunnel categories in this list indicate the restrictions which apply to certain tunnels in Great Britain. They relate to the types of dangerous goods that can be transported through them.
-
*Tunnel Category B*
-
*Risk Level*: Limited risk
-
Restrictions: Few restrictions
-
-
*Tunnel Category C*
-
*Risk Level*: Medium risk
-
Restrictions: Some restrictions
-
-
*Tunnel Category D*
-
*Risk Level*: High risk
-
Restrictions: Many restrictions occur
-
-
*Tunnel Category E*
-
*Risk Level*: Very high risk
-
Restrictions: Restricted tunnel
-
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#weight_per_axle ⇒ Integer
Heaviest weight per axle irrespective of the axle type or the axle group. Meant for usage in countries where the differences in axle types or axle groups are not distinguished.
Unit: ‘kilograms`
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#weight_per_axle_group ⇒ Types::WeightPerAxleGroup
Specifies the total weight for the specified axle group. Meant for usage in countries that have different regulations based on the axle group type.
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#width ⇒ Integer
Width of the vehicle.
Unit: ‘centimeters`
4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4624 class RouteMatrixTruckOptions < Struct.new( :axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |