Class: Aws::GeoRoutes::Types::RouteOriginOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteOriginOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Origin related options.
Constant Summary collapse
- SENSITIVE =
[:avoid_actions_for_distance, :avoid_u_turns, :heading]
Instance Attribute Summary collapse
-
#avoid_actions_for_distance ⇒ Integer
Avoids actions for the provided distance.
-
#avoid_u_turns ⇒ Boolean
Avoid U-turns for calculation on highways and motorways.
-
#heading ⇒ Float
GPS Heading at the position.
-
#matching ⇒ Types::RouteMatchingOptions
Options to configure matching the provided position to the road network.
-
#side_of_street ⇒ Types::RouteSideOfStreetOptions
Options to configure matching the provided position to a side of the street.
Instance Attribute Details
#avoid_actions_for_distance ⇒ Integer
Avoids actions for the provided distance. This is typically to consider for users in moving vehicles who may not have sufficient time to make an action at an origin or a destination.
4731 4732 4733 4734 4735 4736 4737 4738 4739 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4731 class RouteOriginOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading] include Aws::Structure end |
#avoid_u_turns ⇒ Boolean
Avoid U-turns for calculation on highways and motorways.
4731 4732 4733 4734 4735 4736 4737 4738 4739 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4731 class RouteOriginOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading] include Aws::Structure end |
#heading ⇒ Float
GPS Heading at the position.
4731 4732 4733 4734 4735 4736 4737 4738 4739 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4731 class RouteOriginOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading] include Aws::Structure end |
#matching ⇒ Types::RouteMatchingOptions
Options to configure matching the provided position to the road network.
4731 4732 4733 4734 4735 4736 4737 4738 4739 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4731 class RouteOriginOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading] include Aws::Structure end |
#side_of_street ⇒ Types::RouteSideOfStreetOptions
Options to configure matching the provided position to a side of the street.
4731 4732 4733 4734 4735 4736 4737 4738 4739 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4731 class RouteOriginOptions < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :side_of_street) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading] include Aws::Structure end |