Class: Aws::GeoRoutes::Types::RoutePassThroughWaypoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RoutePassThroughWaypoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
If the waypoint should be treated as a stop. If yes, the route is split up into different legs around the stop.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
-
#place ⇒ Types::RoutePassThroughPlace
Place details corresponding to the pass-through waypoint.
Instance Attribute Details
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
4780 4781 4782 4783 4784 4785 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4780 class RoutePassThroughWaypoint < Struct.new( :geometry_offset, :place) SENSITIVE = [] include Aws::Structure end |
#place ⇒ Types::RoutePassThroughPlace
Place details corresponding to the pass-through waypoint.
4780 4781 4782 4783 4784 4785 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4780 class RoutePassThroughWaypoint < Struct.new( :geometry_offset, :place) SENSITIVE = [] include Aws::Structure end |