Class: Aws::GeoRoutes::Types::RoutePedestrianNotice
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RoutePedestrianNotice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Notices are additional information returned that indicate issues that occurred during route calculation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
Code corresponding to the issue.
-
#impact ⇒ String
Impact corresponding to the issue.
Instance Attribute Details
#code ⇒ String
Code corresponding to the issue.
4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4952 class RoutePedestrianNotice < Struct.new( :code, :impact) SENSITIVE = [] include Aws::Structure end |
#impact ⇒ String
Impact corresponding to the issue. While Low impact notices can be safely ignored, High impact notices must be evaluated further to determine the impact.
4952 4953 4954 4955 4956 4957 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4952 class RoutePedestrianNotice < Struct.new( :code, :impact) SENSITIVE = [] include Aws::Structure end |