Class: Aws::GeoRoutes::Types::RoutePedestrianSpan
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RoutePedestrianSpan
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Span computed for the requested SpanAdditionalFeatures.
Constant Summary collapse
- SENSITIVE =
[:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration]
Instance Attribute Summary collapse
-
#best_case_duration ⇒ Integer
Duration of the computed span without traffic congestion.
-
#country ⇒ String
3 letter Country code corresponding to the Span.
-
#distance ⇒ Integer
Distance of the computed span.
-
#duration ⇒ Integer
Duration of the computed span.
-
#dynamic_speed ⇒ Types::RouteSpanDynamicSpeedDetails
Dynamic speed details corresponding to the span.
-
#functional_classification ⇒ Integer
A numerical value indicating the functional classification of the road segment corresponding to the span.
-
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this span.
-
#incidents ⇒ Array<Integer>
Incidents corresponding to the span.
-
#names ⇒ Array<Types::LocalizedString>
Provides an array of names of the pedestrian span in available languages.
-
#pedestrian_access ⇒ Array<String>
Access attributes for a pedestrian corresponding to the span.
-
#region ⇒ String
2-3 letter Region code corresponding to the Span.
-
#road_attributes ⇒ Array<String>
Attributes for the road segment corresponding to the span.
-
#route_numbers ⇒ Array<Types::RouteNumber>
Designated route name or number corresponding to the span.
-
#speed_limit ⇒ Types::RouteSpanSpeedLimitDetails
Speed limit details corresponding to the span.
-
#typical_duration ⇒ Integer
Duration of the computed span under typical traffic congestion.
Instance Attribute Details
#best_case_duration ⇒ Integer
Duration of the computed span without traffic congestion.
Unit: ‘seconds`
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#country ⇒ String
3 letter Country code corresponding to the Span.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#distance ⇒ Integer
Distance of the computed span. This feature doesn’t split a span, but is always computed on a span split by other properties.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#duration ⇒ Integer
Duration of the computed span. This feature doesn’t split a span, but is always computed on a span split by other properties.
Unit: ‘seconds`
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#dynamic_speed ⇒ Types::RouteSpanDynamicSpeedDetails
Dynamic speed details corresponding to the span.
Unit: ‘kilometers per hour`
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#functional_classification ⇒ Integer
A numerical value indicating the functional classification of the road segment corresponding to the span.
Classification values are part of the hierarchical network that helps determine a logical and efficient route, and have the following definitions:
-
Roads that allow for high volume, maximum speed traffic movement between and through major metropolitan areas.
-
Roads that are used to channel traffic to functional class 1 roads for travel between and through cities in the shortest amount of time.
-
Roads that intersect functional class 2 roads and provide a high volume of traffic movement at a lower level of mobility than functional class 2 roads.
-
Roads that provide for a high volume of traffic movement at moderate speeds between neighborhoods.
-
Roads with volume and traffic movement below the level of any other functional class.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this span.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#incidents ⇒ Array<Integer>
Incidents corresponding to the span. These index into the Incidents in the parent Leg.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#names ⇒ Array<Types::LocalizedString>
Provides an array of names of the pedestrian span in available languages.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#pedestrian_access ⇒ Array<String>
Access attributes for a pedestrian corresponding to the span.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#region ⇒ String
2-3 letter Region code corresponding to the Span. This is either a province or a state.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#road_attributes ⇒ Array<String>
Attributes for the road segment corresponding to the span.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#route_numbers ⇒ Array<Types::RouteNumber>
Designated route name or number corresponding to the span.
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#speed_limit ⇒ Types::RouteSpanSpeedLimitDetails
Speed limit details corresponding to the span.
Unit: ‘kilometers per hour`
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |
#typical_duration ⇒ Integer
Duration of the computed span under typical traffic congestion.
Unit: ‘seconds`
5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5153 class RoutePedestrianSpan < Struct.new( :best_case_duration, :country, :distance, :duration, :dynamic_speed, :functional_classification, :geometry_offset, :incidents, :names, :pedestrian_access, :region, :road_attributes, :route_numbers, :speed_limit, :typical_duration) SENSITIVE = [:best_case_duration, :country, :distance, :duration, :functional_classification, :pedestrian_access, :region, :road_attributes, :typical_duration] include Aws::Structure end |