Class: Aws::GeoRoutes::Types::RoutePedestrianTravelStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RoutePedestrianTravelStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Steps of a leg that must be performed during the travel portion of the leg.
Constant Summary collapse
- SENSITIVE =
[:distance, :duration, :instruction, :type]
Instance Attribute Summary collapse
-
#continue_step_details ⇒ Types::RouteContinueStepDetails
Details related to the continue step.
-
#current_road ⇒ Types::RouteRoad
Details of the current road.
-
#distance ⇒ Integer
Distance of the step.
-
#duration ⇒ Integer
Duration of the step.
-
#exit_number ⇒ Array<Types::LocalizedString>
Exit number of the road exit, if applicable.
-
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
-
#instruction ⇒ String
Brief description of the step in the requested language.
-
#keep_step_details ⇒ Types::RouteKeepStepDetails
Details that are specific to a Keep step.
-
#next_road ⇒ Types::RouteRoad
Details of the next road.
-
#roundabout_enter_step_details ⇒ Types::RouteRoundaboutEnterStepDetails
Details that are specific to a Roundabout Enter step.
-
#roundabout_exit_step_details ⇒ Types::RouteRoundaboutExitStepDetails
Details that are specific to a Roundabout Exit step.
-
#roundabout_pass_step_details ⇒ Types::RouteRoundaboutPassStepDetails
Details that are specific to a Roundabout Pass step.
-
#signpost ⇒ Types::RouteSignpost
Sign post information of the action, applicable only for TurnByTurn steps.
-
#turn_step_details ⇒ Types::RouteTurnStepDetails
Details that are specific to a turn step.
-
#type ⇒ String
Type of the step.
Instance Attribute Details
#continue_step_details ⇒ Types::RouteContinueStepDetails
Details related to the continue step.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#current_road ⇒ Types::RouteRoad
Details of the current road. See RouteRoad for details of sub-attributes.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#distance ⇒ Integer
Distance of the step.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#duration ⇒ Integer
Duration of the step.
Unit: ‘seconds`
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#exit_number ⇒ Array<Types::LocalizedString>
Exit number of the road exit, if applicable.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#instruction ⇒ String
Brief description of the step in the requested language.
<note markdown=“1”> Only available when the TravelStepType is Default.
</note>
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#keep_step_details ⇒ Types::RouteKeepStepDetails
Details that are specific to a Keep step.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#next_road ⇒ Types::RouteRoad
Details of the next road. See RouteRoad for details of sub-attributes.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_enter_step_details ⇒ Types::RouteRoundaboutEnterStepDetails
Details that are specific to a Roundabout Enter step.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_exit_step_details ⇒ Types::RouteRoundaboutExitStepDetails
Details that are specific to a Roundabout Exit step.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_pass_step_details ⇒ Types::RouteRoundaboutPassStepDetails
Details that are specific to a Roundabout Pass step.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#signpost ⇒ Types::RouteSignpost
Sign post information of the action, applicable only for TurnByTurn steps. See RouteSignpost for details of sub-attributes.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#turn_step_details ⇒ Types::RouteTurnStepDetails
Details that are specific to a turn step.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#type ⇒ String
Type of the step.
5285 5286 5287 5288 5289 5290 5291 5292 5293 5294 5295 5296 5297 5298 5299 5300 5301 5302 5303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5285 class RoutePedestrianTravelStep < Struct.new( :continue_step_details, :current_road, :distance, :duration, :exit_number, :geometry_offset, :instruction, :keep_step_details, :next_road, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |