Class: Aws::GeoRoutes::Types::RouteRentalAfterTravelStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteRentalAfterTravelStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
A step that must be performed after the travel portion of the leg.
Constant Summary collapse
- SENSITIVE =
[:duration, :instruction, :type]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
Duration of the step.
-
#instruction ⇒ String
Brief description of the step in the requested language.
-
#type ⇒ String
Type of the step.
Instance Attribute Details
#duration ⇒ Integer
Duration of the step.
Unit: ‘seconds`
5352 5353 5354 5355 5356 5357 5358 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5352 class RouteRentalAfterTravelStep < Struct.new( :duration, :instruction, :type) SENSITIVE = [:duration, :instruction, :type] include Aws::Structure end |
#instruction ⇒ String
Brief description of the step in the requested language.
5352 5353 5354 5355 5356 5357 5358 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5352 class RouteRentalAfterTravelStep < Struct.new( :duration, :instruction, :type) SENSITIVE = [:duration, :instruction, :type] include Aws::Structure end |
#type ⇒ String
Type of the step.
5352 5353 5354 5355 5356 5357 5358 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5352 class RouteRentalAfterTravelStep < Struct.new( :duration, :instruction, :type) SENSITIVE = [:duration, :instruction, :type] include Aws::Structure end |