Class: Aws::GeoRoutes::Types::RouteRentalLegDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Populated when the Leg type is Rental, and provides additional information that is specific to rental vehicle travel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#after_travel_stepsArray<Types::RouteRentalAfterTravelStep>

Steps of a leg that must be performed after the travel portion of the leg.



5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-georoutes/types.rb', line 5491

class RouteRentalLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#agencyTypes::RouteRentalAgency

Details about the rental agency.



5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-georoutes/types.rb', line 5491

class RouteRentalLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#arrivalTypes::RouteRentalArrival

Details corresponding to the arrival for the leg.



5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-georoutes/types.rb', line 5491

class RouteRentalLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#attributionsArray<Types::RouteAttribution>

List of required attributions to display.

Returns:



5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-georoutes/types.rb', line 5491

class RouteRentalLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#before_travel_stepsArray<Types::RouteRentalBeforeTravelStep>

Steps of a leg that must be performed before the travel portion of the leg.



5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-georoutes/types.rb', line 5491

class RouteRentalLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

Web links to external ticket booking services for the rental.

Returns:



5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-georoutes/types.rb', line 5491

class RouteRentalLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#departureTypes::RouteRentalDeparture

Details corresponding to the departure for the leg.



5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-georoutes/types.rb', line 5491

class RouteRentalLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#summaryTypes::RouteRentalSummary

Summary of the rental leg.



5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-georoutes/types.rb', line 5491

class RouteRentalLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#transportTypes::RouteRentalTransportModeDetails

Transport mode details for the rental leg.



5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-georoutes/types.rb', line 5491

class RouteRentalLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#travel_stepsArray<Types::RouteRentalTravelStep>

Steps of a leg that must be performed during the travel portion of the leg.

Returns:



5491
5492
5493
5494
5495
5496
5497
5498
5499
5500
5501
5502
5503
5504
# File 'lib/aws-sdk-georoutes/types.rb', line 5491

class RouteRentalLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end