Class: Aws::GeoRoutes::Types::RouteRentalSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Summary of the rental leg.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#overviewTypes::RouteRentalOverviewSummary

Summary including duration and distance for the entire leg.



5587
5588
5589
5590
5591
5592
# File 'lib/aws-sdk-georoutes/types.rb', line 5587

class RouteRentalSummary < Struct.new(
  :overview,
  :travel_only)
  SENSITIVE = []
  include Aws::Structure
end

#travel_onlyTypes::RouteRentalTravelOnlySummary

Summary including duration and distance for the travel portion of the leg only.



5587
5588
5589
5590
5591
5592
# File 'lib/aws-sdk-georoutes/types.rb', line 5587

class RouteRentalSummary < Struct.new(
  :overview,
  :travel_only)
  SENSITIVE = []
  include Aws::Structure
end