Class: Aws::GeoRoutes::Types::RouteRentalTravelOnlySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Summary including duration and distance for the travel portion of the leg only.

Constant Summary collapse

SENSITIVE =
[:duration]

Instance Attribute Summary collapse

Instance Attribute Details

#durationInteger

Duration of the travel portion of the rental leg.

Unit: ‘seconds`

Returns:

  • (Integer)


5660
5661
5662
5663
5664
# File 'lib/aws-sdk-georoutes/types.rb', line 5660

class RouteRentalTravelOnlySummary < Struct.new(
  :duration)
  SENSITIVE = [:duration]
  include Aws::Structure
end