Class: Aws::GeoRoutes::Types::RouteRentalTravelStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteRentalTravelStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
A step that must be performed during the travel portion of the leg.
Constant Summary collapse
- SENSITIVE =
[:distance, :duration, :instruction, :type]
Instance Attribute Summary collapse
-
#continue_step_details ⇒ Types::RouteContinueStepDetails
Details related to the continue step.
-
#distance ⇒ Integer
Distance of the step.
-
#duration ⇒ Integer
Duration of the step.
-
#exit_step_details ⇒ Types::RouteExitStepDetails
Details related to the exit step.
-
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
-
#instruction ⇒ String
Brief description of the step in the requested language.
-
#keep_step_details ⇒ Types::RouteKeepStepDetails
Details that are specific to a Keep step.
-
#ramp_step_details ⇒ Types::RouteRampStepDetails
Details that are specific to a ramp step.
-
#roundabout_enter_step_details ⇒ Types::RouteRoundaboutEnterStepDetails
Details about the roundabout leg.
-
#roundabout_exit_step_details ⇒ Types::RouteRoundaboutExitStepDetails
Details about the roundabout step.
-
#roundabout_pass_step_details ⇒ Types::RouteRoundaboutPassStepDetails
Details about the step.
-
#turn_step_details ⇒ Types::RouteTurnStepDetails
Details related to the turn step.
-
#type ⇒ String
Type of the step.
-
#u_turn_step_details ⇒ Types::RouteUTurnStepDetails
Details related to the U-turn step.
Instance Attribute Details
#continue_step_details ⇒ Types::RouteContinueStepDetails
Details related to the continue step.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#distance ⇒ Integer
Distance of the step.
Unit: ‘meters`
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#duration ⇒ Integer
Duration of the step.
Unit: ‘seconds`
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#exit_step_details ⇒ Types::RouteExitStepDetails
Details related to the exit step.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#instruction ⇒ String
Brief description of the step in the requested language.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#keep_step_details ⇒ Types::RouteKeepStepDetails
Details that are specific to a Keep step.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#ramp_step_details ⇒ Types::RouteRampStepDetails
Details that are specific to a ramp step.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_enter_step_details ⇒ Types::RouteRoundaboutEnterStepDetails
Details about the roundabout leg.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_exit_step_details ⇒ Types::RouteRoundaboutExitStepDetails
Details about the roundabout step.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_pass_step_details ⇒ Types::RouteRoundaboutPassStepDetails
Details about the step.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#turn_step_details ⇒ Types::RouteTurnStepDetails
Details related to the turn step.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#type ⇒ String
Type of the step.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#u_turn_step_details ⇒ Types::RouteUTurnStepDetails
Details related to the U-turn step.
5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5730 class RouteRentalTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |