Class: Aws::GeoRoutes::Types::RouteResponseNotice
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteResponseNotice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Notices are additional information returned that indicate issues that occurred during route calculation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
Code corresponding to the issue.
-
#impact ⇒ String
Impact corresponding to the issue.
Instance Attribute Details
#code ⇒ String
Code corresponding to the issue.
5764 5765 5766 5767 5768 5769 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5764 class RouteResponseNotice < Struct.new( :code, :impact) SENSITIVE = [] include Aws::Structure end |
#impact ⇒ String
Impact corresponding to the issue. While Low impact notices can be safely ignored, High impact notices must be evaluated further to determine the impact.
5764 5765 5766 5767 5768 5769 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5764 class RouteResponseNotice < Struct.new( :code, :impact) SENSITIVE = [] include Aws::Structure end |