Class: Aws::GeoRoutes::Types::RouteSideOfStreetOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Options to configure matching the provided position to a side of the street.

Constant Summary collapse

SENSITIVE =
[:position]

Instance Attribute Summary collapse

Instance Attribute Details

#positionArray<Float>

Position in World Geodetic System (WGS 84) format: [longitude, latitude].

Returns:

  • (Array<Float>)


5038
5039
5040
5041
5042
5043
# File 'lib/aws-sdk-georoutes/types.rb', line 5038

class RouteSideOfStreetOptions < Struct.new(
  :position,
  :use_with)
  SENSITIVE = [:position]
  include Aws::Structure
end

#use_withString

Strategy that defines when the side of street position should be used.

Default value: ‘DividedStreetOnly`

Returns:

  • (String)


5038
5039
5040
5041
5042
5043
# File 'lib/aws-sdk-georoutes/types.rb', line 5038

class RouteSideOfStreetOptions < Struct.new(
  :position,
  :use_with)
  SENSITIVE = [:position]
  include Aws::Structure
end