Class: Aws::GeoRoutes::Types::RouteSpanDynamicSpeedDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteSpanDynamicSpeedDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Details about the dynamic speed.
Unit: ‘kilometers per hour`
Constant Summary collapse
- SENSITIVE =
[:best_case_speed, :turn_duration, :typical_speed]
Instance Attribute Summary collapse
-
#best_case_speed ⇒ Float
Estimated speed while traversing the span without traffic congestion.
-
#turn_duration ⇒ Integer
Estimated time to turn from this span into the next.
-
#typical_speed ⇒ Float
Estimated speed while traversing the span under typical traffic congestion.
Instance Attribute Details
#best_case_speed ⇒ Float
Estimated speed while traversing the span without traffic congestion.
Unit: ‘kilometers per hour`
6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6027 class RouteSpanDynamicSpeedDetails < Struct.new( :best_case_speed, :turn_duration, :typical_speed) SENSITIVE = [:best_case_speed, :turn_duration, :typical_speed] include Aws::Structure end |
#turn_duration ⇒ Integer
Estimated time to turn from this span into the next.
Unit: ‘seconds`
6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6027 class RouteSpanDynamicSpeedDetails < Struct.new( :best_case_speed, :turn_duration, :typical_speed) SENSITIVE = [:best_case_speed, :turn_duration, :typical_speed] include Aws::Structure end |
#typical_speed ⇒ Float
Estimated speed while traversing the span under typical traffic congestion.
Unit: ‘kilometers per hour`
6027 6028 6029 6030 6031 6032 6033 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6027 class RouteSpanDynamicSpeedDetails < Struct.new( :best_case_speed, :turn_duration, :typical_speed) SENSITIVE = [:best_case_speed, :turn_duration, :typical_speed] include Aws::Structure end |