Class: Aws::GeoRoutes::Types::RouteStationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteStationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Details about the station.
Constant Summary collapse
- SENSITIVE =
[:platform_name, :short_name]
Instance Attribute Summary collapse
-
#accessibility ⇒ Types::RouteAccessibilityAvailabilityDetails
Wheelchair accessibility information for the station.
-
#platform_name ⇒ String
Platform name or number.
-
#short_name ⇒ String
Short text or a number that identifies the station.
Instance Attribute Details
#accessibility ⇒ Types::RouteAccessibilityAvailabilityDetails
Wheelchair accessibility information for the station.
6074 6075 6076 6077 6078 6079 6080 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6074 class RouteStationDetails < Struct.new( :accessibility, :platform_name, :short_name) SENSITIVE = [:platform_name, :short_name] include Aws::Structure end |
#platform_name ⇒ String
Platform name or number.
6074 6075 6076 6077 6078 6079 6080 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6074 class RouteStationDetails < Struct.new( :accessibility, :platform_name, :short_name) SENSITIVE = [:platform_name, :short_name] include Aws::Structure end |
#short_name ⇒ String
Short text or a number that identifies the station.
6074 6075 6076 6077 6078 6079 6080 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6074 class RouteStationDetails < Struct.new( :accessibility, :platform_name, :short_name) SENSITIVE = [:platform_name, :short_name] include Aws::Structure end |