Class: Aws::GeoRoutes::Types::RouteSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Summarized details for the leg including travel steps only. The Distance for the travel only portion of the journey is the same as the Distance within the Overview summary.
Constant Summary collapse
- SENSITIVE =
[:distance, :duration]
Instance Attribute Summary collapse
-
#distance ⇒ Integer
Distance of the route.
-
#duration ⇒ Integer
Duration of the route.
-
#tolls ⇒ Types::RouteTollSummary
Toll summary for the complete route.
Instance Attribute Details
#distance ⇒ Integer
Distance of the route.
6102 6103 6104 6105 6106 6107 6108 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6102 class RouteSummary < Struct.new( :distance, :duration, :tolls) SENSITIVE = [:distance, :duration] include Aws::Structure end |
#duration ⇒ Integer
Duration of the route.
Unit: ‘seconds`
6102 6103 6104 6105 6106 6107 6108 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6102 class RouteSummary < Struct.new( :distance, :duration, :tolls) SENSITIVE = [:distance, :duration] include Aws::Structure end |
#tolls ⇒ Types::RouteTollSummary
Toll summary for the complete route.
6102 6103 6104 6105 6106 6107 6108 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6102 class RouteSummary < Struct.new( :distance, :duration, :tolls) SENSITIVE = [:distance, :duration] include Aws::Structure end |