Class: Aws::GeoRoutes::Types::RouteTaxiAfterTravelStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTaxiAfterTravelStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
A step that must be performed after the travel portion of the leg.
Constant Summary collapse
- SENSITIVE =
[:duration, :instruction, :type]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
Duration of the step.
-
#instruction ⇒ String
Brief description of the step in the requested language.
-
#type ⇒ String
Type of the step.
Instance Attribute Details
#duration ⇒ Integer
Duration of the step.
Unit: ‘seconds`
6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6128 class RouteTaxiAfterTravelStep < Struct.new( :duration, :instruction, :type) SENSITIVE = [:duration, :instruction, :type] include Aws::Structure end |
#instruction ⇒ String
Brief description of the step in the requested language.
6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6128 class RouteTaxiAfterTravelStep < Struct.new( :duration, :instruction, :type) SENSITIVE = [:duration, :instruction, :type] include Aws::Structure end |
#type ⇒ String
Type of the step.
6128 6129 6130 6131 6132 6133 6134 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6128 class RouteTaxiAfterTravelStep < Struct.new( :duration, :instruction, :type) SENSITIVE = [:duration, :instruction, :type] include Aws::Structure end |