Class: Aws::GeoRoutes::Types::RouteTaxiLegDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Populated when the Leg type is Taxi, and provides additional information that is specific to taxi travel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#after_travel_stepsArray<Types::RouteTaxiAfterTravelStep>

Steps of a leg that must be performed after the travel portion of the leg.



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#agencyTypes::RouteTaxiAgency

Details about the taxi agency.



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#arrivalTypes::RouteTaxiArrival

Details corresponding to the arrival for the leg.



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#attributionsArray<Types::RouteAttribution>

List of required attributions to display.

Returns:



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#before_travel_stepsArray<Types::RouteTaxiBeforeTravelStep>

Steps of a leg that must be performed before the travel portion of the leg.



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

Web links to external ticket booking services for the taxi.

Returns:



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#departureTypes::RouteTaxiDeparture

Details corresponding to the departure for the leg.



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#noticesArray<Types::RouteTaxiNotice>

List of notices that indicate issues that occurred during route calculation.

Returns:



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#summaryTypes::RouteTaxiSummary

Summary of the taxi leg.



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#transportTypes::RouteTaxiTransportModeDetails

Transport mode details for the taxi leg.



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end

#travel_stepsArray<Types::RouteTaxiTravelStep>

Steps of a leg that must be performed during the travel portion of the leg.

Returns:



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
6284
6285
6286
# File 'lib/aws-sdk-georoutes/types.rb', line 6272

class RouteTaxiLegDetails < Struct.new(
  :after_travel_steps,
  :agency,
  :arrival,
  :attributions,
  :before_travel_steps,
  :booking_web_links,
  :departure,
  :notices,
  :summary,
  :transport,
  :travel_steps)
  SENSITIVE = []
  include Aws::Structure
end