Class: Aws::GeoRoutes::Types::RouteTaxiNotice

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

A notice that indicates an issue that occurred during route calculation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

Code corresponding to the issue.

Returns:

  • (String)


6303
6304
6305
6306
6307
6308
# File 'lib/aws-sdk-georoutes/types.rb', line 6303

class RouteTaxiNotice < Struct.new(
  :code,
  :impact)
  SENSITIVE = []
  include Aws::Structure
end

#impactString

Impact corresponding to the issue. While Low impact notices can be safely ignored, High impact notices must be evaluated further to determine the impact.

Returns:

  • (String)


6303
6304
6305
6306
6307
6308
# File 'lib/aws-sdk-georoutes/types.rb', line 6303

class RouteTaxiNotice < Struct.new(
  :code,
  :impact)
  SENSITIVE = []
  include Aws::Structure
end