Class: Aws::GeoRoutes::Types::RouteTaxiSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Summary of the taxi leg.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#overviewTypes::RouteTaxiOverviewSummary

Summary including duration and distance for the entire leg.



6391
6392
6393
6394
6395
6396
# File 'lib/aws-sdk-georoutes/types.rb', line 6391

class RouteTaxiSummary < Struct.new(
  :overview,
  :travel_only)
  SENSITIVE = []
  include Aws::Structure
end

#travel_onlyTypes::RouteTaxiTravelOnlySummary

Summary including duration and distance for the travel portion of the leg only.



6391
6392
6393
6394
6395
6396
# File 'lib/aws-sdk-georoutes/types.rb', line 6391

class RouteTaxiSummary < Struct.new(
  :overview,
  :travel_only)
  SENSITIVE = []
  include Aws::Structure
end