Class: Aws::GeoRoutes::Types::RouteTaxiTravelOnlySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTaxiTravelOnlySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Summary including duration and distance for the travel portion of the leg only.
Constant Summary collapse
- SENSITIVE =
[:duration]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
Duration of the travel portion of the taxi leg.
Instance Attribute Details
#duration ⇒ Integer
Duration of the travel portion of the taxi leg.
Unit: ‘seconds`
6464 6465 6466 6467 6468 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6464 class RouteTaxiTravelOnlySummary < Struct.new( :duration) SENSITIVE = [:duration] include Aws::Structure end |