Class: Aws::GeoRoutes::Types::RouteTaxiTravelStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTaxiTravelStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
A step that must be performed during the travel portion of the leg.
Constant Summary collapse
- SENSITIVE =
[:distance, :duration, :instruction, :type]
Instance Attribute Summary collapse
-
#continue_step_details ⇒ Types::RouteContinueStepDetails
Details related to the continue step.
-
#distance ⇒ Integer
Distance of the step.
-
#duration ⇒ Integer
Duration of the step.
-
#exit_step_details ⇒ Types::RouteExitStepDetails
Details related to the exit step.
-
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
-
#instruction ⇒ String
Brief description of the step in the requested language.
-
#keep_step_details ⇒ Types::RouteKeepStepDetails
Details that are specific to a Keep step.
-
#ramp_step_details ⇒ Types::RouteRampStepDetails
Details that are specific to a ramp step.
-
#roundabout_enter_step_details ⇒ Types::RouteRoundaboutEnterStepDetails
Details about the roundabout leg.
-
#roundabout_exit_step_details ⇒ Types::RouteRoundaboutExitStepDetails
Details about the roundabout step.
-
#roundabout_pass_step_details ⇒ Types::RouteRoundaboutPassStepDetails
Details about the step.
-
#turn_step_details ⇒ Types::RouteTurnStepDetails
Details related to the turn step.
-
#type ⇒ String
Type of the step.
-
#u_turn_step_details ⇒ Types::RouteUTurnStepDetails
Details related to the U-turn step.
Instance Attribute Details
#continue_step_details ⇒ Types::RouteContinueStepDetails
Details related to the continue step.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#distance ⇒ Integer
Distance of the step.
Unit: ‘meters`
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#duration ⇒ Integer
Duration of the step.
Unit: ‘seconds`
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#exit_step_details ⇒ Types::RouteExitStepDetails
Details related to the exit step.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#instruction ⇒ String
Brief description of the step in the requested language.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#keep_step_details ⇒ Types::RouteKeepStepDetails
Details that are specific to a Keep step.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#ramp_step_details ⇒ Types::RouteRampStepDetails
Details that are specific to a ramp step.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_enter_step_details ⇒ Types::RouteRoundaboutEnterStepDetails
Details about the roundabout leg.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_exit_step_details ⇒ Types::RouteRoundaboutExitStepDetails
Details about the roundabout step.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_pass_step_details ⇒ Types::RouteRoundaboutPassStepDetails
Details about the step.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#turn_step_details ⇒ Types::RouteTurnStepDetails
Details related to the turn step.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#type ⇒ String
Type of the step.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#u_turn_step_details ⇒ Types::RouteUTurnStepDetails
Details related to the U-turn step.
6534 6535 6536 6537 6538 6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6534 class RouteTaxiTravelStep < Struct.new( :continue_step_details, :distance, :duration, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |