Class: Aws::GeoRoutes::Types::RouteTollOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTollOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Options related to Tolls on a route.
Constant Summary collapse
- SENSITIVE =
[:all_transponders, :all_vignettes, :vehicle_category]
Instance Attribute Summary collapse
-
#all_transponders ⇒ Boolean
Specifies if the user has valid transponder with access to all toll systems.
-
#all_vignettes ⇒ Boolean
Specifies if the user has valid vignettes with access for all toll roads.
-
#currency ⇒ String
Currency code corresponding to the price.
-
#emission_type ⇒ Types::RouteEmissionType
Emission type of the vehicle for toll cost calculation.
-
#vehicle_category ⇒ String
Vehicle category for toll cost calculation.
Instance Attribute Details
#all_transponders ⇒ Boolean
Specifies if the user has valid transponder with access to all toll systems. This impacts toll calculation, and if true the price with transponders is used.
6616 6617 6618 6619 6620 6621 6622 6623 6624 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6616 class RouteTollOptions < Struct.new( :all_transponders, :all_vignettes, :currency, :emission_type, :vehicle_category) SENSITIVE = [:all_transponders, :all_vignettes, :vehicle_category] include Aws::Structure end |
#all_vignettes ⇒ Boolean
Specifies if the user has valid vignettes with access for all toll roads. If a user has a vignette for a toll road, then toll cost for that road is omitted since no further payment is necessary.
6616 6617 6618 6619 6620 6621 6622 6623 6624 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6616 class RouteTollOptions < Struct.new( :all_transponders, :all_vignettes, :currency, :emission_type, :vehicle_category) SENSITIVE = [:all_transponders, :all_vignettes, :vehicle_category] include Aws::Structure end |
#currency ⇒ String
Currency code corresponding to the price. This is the same as Currency specified in the request.
6616 6617 6618 6619 6620 6621 6622 6623 6624 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6616 class RouteTollOptions < Struct.new( :all_transponders, :all_vignettes, :currency, :emission_type, :vehicle_category) SENSITIVE = [:all_transponders, :all_vignettes, :vehicle_category] include Aws::Structure end |
#emission_type ⇒ Types::RouteEmissionType
Emission type of the vehicle for toll cost calculation.
**Valid values**: ‘Euro1, Euro2, Euro3, Euro4, Euro5, Euro6, EuroEev`
6616 6617 6618 6619 6620 6621 6622 6623 6624 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6616 class RouteTollOptions < Struct.new( :all_transponders, :all_vignettes, :currency, :emission_type, :vehicle_category) SENSITIVE = [:all_transponders, :all_vignettes, :vehicle_category] include Aws::Structure end |
#vehicle_category ⇒ String
Vehicle category for toll cost calculation.
6616 6617 6618 6619 6620 6621 6622 6623 6624 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6616 class RouteTollOptions < Struct.new( :all_transponders, :all_vignettes, :currency, :emission_type, :vehicle_category) SENSITIVE = [:all_transponders, :all_vignettes, :vehicle_category] include Aws::Structure end |