Class: Aws::GeoRoutes::Types::RouteTrafficOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Traffic options for the route.

Constant Summary collapse

SENSITIVE =
[:flow_event_threshold_override]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_event_threshold_overrideInteger

Duration for which flow traffic is considered valid. For this period, the flow traffic is used over historical traffic data. Flow traffic refers to congestion, which changes very quickly. Duration in seconds for which flow traffic event would be considered valid. While flow traffic event is valid it will be used over the historical traffic data.

Returns:

  • (Integer)


5523
5524
5525
5526
5527
5528
# File 'lib/aws-sdk-georoutes/types.rb', line 5523

class RouteTrafficOptions < Struct.new(
  :flow_event_threshold_override,
  :usage)
  SENSITIVE = [:flow_event_threshold_override]
  include Aws::Structure
end

#usageString

Specifies how traffic data should be used when calculating routes.

Default Value: ‘UseTrafficData`

<note markdown=“1”> Traffic data usage depends on the time parameters in your route request:

* When `Usage` is set to `UseTrafficData`:

 * If `DepartNow` is set to `true`, or if you specify
   `DepartureTime` or `ArrivalTime`, then all traffic data is
   considered (including live traffic and closures).

 * If `DepartNow`, `DepartureTime`, and `ArrivalTime` are all
   unspecified, then only long-term closures are considered,
   regardless of this setting.
  • When ‘Usage` is set to `IgnoreTrafficData`, then all traffic data is ignored regardless of the time parameters in your route request.

</note>

Returns:

  • (String)


5523
5524
5525
5526
5527
5528
# File 'lib/aws-sdk-georoutes/types.rb', line 5523

class RouteTrafficOptions < Struct.new(
  :flow_event_threshold_override,
  :usage)
  SENSITIVE = [:flow_event_threshold_override]
  include Aws::Structure
end