Class: Aws::GeoRoutes::Types::RouteTransitAfterTravelStep

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

A step that must be performed after the travel portion of the leg.

Constant Summary collapse

SENSITIVE =
[:duration, :instruction, :type]

Instance Attribute Summary collapse

Instance Attribute Details

#durationInteger

Duration of the step.

Unit: ‘seconds`

Returns:

  • (Integer)


6958
6959
6960
6961
6962
6963
6964
# File 'lib/aws-sdk-georoutes/types.rb', line 6958

class RouteTransitAfterTravelStep < Struct.new(
  :duration,
  :instruction,
  :type)
  SENSITIVE = [:duration, :instruction, :type]
  include Aws::Structure
end

#instructionString

Brief description of the step in the requested language.

Returns:

  • (String)


6958
6959
6960
6961
6962
6963
6964
# File 'lib/aws-sdk-georoutes/types.rb', line 6958

class RouteTransitAfterTravelStep < Struct.new(
  :duration,
  :instruction,
  :type)
  SENSITIVE = [:duration, :instruction, :type]
  include Aws::Structure
end

#typeString

Type of the step.

Returns:

  • (String)


6958
6959
6960
6961
6962
6963
6964
# File 'lib/aws-sdk-georoutes/types.rb', line 6958

class RouteTransitAfterTravelStep < Struct.new(
  :duration,
  :instruction,
  :type)
  SENSITIVE = [:duration, :instruction, :type]
  include Aws::Structure
end