Class: Aws::GeoRoutes::Types::RouteTransitIncident

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

An incident describes disruptions on the transit route.

Constant Summary collapse

SENSITIVE =
[:description, :effect, :end_time, :start_time, :type, :url]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A human readable description of the incident.

Returns:

  • (String)


7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
# File 'lib/aws-sdk-georoutes/types.rb', line 7101

class RouteTransitIncident < Struct.new(
  :description,
  :effect,
  :end_time,
  :start_time,
  :type,
  :url)
  SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url]
  include Aws::Structure
end

#effectString

The effect of the incident on the transit service.

Returns:

  • (String)


7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
# File 'lib/aws-sdk-georoutes/types.rb', line 7101

class RouteTransitIncident < Struct.new(
  :description,
  :effect,
  :end_time,
  :start_time,
  :type,
  :url)
  SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url]
  include Aws::Structure
end

#end_timeString

The end time of the incident.

Returns:

  • (String)


7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
# File 'lib/aws-sdk-georoutes/types.rb', line 7101

class RouteTransitIncident < Struct.new(
  :description,
  :effect,
  :end_time,
  :start_time,
  :type,
  :url)
  SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url]
  include Aws::Structure
end

#start_timeString

The start time of the incident.

Returns:

  • (String)


7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
# File 'lib/aws-sdk-georoutes/types.rb', line 7101

class RouteTransitIncident < Struct.new(
  :description,
  :effect,
  :end_time,
  :start_time,
  :type,
  :url)
  SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url]
  include Aws::Structure
end

#typeString

Type of the incident.

Returns:

  • (String)


7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
# File 'lib/aws-sdk-georoutes/types.rb', line 7101

class RouteTransitIncident < Struct.new(
  :description,
  :effect,
  :end_time,
  :start_time,
  :type,
  :url)
  SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url]
  include Aws::Structure
end

#urlString

URL to the original incident published at the agency website.

Returns:

  • (String)


7101
7102
7103
7104
7105
7106
7107
7108
7109
7110
# File 'lib/aws-sdk-georoutes/types.rb', line 7101

class RouteTransitIncident < Struct.new(
  :description,
  :effect,
  :end_time,
  :start_time,
  :type,
  :url)
  SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url]
  include Aws::Structure
end