Class: Aws::GeoRoutes::Types::RouteTransitIntermediateStop

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

An intermediate stop between departure and destination of the transit route.

Constant Summary collapse

SENSITIVE =
[:attributes, :duration]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesArray<String>

Attributes of the intermediate stop.

Returns:

  • (Array<String>)


7139
7140
7141
7142
7143
7144
7145
7146
7147
# File 'lib/aws-sdk-georoutes/types.rb', line 7139

class RouteTransitIntermediateStop < Struct.new(
  :attributes,
  :departure,
  :duration,
  :geometry_offset,
  :transport)
  SENSITIVE = [:attributes, :duration]
  include Aws::Structure
end

#departureTypes::RouteTransitDeparture

Departure details for the intermediate stop.



7139
7140
7141
7142
7143
7144
7145
7146
7147
# File 'lib/aws-sdk-georoutes/types.rb', line 7139

class RouteTransitIntermediateStop < Struct.new(
  :attributes,
  :departure,
  :duration,
  :geometry_offset,
  :transport)
  SENSITIVE = [:attributes, :duration]
  include Aws::Structure
end

#durationInteger

Duration of the stop.

Unit: ‘seconds`

Returns:

  • (Integer)


7139
7140
7141
7142
7143
7144
7145
7146
7147
# File 'lib/aws-sdk-georoutes/types.rb', line 7139

class RouteTransitIntermediateStop < Struct.new(
  :attributes,
  :departure,
  :duration,
  :geometry_offset,
  :transport)
  SENSITIVE = [:attributes, :duration]
  include Aws::Structure
end

#geometry_offsetInteger

Offset in the leg geometry corresponding to the start of this stop.

Returns:

  • (Integer)


7139
7140
7141
7142
7143
7144
7145
7146
7147
# File 'lib/aws-sdk-georoutes/types.rb', line 7139

class RouteTransitIntermediateStop < Struct.new(
  :attributes,
  :departure,
  :duration,
  :geometry_offset,
  :transport)
  SENSITIVE = [:attributes, :duration]
  include Aws::Structure
end

#transportTypes::RouteTransitTransportModeDetails

Transport mode details at the intermediate stop.



7139
7140
7141
7142
7143
7144
7145
7146
7147
# File 'lib/aws-sdk-georoutes/types.rb', line 7139

class RouteTransitIntermediateStop < Struct.new(
  :attributes,
  :departure,
  :duration,
  :geometry_offset,
  :transport)
  SENSITIVE = [:attributes, :duration]
  include Aws::Structure
end