Class: Aws::GeoRoutes::Types::RouteTransitNotice
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTransitNotice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
A notice that indicates an issue that occurred during route calculation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
Code corresponding to the issue.
-
#impact ⇒ String
Impact corresponding to the issue.
Instance Attribute Details
#code ⇒ String
Code corresponding to the issue.
7298 7299 7300 7301 7302 7303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7298 class RouteTransitNotice < Struct.new( :code, :impact) SENSITIVE = [] include Aws::Structure end |
#impact ⇒ String
Impact corresponding to the issue. While Low impact notices can be safely ignored, High impact notices must be evaluated further to determine the impact.
7298 7299 7300 7301 7302 7303 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7298 class RouteTransitNotice < Struct.new( :code, :impact) SENSITIVE = [] include Aws::Structure end |