Class: Aws::GeoRoutes::Types::RouteTransitSpan

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Span computed for the requested SpanAdditionalFeatures.

Constant Summary collapse

SENSITIVE =
[:country, :distance, :duration, :region]

Instance Attribute Summary collapse

Instance Attribute Details

#countryString

3 letter Country code corresponding to the Span.

Returns:

  • (String)


7473
7474
7475
7476
7477
7478
7479
7480
7481
7482
# File 'lib/aws-sdk-georoutes/types.rb', line 7473

class RouteTransitSpan < Struct.new(
  :country,
  :distance,
  :duration,
  :geometry_offset,
  :names,
  :region)
  SENSITIVE = [:country, :distance, :duration, :region]
  include Aws::Structure
end

#distanceInteger

Distance of the computed span. This feature doesn’t split a span, but is always computed on a span split by other properties.

Unit: ‘meters`

Returns:

  • (Integer)


7473
7474
7475
7476
7477
7478
7479
7480
7481
7482
# File 'lib/aws-sdk-georoutes/types.rb', line 7473

class RouteTransitSpan < Struct.new(
  :country,
  :distance,
  :duration,
  :geometry_offset,
  :names,
  :region)
  SENSITIVE = [:country, :distance, :duration, :region]
  include Aws::Structure
end

#durationInteger

Duration of the computed span. This feature doesn’t split a span, but is always computed on a span split by other properties.

Unit: ‘seconds`

Returns:

  • (Integer)


7473
7474
7475
7476
7477
7478
7479
7480
7481
7482
# File 'lib/aws-sdk-georoutes/types.rb', line 7473

class RouteTransitSpan < Struct.new(
  :country,
  :distance,
  :duration,
  :geometry_offset,
  :names,
  :region)
  SENSITIVE = [:country, :distance, :duration, :region]
  include Aws::Structure
end

#geometry_offsetInteger

Offset in the leg geometry corresponding to the start of this span.

Returns:

  • (Integer)


7473
7474
7475
7476
7477
7478
7479
7480
7481
7482
# File 'lib/aws-sdk-georoutes/types.rb', line 7473

class RouteTransitSpan < Struct.new(
  :country,
  :distance,
  :duration,
  :geometry_offset,
  :names,
  :region)
  SENSITIVE = [:country, :distance, :duration, :region]
  include Aws::Structure
end

#namesArray<Types::LocalizedString>

Names of the transit span in available languages.

Returns:



7473
7474
7475
7476
7477
7478
7479
7480
7481
7482
# File 'lib/aws-sdk-georoutes/types.rb', line 7473

class RouteTransitSpan < Struct.new(
  :country,
  :distance,
  :duration,
  :geometry_offset,
  :names,
  :region)
  SENSITIVE = [:country, :distance, :duration, :region]
  include Aws::Structure
end

#regionString

2-3 letter Region code corresponding to the Span. This is either a province or a state.

Returns:

  • (String)


7473
7474
7475
7476
7477
7478
7479
7480
7481
7482
# File 'lib/aws-sdk-georoutes/types.rb', line 7473

class RouteTransitSpan < Struct.new(
  :country,
  :distance,
  :duration,
  :geometry_offset,
  :names,
  :region)
  SENSITIVE = [:country, :distance, :duration, :region]
  include Aws::Structure
end