Class: Aws::GeoRoutes::Types::RouteTransitTravelOnlySummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Summary including duration and distance for the travel portion of the leg only.

Constant Summary collapse

SENSITIVE =
[:duration]

Instance Attribute Summary collapse

Instance Attribute Details

#durationInteger

Duration of the travel portion of the transit leg.

Unit: ‘seconds`

Returns:

  • (Integer)


7565
7566
7567
7568
7569
# File 'lib/aws-sdk-georoutes/types.rb', line 7565

class RouteTransitTravelOnlySummary < Struct.new(
  :duration)
  SENSITIVE = [:duration]
  include Aws::Structure
end