Class: Aws::GeoRoutes::Types::RouteTransitTravelStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTransitTravelStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
A step that must be performed during the travel portion of the leg.
Constant Summary collapse
- SENSITIVE =
[:distance, :duration, :instruction, :type]
Instance Attribute Summary collapse
-
#distance ⇒ Integer
Distance of the step.
-
#duration ⇒ Integer
Duration of the step.
-
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
-
#instruction ⇒ String
Brief description of the step in the requested language.
-
#type ⇒ String
Type of the step.
Instance Attribute Details
#distance ⇒ Integer
Distance of the step.
Unit: ‘meters`
7599 7600 7601 7602 7603 7604 7605 7606 7607 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7599 class RouteTransitTravelStep < Struct.new( :distance, :duration, :geometry_offset, :instruction, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#duration ⇒ Integer
Duration of the step.
Unit: ‘seconds`
7599 7600 7601 7602 7603 7604 7605 7606 7607 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7599 class RouteTransitTravelStep < Struct.new( :distance, :duration, :geometry_offset, :instruction, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
7599 7600 7601 7602 7603 7604 7605 7606 7607 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7599 class RouteTransitTravelStep < Struct.new( :distance, :duration, :geometry_offset, :instruction, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#instruction ⇒ String
Brief description of the step in the requested language.
7599 7600 7601 7602 7603 7604 7605 7606 7607 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7599 class RouteTransitTravelStep < Struct.new( :distance, :duration, :geometry_offset, :instruction, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#type ⇒ String
Type of the step.
7599 7600 7601 7602 7603 7604 7605 7606 7607 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7599 class RouteTransitTravelStep < Struct.new( :distance, :duration, :geometry_offset, :instruction, :type) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |