Class: Aws::GeoRoutes::Types::RouteVehicleAfterTravelStep

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Steps of a leg that must be performed after the travel portion of the leg.

Constant Summary collapse

SENSITIVE =
[:duration, :instruction, :type]

Instance Attribute Summary collapse

Instance Attribute Details

#charge_step_detailsTypes::RouteChargeStepDetails

Details that are specific to a Charge step.

Unit: ‘KwH `



7936
7937
7938
7939
7940
7941
7942
7943
# File 'lib/aws-sdk-georoutes/types.rb', line 7936

class RouteVehicleAfterTravelStep < Struct.new(
  :charge_step_details,
  :duration,
  :instruction,
  :type)
  SENSITIVE = [:duration, :instruction, :type]
  include Aws::Structure
end

#durationInteger

Duration of the step.

Unit: ‘seconds`

Returns:

  • (Integer)


7936
7937
7938
7939
7940
7941
7942
7943
# File 'lib/aws-sdk-georoutes/types.rb', line 7936

class RouteVehicleAfterTravelStep < Struct.new(
  :charge_step_details,
  :duration,
  :instruction,
  :type)
  SENSITIVE = [:duration, :instruction, :type]
  include Aws::Structure
end

#instructionString

Brief description of the step in the requested language.

<note markdown=“1”> Only available when the TravelStepType is Default.

</note>

Returns:

  • (String)


7936
7937
7938
7939
7940
7941
7942
7943
# File 'lib/aws-sdk-georoutes/types.rb', line 7936

class RouteVehicleAfterTravelStep < Struct.new(
  :charge_step_details,
  :duration,
  :instruction,
  :type)
  SENSITIVE = [:duration, :instruction, :type]
  include Aws::Structure
end

#typeString

Type of the step.

Returns:

  • (String)


7936
7937
7938
7939
7940
7941
7942
7943
# File 'lib/aws-sdk-georoutes/types.rb', line 7936

class RouteVehicleAfterTravelStep < Struct.new(
  :charge_step_details,
  :duration,
  :instruction,
  :type)
  SENSITIVE = [:duration, :instruction, :type]
  include Aws::Structure
end