Class: Aws::GeoRoutes::Types::RouteVehicleLegDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Steps of a leg that correspond to the travel portion of the leg.

Constant Summary collapse

SENSITIVE =
[:truck_road_types]

Instance Attribute Summary collapse

Instance Attribute Details

#after_travel_stepsArray<Types::RouteVehicleAfterTravelStep>

Steps of a leg that must be performed after the travel portion of the leg.



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#arrivalTypes::RouteVehicleArrival

Details corresponding to the arrival for the leg.



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#departureTypes::RouteVehicleDeparture

Details corresponding to the departure for the leg.



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#incidentsArray<Types::RouteVehicleIncident>

Incidents corresponding to this leg of the route. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#noticesArray<Types::RouteVehicleNotice>

Notices are additional information returned that indicate issues that occurred during route calculation. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#pass_through_waypointsArray<Types::RoutePassThroughWaypoint>

Waypoints that were passed through during the leg. This includes the waypoints that were configured with the PassThrough option.



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#spansArray<Types::RouteVehicleSpan>

Spans that were computed for the requested SpanAdditionalFeatures. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#summaryTypes::RouteVehicleSummary

Summarized details of the leg.



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#toll_systemsArray<Types::RouteTollSystem>

Toll systems are authorities that collect payments for the toll. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#tollsArray<Types::RouteToll>

Toll related options. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#travel_stepsArray<Types::RouteVehicleTravelStep>

Steps of a leg that must be performed before the travel portion of the leg.

Returns:



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#truck_road_typesArray<String>

Truck road type identifiers. ‘BK1` through `BK4` apply only to Sweden. `A2,A4,B2,B4,C,D,ET2,ET4` apply only to Mexico. Not supported in `ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

<note markdown=“1”> There are currently no other supported values as of 26th April 2024.

</note>

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (Array<String>)


8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end

#zonesArray<Types::RouteZone>

Zones corresponding to this leg of the route. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:



8127
8128
8129
8130
8131
8132
8133
8134
8135
8136
8137
8138
8139
8140
8141
8142
8143
# File 'lib/aws-sdk-georoutes/types.rb', line 8127

class RouteVehicleLegDetails < Struct.new(
  :after_travel_steps,
  :arrival,
  :departure,
  :incidents,
  :notices,
  :pass_through_waypoints,
  :spans,
  :summary,
  :tolls,
  :toll_systems,
  :travel_steps,
  :truck_road_types,
  :zones)
  SENSITIVE = [:truck_road_types]
  include Aws::Structure
end