Class: Aws::GeoRoutes::Types::RouteVehicleNotice
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteVehicleNotice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Notices are additional information returned that indicate issues that occurred during route calculation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
Code corresponding to the issue.
-
#details ⇒ Array<Types::RouteVehicleNoticeDetail>
Additional details of the notice.
-
#impact ⇒ String
Impact corresponding to the issue.
Instance Attribute Details
#code ⇒ String
Code corresponding to the issue.
8180 8181 8182 8183 8184 8185 8186 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8180 class RouteVehicleNotice < Struct.new( :code, :details, :impact) SENSITIVE = [] include Aws::Structure end |
#details ⇒ Array<Types::RouteVehicleNoticeDetail>
Additional details of the notice.
8180 8181 8182 8183 8184 8185 8186 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8180 class RouteVehicleNotice < Struct.new( :code, :details, :impact) SENSITIVE = [] include Aws::Structure end |
#impact ⇒ String
Impact corresponding to the issue. While Low impact notices can be safely ignored, High impact notices must be evaluated further to determine the impact.
8180 8181 8182 8183 8184 8185 8186 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8180 class RouteVehicleNotice < Struct.new( :code, :details, :impact) SENSITIVE = [] include Aws::Structure end |