Class: Aws::GeoRoutes::Types::RouteVehicleOverviewSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteVehicleOverviewSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Summary including duration and distance for the entire leg.
Constant Summary collapse
- SENSITIVE =
[:best_case_duration, :distance, :duration, :typical_duration]
Instance Attribute Summary collapse
-
#best_case_duration ⇒ Integer
Total duration in free flowing traffic, which is the best case or shortest duration possible to cover the leg.
-
#distance ⇒ Integer
Distance of the entire leg.
-
#duration ⇒ Integer
Duration of the entire leg.
-
#typical_duration ⇒ Integer
Duration of the leg under typical traffic congestion.
Instance Attribute Details
#best_case_duration ⇒ Integer
Total duration in free flowing traffic, which is the best case or shortest duration possible to cover the leg.
Unit: ‘seconds`
8236 8237 8238 8239 8240 8241 8242 8243 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8236 class RouteVehicleOverviewSummary < Struct.new( :best_case_duration, :distance, :duration, :typical_duration) SENSITIVE = [:best_case_duration, :distance, :duration, :typical_duration] include Aws::Structure end |
#distance ⇒ Integer
Distance of the entire leg.
Unit: ‘meters`
8236 8237 8238 8239 8240 8241 8242 8243 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8236 class RouteVehicleOverviewSummary < Struct.new( :best_case_duration, :distance, :duration, :typical_duration) SENSITIVE = [:best_case_duration, :distance, :duration, :typical_duration] include Aws::Structure end |
#duration ⇒ Integer
Duration of the entire leg.
Unit: ‘seconds`
8236 8237 8238 8239 8240 8241 8242 8243 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8236 class RouteVehicleOverviewSummary < Struct.new( :best_case_duration, :distance, :duration, :typical_duration) SENSITIVE = [:best_case_duration, :distance, :duration, :typical_duration] include Aws::Structure end |
#typical_duration ⇒ Integer
Duration of the leg under typical traffic congestion.
Unit: ‘seconds`
8236 8237 8238 8239 8240 8241 8242 8243 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8236 class RouteVehicleOverviewSummary < Struct.new( :best_case_duration, :distance, :duration, :typical_duration) SENSITIVE = [:best_case_duration, :distance, :duration, :typical_duration] include Aws::Structure end |