Class: Aws::GeoRoutes::Types::RouteVehicleSpan
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteVehicleSpan
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Span computed for the requested SpanAdditionalFeatures.
Constant Summary collapse
- SENSITIVE =
[:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration]
Instance Attribute Summary collapse
-
#best_case_duration ⇒ Integer
Duration of the computed span without traffic congestion.
-
#car_access ⇒ Array<String>
Access attributes for a car corresponding to the span.
-
#country ⇒ String
3 letter Country code corresponding to the Span.
-
#distance ⇒ Integer
Distance of the computed span.
-
#duration ⇒ Integer
Duration of the computed span.
-
#dynamic_speed ⇒ Types::RouteSpanDynamicSpeedDetails
Dynamic speed details corresponding to the span.
-
#functional_classification ⇒ Integer
A numerical value indicating the functional classification of the road segment corresponding to the span.
-
#gate ⇒ String
Attributes corresponding to a gate.
-
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this span.
-
#incidents ⇒ Array<Integer>
Incidents corresponding to the span.
-
#names ⇒ Array<Types::LocalizedString>
Provides an array of names of the vehicle span in available languages.
-
#notices ⇒ Array<Integer>
Notices are additional information returned that indicate issues that occurred during route calculation.
-
#railway_crossing ⇒ String
Attributes corresponding to a railway crossing.
-
#region ⇒ String
2-3 letter Region code corresponding to the Span.
-
#road_attributes ⇒ Array<String>
Attributes for the road segment corresponding to the span.
-
#route_numbers ⇒ Array<Types::RouteNumber>
Designated route name or number corresponding to the span.
-
#scooter_access ⇒ Array<String>
Access attributes for a scooter corresponding to the span.
-
#speed_limit ⇒ Types::RouteSpanSpeedLimitDetails
Speed limit details corresponding to the span.
-
#toll_systems ⇒ Array<Integer>
Toll systems are authorities that collect payments for the toll.
-
#truck_access ⇒ Array<String>
Access attributes for a truck corresponding to the span.
-
#truck_road_types ⇒ Array<Integer>
Truck road type identifiers.
-
#typical_duration ⇒ Integer
Duration of the computed span under typical traffic congestion.
-
#zones ⇒ Array<Integer>
Zones corresponding to this leg of the route.
Instance Attribute Details
#best_case_duration ⇒ Integer
Duration of the computed span without traffic congestion.
Unit: ‘seconds`
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#car_access ⇒ Array<String>
Access attributes for a car corresponding to the span.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#country ⇒ String
3 letter Country code corresponding to the Span.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#distance ⇒ Integer
Distance of the computed span. This feature doesn’t split a span, but is always computed on a span split by other properties.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#duration ⇒ Integer
Duration of the computed span. This feature doesn’t split a span, but is always computed on a span split by other properties.
Unit: ‘seconds`
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#dynamic_speed ⇒ Types::RouteSpanDynamicSpeedDetails
Dynamic speed details corresponding to the span.
Unit: ‘kilometers per hour`
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#functional_classification ⇒ Integer
A numerical value indicating the functional classification of the road segment corresponding to the span.
Classification values are part of the hierarchical network that helps determine a logical and efficient route, and have the following definitions:
-
Roads that allow for high volume, maximum speed traffic movement between and through major metropolitan areas.
-
Roads that are used to channel traffic to functional class 1 roads for travel between and through cities in the shortest amount of time.
-
Roads that intersect functional class 2 roads and provide a high volume of traffic movement at a lower level of mobility than functional class 2 roads.
-
Roads that provide for a high volume of traffic movement at moderate speeds between neighborhoods.
-
Roads with volume and traffic movement below the level of any other functional class.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#gate ⇒ String
Attributes corresponding to a gate. The gate is present at the end of the returned span.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this span.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#incidents ⇒ Array<Integer>
Incidents corresponding to the span. These index into the Incidents in the parent Leg.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#names ⇒ Array<Types::LocalizedString>
Provides an array of names of the vehicle span in available languages.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#notices ⇒ Array<Integer>
Notices are additional information returned that indicate issues that occurred during route calculation.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#railway_crossing ⇒ String
Attributes corresponding to a railway crossing. The gate is present at the end of the returned span.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#region ⇒ String
2-3 letter Region code corresponding to the Span. This is either a province or a state.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#road_attributes ⇒ Array<String>
Attributes for the road segment corresponding to the span.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#route_numbers ⇒ Array<Types::RouteNumber>
Designated route name or number corresponding to the span.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#scooter_access ⇒ Array<String>
Access attributes for a scooter corresponding to the span.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#speed_limit ⇒ Types::RouteSpanSpeedLimitDetails
Speed limit details corresponding to the span.
Unit: ‘kilometers per hour`
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#toll_systems ⇒ Array<Integer>
Toll systems are authorities that collect payments for the toll.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#truck_access ⇒ Array<String>
Access attributes for a truck corresponding to the span.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#truck_road_types ⇒ Array<Integer>
Truck road type identifiers. ‘BK1` through `BK4` apply only to Sweden. `A2,A4,B2,B4,C,D,ET2,ET4` apply only to Mexico.
<note markdown=“1”> There are currently no other supported values as of 26th April 2024.
</note>
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#typical_duration ⇒ Integer
Duration of the computed span under typical traffic congestion.
Unit: ‘seconds`
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |
#zones ⇒ Array<Integer>
Zones corresponding to this leg of the route.
8437 8438 8439 8440 8441 8442 8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 8454 8455 8456 8457 8458 8459 8460 8461 8462 8463 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8437 class RouteVehicleSpan < Struct.new( :best_case_duration, :car_access, :country, :distance, :duration, :dynamic_speed, :functional_classification, :gate, :geometry_offset, :incidents, :names, :notices, :railway_crossing, :region, :road_attributes, :route_numbers, :scooter_access, :speed_limit, :toll_systems, :truck_access, :truck_road_types, :typical_duration, :zones) SENSITIVE = [:best_case_duration, :car_access, :country, :distance, :duration, :functional_classification, :gate, :railway_crossing, :region, :road_attributes, :scooter_access, :truck_access, :typical_duration] include Aws::Structure end |