Class: Aws::GeoRoutes::Types::RouteVehicleTravelStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteVehicleTravelStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Steps of a leg that correspond to the travel portion of the leg.
Constant Summary collapse
- SENSITIVE =
[:distance, :duration, :instruction, :type]
Instance Attribute Summary collapse
-
#continue_highway_step_details ⇒ Types::RouteContinueHighwayStepDetails
Details that are specific to a Continue Highway step.
-
#continue_step_details ⇒ Types::RouteContinueStepDetails
Details that are specific to a Continue step.
-
#current_road ⇒ Types::RouteRoad
Details of the current road.
-
#distance ⇒ Integer
Distance of the step.
-
#duration ⇒ Integer
Duration of the step.
-
#enter_highway_step_details ⇒ Types::RouteEnterHighwayStepDetails
Details that are specific to a Enter Highway step.
-
#exit_number ⇒ Array<Types::LocalizedString>
Exit number of the road exit, if applicable.
-
#exit_step_details ⇒ Types::RouteExitStepDetails
Details that are specific to a Roundabout Exit step.
-
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
-
#instruction ⇒ String
Brief description of the step in the requested language.
-
#keep_step_details ⇒ Types::RouteKeepStepDetails
Details that are specific to a Keep step.
-
#next_road ⇒ Types::RouteRoad
Details of the next road.
-
#ramp_step_details ⇒ Types::RouteRampStepDetails
Details that are specific to a Ramp step.
-
#roundabout_enter_step_details ⇒ Types::RouteRoundaboutEnterStepDetails
Details that are specific to a Roundabout Enter step.
-
#roundabout_exit_step_details ⇒ Types::RouteRoundaboutExitStepDetails
Details that are specific to a Roundabout Exit step.
-
#roundabout_pass_step_details ⇒ Types::RouteRoundaboutPassStepDetails
Details that are specific to a Roundabout Pass step.
-
#signpost ⇒ Types::RouteSignpost
Sign post information of the action, applicable only for TurnByTurn steps.
-
#turn_step_details ⇒ Types::RouteTurnStepDetails
Details that are specific to a Turn step.
-
#type ⇒ String
Type of the step.
-
#u_turn_step_details ⇒ Types::RouteUTurnStepDetails
Details that are specific to a Turn step.
Instance Attribute Details
#continue_highway_step_details ⇒ Types::RouteContinueHighwayStepDetails
Details that are specific to a Continue Highway step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#continue_step_details ⇒ Types::RouteContinueStepDetails
Details that are specific to a Continue step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#current_road ⇒ Types::RouteRoad
Details of the current road.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#distance ⇒ Integer
Distance of the step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#duration ⇒ Integer
Duration of the step.
Unit: ‘seconds`
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#enter_highway_step_details ⇒ Types::RouteEnterHighwayStepDetails
Details that are specific to a Enter Highway step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#exit_number ⇒ Array<Types::LocalizedString>
Exit number of the road exit, if applicable.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#exit_step_details ⇒ Types::RouteExitStepDetails
Details that are specific to a Roundabout Exit step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#instruction ⇒ String
Brief description of the step in the requested language.
<note markdown=“1”> Only available when the TravelStepType is Default.
</note>
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#keep_step_details ⇒ Types::RouteKeepStepDetails
Details that are specific to a Keep step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#next_road ⇒ Types::RouteRoad
Details of the next road. See RouteRoad for details of sub-attributes.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#ramp_step_details ⇒ Types::RouteRampStepDetails
Details that are specific to a Ramp step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_enter_step_details ⇒ Types::RouteRoundaboutEnterStepDetails
Details that are specific to a Roundabout Enter step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_exit_step_details ⇒ Types::RouteRoundaboutExitStepDetails
Details that are specific to a Roundabout Exit step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#roundabout_pass_step_details ⇒ Types::RouteRoundaboutPassStepDetails
Details that are specific to a Roundabout Pass step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#signpost ⇒ Types::RouteSignpost
Sign post information of the action, applicable only for TurnByTurn steps. See RouteSignpost for details of sub-attributes.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#turn_step_details ⇒ Types::RouteTurnStepDetails
Details that are specific to a Turn step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#type ⇒ String
Type of the step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |
#u_turn_step_details ⇒ Types::RouteUTurnStepDetails
Details that are specific to a Turn step.
8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 |
# File 'lib/aws-sdk-georoutes/types.rb', line 8609 class RouteVehicleTravelStep < Struct.new( :continue_highway_step_details, :continue_step_details, :current_road, :distance, :duration, :enter_highway_step_details, :exit_number, :exit_step_details, :geometry_offset, :instruction, :keep_step_details, :next_road, :ramp_step_details, :roundabout_enter_step_details, :roundabout_exit_step_details, :roundabout_pass_step_details, :signpost, :turn_step_details, :type, :u_turn_step_details) SENSITIVE = [:distance, :duration, :instruction, :type] include Aws::Structure end |