Class: Aws::GeoRoutes::Types::RouteWaypoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Waypoint between the Origin and Destination.

Constant Summary collapse

SENSITIVE =
[:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration]

Instance Attribute Summary collapse

Instance Attribute Details

#avoid_actions_for_distanceInteger

Avoids actions for the provided distance. This is typically to consider for users in moving vehicles who may not have sufficient time to make an action at an origin or a destination. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (Integer)


8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
# File 'lib/aws-sdk-georoutes/types.rb', line 8868

class RouteWaypoint < Struct.new(
  :avoid_actions_for_distance,
  :avoid_u_turns,
  :heading,
  :matching,
  :pass_through,
  :position,
  :side_of_street,
  :stop_duration)
  SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration]
  include Aws::Structure
end

#avoid_u_turnsBoolean

Avoid U-turns for calculation on highways and motorways. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for

GrabMaps][1

customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (Boolean)


8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
# File 'lib/aws-sdk-georoutes/types.rb', line 8868

class RouteWaypoint < Struct.new(
  :avoid_actions_for_distance,
  :avoid_u_turns,
  :heading,
  :matching,
  :pass_through,
  :position,
  :side_of_street,
  :stop_duration)
  SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration]
  include Aws::Structure
end

#headingFloat

GPS Heading at the position. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (Float)


8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
# File 'lib/aws-sdk-georoutes/types.rb', line 8868

class RouteWaypoint < Struct.new(
  :avoid_actions_for_distance,
  :avoid_u_turns,
  :heading,
  :matching,
  :pass_through,
  :position,
  :side_of_street,
  :stop_duration)
  SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration]
  include Aws::Structure
end

#matchingTypes::RouteMatchingOptions

Options to configure matching the provided position to the road network. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
# File 'lib/aws-sdk-georoutes/types.rb', line 8868

class RouteWaypoint < Struct.new(
  :avoid_actions_for_distance,
  :avoid_u_turns,
  :heading,
  :matching,
  :pass_through,
  :position,
  :side_of_street,
  :stop_duration)
  SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration]
  include Aws::Structure
end

#pass_throughBoolean

If the waypoint should not be treated as a stop. If yes, the waypoint is passed through and doesn’t split the route into different legs. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (Boolean)


8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
# File 'lib/aws-sdk-georoutes/types.rb', line 8868

class RouteWaypoint < Struct.new(
  :avoid_actions_for_distance,
  :avoid_u_turns,
  :heading,
  :matching,
  :pass_through,
  :position,
  :side_of_street,
  :stop_duration)
  SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration]
  include Aws::Structure
end

#positionArray<Float>

Position in World Geodetic System (WGS 84) format: [longitude, latitude].

Returns:

  • (Array<Float>)


8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
# File 'lib/aws-sdk-georoutes/types.rb', line 8868

class RouteWaypoint < Struct.new(
  :avoid_actions_for_distance,
  :avoid_u_turns,
  :heading,
  :matching,
  :pass_through,
  :position,
  :side_of_street,
  :stop_duration)
  SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration]
  include Aws::Structure
end

#side_of_streetTypes::RouteSideOfStreetOptions

Options to configure matching the provided position to a side of the street. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html



8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
# File 'lib/aws-sdk-georoutes/types.rb', line 8868

class RouteWaypoint < Struct.new(
  :avoid_actions_for_distance,
  :avoid_u_turns,
  :heading,
  :matching,
  :pass_through,
  :position,
  :side_of_street,
  :stop_duration)
  SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration]
  include Aws::Structure
end

#stop_durationInteger

Duration of the stop. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.

Unit: ‘seconds`

[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html

Returns:

  • (Integer)


8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
# File 'lib/aws-sdk-georoutes/types.rb', line 8868

class RouteWaypoint < Struct.new(
  :avoid_actions_for_distance,
  :avoid_u_turns,
  :heading,
  :matching,
  :pass_through,
  :position,
  :side_of_street,
  :stop_duration)
  SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration]
  include Aws::Structure
end