Class: Aws::GeoRoutes::Types::WaypointOptimizationDestinationOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Destination related options.

Constant Summary collapse

SENSITIVE =
[:appointment_time, :heading, :service_duration]

Instance Attribute Summary collapse

Instance Attribute Details

#access_hoursTypes::WaypointOptimizationAccessHours

Access hours corresponding to when a waypoint can be visited.



9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
# File 'lib/aws-sdk-georoutes/types.rb', line 9315

class WaypointOptimizationDestinationOptions < Struct.new(
  :access_hours,
  :appointment_time,
  :heading,
  :id,
  :service_duration,
  :side_of_street)
  SENSITIVE = [:appointment_time, :heading, :service_duration]
  include Aws::Structure
end

#appointment_timeString

Appointment time at the destination.

Returns:

  • (String)


9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
# File 'lib/aws-sdk-georoutes/types.rb', line 9315

class WaypointOptimizationDestinationOptions < Struct.new(
  :access_hours,
  :appointment_time,
  :heading,
  :id,
  :service_duration,
  :side_of_street)
  SENSITIVE = [:appointment_time, :heading, :service_duration]
  include Aws::Structure
end

#headingFloat

GPS Heading at the position.

Returns:

  • (Float)


9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
# File 'lib/aws-sdk-georoutes/types.rb', line 9315

class WaypointOptimizationDestinationOptions < Struct.new(
  :access_hours,
  :appointment_time,
  :heading,
  :id,
  :service_duration,
  :side_of_street)
  SENSITIVE = [:appointment_time, :heading, :service_duration]
  include Aws::Structure
end

#idString

The waypoint Id.

Returns:

  • (String)


9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
# File 'lib/aws-sdk-georoutes/types.rb', line 9315

class WaypointOptimizationDestinationOptions < Struct.new(
  :access_hours,
  :appointment_time,
  :heading,
  :id,
  :service_duration,
  :side_of_street)
  SENSITIVE = [:appointment_time, :heading, :service_duration]
  include Aws::Structure
end

#service_durationInteger

Service time spent at the destination. At an appointment, the service time should be the appointment duration.

Unit: ‘seconds`

Returns:

  • (Integer)


9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
# File 'lib/aws-sdk-georoutes/types.rb', line 9315

class WaypointOptimizationDestinationOptions < Struct.new(
  :access_hours,
  :appointment_time,
  :heading,
  :id,
  :service_duration,
  :side_of_street)
  SENSITIVE = [:appointment_time, :heading, :service_duration]
  include Aws::Structure
end

#side_of_streetTypes::WaypointOptimizationSideOfStreetOptions

Options to configure matching the provided position to a side of the street.



9315
9316
9317
9318
9319
9320
9321
9322
9323
9324
# File 'lib/aws-sdk-georoutes/types.rb', line 9315

class WaypointOptimizationDestinationOptions < Struct.new(
  :access_hours,
  :appointment_time,
  :heading,
  :id,
  :service_duration,
  :side_of_street)
  SENSITIVE = [:appointment_time, :heading, :service_duration]
  include Aws::Structure
end