Class: Aws::GeoRoutes::Types::WaypointOptimizationDriverOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Driver related options.

Constant Summary collapse

SENSITIVE =
[:treat_service_time_as]

Instance Attribute Summary collapse

Instance Attribute Details

#rest_cyclesTypes::WaypointOptimizationRestCycles

Driver work-rest schedules defined by a short and long cycle. A rest needs to be taken after the short work duration. The short cycle can be repeated until you hit the long work duration, at which point the long rest duration should be taken before restarting.



9348
9349
9350
9351
9352
9353
9354
# File 'lib/aws-sdk-georoutes/types.rb', line 9348

class WaypointOptimizationDriverOptions < Struct.new(
  :rest_cycles,
  :rest_profile,
  :treat_service_time_as)
  SENSITIVE = [:treat_service_time_as]
  include Aws::Structure
end

#rest_profileTypes::WaypointOptimizationRestProfile

Pre defined rest profiles for a driver schedule. The only currently supported profile is EU.



9348
9349
9350
9351
9352
9353
9354
# File 'lib/aws-sdk-georoutes/types.rb', line 9348

class WaypointOptimizationDriverOptions < Struct.new(
  :rest_cycles,
  :rest_profile,
  :treat_service_time_as)
  SENSITIVE = [:treat_service_time_as]
  include Aws::Structure
end

#treat_service_time_asString

If the service time provided at a waypoint/destination should be considered as rest or work. This contributes to the total time breakdown returned within the response.

Returns:

  • (String)


9348
9349
9350
9351
9352
9353
9354
# File 'lib/aws-sdk-georoutes/types.rb', line 9348

class WaypointOptimizationDriverOptions < Struct.new(
  :rest_cycles,
  :rest_profile,
  :treat_service_time_as)
  SENSITIVE = [:treat_service_time_as]
  include Aws::Structure
end