Class: Aws::GeoRoutes::Types::WaypointOptimizationDrivingDistanceOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::WaypointOptimizationDrivingDistanceOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Driving distance related options.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#driving_distance ⇒ Integer
DrivingDistance assigns all the waypoints that are within driving distance of each other into a single cluster.
Instance Attribute Details
#driving_distance ⇒ Integer
DrivingDistance assigns all the waypoints that are within driving distance of each other into a single cluster.
9365 9366 9367 9368 9369 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9365 class WaypointOptimizationDrivingDistanceOptions < Struct.new( :driving_distance) SENSITIVE = [] include Aws::Structure end |