Class: Aws::GeoRoutes::Types::WaypointOptimizationOptimizedWaypoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

The optimized waypoint.

Constant Summary collapse

SENSITIVE =
[:arrival_time, :departure_time, :position]

Instance Attribute Summary collapse

Instance Attribute Details

#arrival_timeString

Estimated time of arrival at the destination.

Time format:‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`

Examples:

‘2020-04-22T17:57:24Z`

‘2020-04-22T17:57:24+02:00`

Returns:

  • (String)


9477
9478
9479
9480
9481
9482
9483
9484
9485
# File 'lib/aws-sdk-georoutes/types.rb', line 9477

class WaypointOptimizationOptimizedWaypoint < Struct.new(
  :arrival_time,
  :cluster_index,
  :departure_time,
  :id,
  :position)
  SENSITIVE = [:arrival_time, :departure_time, :position]
  include Aws::Structure
end

#cluster_indexInteger

Index of the cluster the waypoint is associated with. The index is included in the response only if clustering was performed while processing the request.

Returns:

  • (Integer)


9477
9478
9479
9480
9481
9482
9483
9484
9485
# File 'lib/aws-sdk-georoutes/types.rb', line 9477

class WaypointOptimizationOptimizedWaypoint < Struct.new(
  :arrival_time,
  :cluster_index,
  :departure_time,
  :id,
  :position)
  SENSITIVE = [:arrival_time, :departure_time, :position]
  include Aws::Structure
end

#departure_timeString

Estimated time of departure from the origin.

Time format:‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`

Examples:

‘2020-04-22T17:57:24Z`

‘2020-04-22T17:57:24+02:00`

Returns:

  • (String)


9477
9478
9479
9480
9481
9482
9483
9484
9485
# File 'lib/aws-sdk-georoutes/types.rb', line 9477

class WaypointOptimizationOptimizedWaypoint < Struct.new(
  :arrival_time,
  :cluster_index,
  :departure_time,
  :id,
  :position)
  SENSITIVE = [:arrival_time, :departure_time, :position]
  include Aws::Structure
end

#idString

The waypoint Id.

Returns:

  • (String)


9477
9478
9479
9480
9481
9482
9483
9484
9485
# File 'lib/aws-sdk-georoutes/types.rb', line 9477

class WaypointOptimizationOptimizedWaypoint < Struct.new(
  :arrival_time,
  :cluster_index,
  :departure_time,
  :id,
  :position)
  SENSITIVE = [:arrival_time, :departure_time, :position]
  include Aws::Structure
end

#positionArray<Float>

Position in World Geodetic System (WGS 84) format: [longitude, latitude].

Returns:

  • (Array<Float>)


9477
9478
9479
9480
9481
9482
9483
9484
9485
# File 'lib/aws-sdk-georoutes/types.rb', line 9477

class WaypointOptimizationOptimizedWaypoint < Struct.new(
  :arrival_time,
  :cluster_index,
  :departure_time,
  :id,
  :position)
  SENSITIVE = [:arrival_time, :departure_time, :position]
  include Aws::Structure
end