Class: Aws::GeoRoutes::Types::WaypointOptimizationRestCycleDurations
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::WaypointOptimizationRestCycleDurations
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Driver work-rest schedules defined by a short and long cycle. A rest needs to be taken after the short work duration. The short cycle can be repeated until you hit the long work duration, at which point the long rest duration should be taken before restarting.
Unit: ‘seconds`
Constant Summary collapse
- SENSITIVE =
[:rest_duration, :work_duration]
Instance Attribute Summary collapse
-
#rest_duration ⇒ Integer
Resting phase of the cycle.
-
#work_duration ⇒ Integer
Working phase of the cycle.
Instance Attribute Details
#rest_duration ⇒ Integer
Resting phase of the cycle.
Unit: ‘seconds`
9538 9539 9540 9541 9542 9543 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9538 class WaypointOptimizationRestCycleDurations < Struct.new( :rest_duration, :work_duration) SENSITIVE = [:rest_duration, :work_duration] include Aws::Structure end |
#work_duration ⇒ Integer
Working phase of the cycle.
Unit: ‘seconds`
9538 9539 9540 9541 9542 9543 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9538 class WaypointOptimizationRestCycleDurations < Struct.new( :rest_duration, :work_duration) SENSITIVE = [:rest_duration, :work_duration] include Aws::Structure end |