Class: Aws::GeoRoutes::Types::WaypointOptimizationTruckOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Travel mode options when the provided travel mode is ‘Truck`.

Constant Summary collapse

SENSITIVE =
[:gross_weight, :hazardous_cargos, :height, :length, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]

Instance Attribute Summary collapse

Instance Attribute Details

#gross_weightInteger

Gross weight of the vehicle including trailers, and goods at capacity.

Unit: ‘kilograms`

Returns:

  • (Integer)


9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-georoutes/types.rb', line 9774

class WaypointOptimizationTruckOptions < Struct.new(
  :gross_weight,
  :hazardous_cargos,
  :height,
  :length,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :width)
  SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#hazardous_cargosArray<String>

List of Hazardous cargo contained in the vehicle.

Returns:

  • (Array<String>)


9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-georoutes/types.rb', line 9774

class WaypointOptimizationTruckOptions < Struct.new(
  :gross_weight,
  :hazardous_cargos,
  :height,
  :length,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :width)
  SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#heightInteger

Height of the vehicle.

Unit: ‘centimeters`

Returns:

  • (Integer)


9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-georoutes/types.rb', line 9774

class WaypointOptimizationTruckOptions < Struct.new(
  :gross_weight,
  :hazardous_cargos,
  :height,
  :length,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :width)
  SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#lengthInteger

Length of the vehicle.

Unit: ‘centimeters`

Returns:

  • (Integer)


9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-georoutes/types.rb', line 9774

class WaypointOptimizationTruckOptions < Struct.new(
  :gross_weight,
  :hazardous_cargos,
  :height,
  :length,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :width)
  SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#trailerTypes::WaypointOptimizationTrailerOptions

Trailer options corresponding to the vehicle.



9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-georoutes/types.rb', line 9774

class WaypointOptimizationTruckOptions < Struct.new(
  :gross_weight,
  :hazardous_cargos,
  :height,
  :length,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :width)
  SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#truck_typeString

The type of truck: ‘LightTruck` for smaller delivery vehicles, ` StraightTruck` for rigid body trucks, or `Tractor` for tractor-trailer combinations.

Returns:

  • (String)


9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-georoutes/types.rb', line 9774

class WaypointOptimizationTruckOptions < Struct.new(
  :gross_weight,
  :hazardous_cargos,
  :height,
  :length,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :width)
  SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#tunnel_restriction_codeString

The tunnel restriction code.

Tunnel categories in this list indicate the restrictions which apply to certain tunnels in Great Britain. They relate to the types of dangerous goods that can be transported through them.

  • *Tunnel Category B*

    • *Risk Level*: Limited risk

    • Restrictions: Few restrictions

  • *Tunnel Category C*

    • *Risk Level*: Medium risk

    • Restrictions: Some restrictions

  • *Tunnel Category D*

    • *Risk Level*: High risk

    • Restrictions: Many restrictions occur

  • *Tunnel Category E*

    • *Risk Level*: Very high risk

    • Restrictions: Restricted tunnel

Returns:

  • (String)


9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-georoutes/types.rb', line 9774

class WaypointOptimizationTruckOptions < Struct.new(
  :gross_weight,
  :hazardous_cargos,
  :height,
  :length,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :width)
  SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#weight_per_axleInteger

Heaviest weight per axle irrespective of the axle type or the axle group. Meant for usage in countries where the differences in axle types or axle groups are not distinguished.

Unit: ‘kilograms`

Returns:

  • (Integer)


9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-georoutes/types.rb', line 9774

class WaypointOptimizationTruckOptions < Struct.new(
  :gross_weight,
  :hazardous_cargos,
  :height,
  :length,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :width)
  SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#widthInteger

Width of the vehicle.

Unit: ‘centimeters`

Returns:

  • (Integer)


9774
9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
# File 'lib/aws-sdk-georoutes/types.rb', line 9774

class WaypointOptimizationTruckOptions < Struct.new(
  :gross_weight,
  :hazardous_cargos,
  :height,
  :length,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :width)
  SENSITIVE = [:gross_weight, :hazardous_cargos, :height, :length, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end