Class: Aws::GeoRoutes::Types::WaypointOptimizationWaypoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::WaypointOptimizationWaypoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Waypoint between the Origin and Destination.
Constant Summary collapse
- SENSITIVE =
[:appointment_time, :heading, :position, :service_duration]
Instance Attribute Summary collapse
-
#access_hours ⇒ Types::WaypointOptimizationAccessHours
Access hours corresponding to when a waypoint can be visited.
-
#appointment_time ⇒ String
Appointment time at the waypoint.
-
#before ⇒ Array<Integer>
Constraint defining what waypoints are to be visited after this waypoint.
-
#heading ⇒ Float
GPS Heading at the position.
-
#id ⇒ String
The waypoint Id.
-
#position ⇒ Array<Float>
Position in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#service_duration ⇒ Integer
Service time spent at the waypoint.
-
#side_of_street ⇒ Types::WaypointOptimizationSideOfStreetOptions
Options to configure matching the provided position to a side of the street.
Instance Attribute Details
#access_hours ⇒ Types::WaypointOptimizationAccessHours
Access hours corresponding to when a waypoint can be visited.
9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 9840 9841 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9830 class WaypointOptimizationWaypoint < Struct.new( :access_hours, :appointment_time, :before, :heading, :id, :position, :service_duration, :side_of_street) SENSITIVE = [:appointment_time, :heading, :position, :service_duration] include Aws::Structure end |
#appointment_time ⇒ String
Appointment time at the waypoint.
9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 9840 9841 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9830 class WaypointOptimizationWaypoint < Struct.new( :access_hours, :appointment_time, :before, :heading, :id, :position, :service_duration, :side_of_street) SENSITIVE = [:appointment_time, :heading, :position, :service_duration] include Aws::Structure end |
#before ⇒ Array<Integer>
Constraint defining what waypoints are to be visited after this waypoint.
9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 9840 9841 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9830 class WaypointOptimizationWaypoint < Struct.new( :access_hours, :appointment_time, :before, :heading, :id, :position, :service_duration, :side_of_street) SENSITIVE = [:appointment_time, :heading, :position, :service_duration] include Aws::Structure end |
#heading ⇒ Float
GPS Heading at the position.
9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 9840 9841 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9830 class WaypointOptimizationWaypoint < Struct.new( :access_hours, :appointment_time, :before, :heading, :id, :position, :service_duration, :side_of_street) SENSITIVE = [:appointment_time, :heading, :position, :service_duration] include Aws::Structure end |
#id ⇒ String
The waypoint Id.
9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 9840 9841 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9830 class WaypointOptimizationWaypoint < Struct.new( :access_hours, :appointment_time, :before, :heading, :id, :position, :service_duration, :side_of_street) SENSITIVE = [:appointment_time, :heading, :position, :service_duration] include Aws::Structure end |
#position ⇒ Array<Float>
Position in World Geodetic System (WGS 84) format: [longitude, latitude].
9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 9840 9841 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9830 class WaypointOptimizationWaypoint < Struct.new( :access_hours, :appointment_time, :before, :heading, :id, :position, :service_duration, :side_of_street) SENSITIVE = [:appointment_time, :heading, :position, :service_duration] include Aws::Structure end |
#service_duration ⇒ Integer
Service time spent at the waypoint. At an appointment, the service time should be the appointment duration.
Unit: ‘seconds`
9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 9840 9841 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9830 class WaypointOptimizationWaypoint < Struct.new( :access_hours, :appointment_time, :before, :heading, :id, :position, :service_duration, :side_of_street) SENSITIVE = [:appointment_time, :heading, :position, :service_duration] include Aws::Structure end |
#side_of_street ⇒ Types::WaypointOptimizationSideOfStreetOptions
Options to configure matching the provided position to a side of the street.
9830 9831 9832 9833 9834 9835 9836 9837 9838 9839 9840 9841 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9830 class WaypointOptimizationWaypoint < Struct.new( :access_hours, :appointment_time, :before, :heading, :id, :position, :service_duration, :side_of_street) SENSITIVE = [:appointment_time, :heading, :position, :service_duration] include Aws::Structure end |