Class: Aws::GeoRoutes::Types::CalculateIsolinesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::CalculateIsolinesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:arrival_time, :depart_now, :departure_time, :destination, :key, :origin]
Instance Attribute Summary collapse
-
#allow ⇒ Types::IsolineAllowOptions
Enables special road types or features that should be considered for routing even if they might be restricted by default for the selected travel mode.
-
#arrival_time ⇒ String
Determine areas from which ‘Destination` can be reached by this time, taking into account predicted traffic conditions and working backward to account for congestion patterns.
-
#avoid ⇒ Types::IsolineAvoidanceOptions
Specifies road types, features, or areas to avoid (if possible) when calculating reachable areas.
-
#depart_now ⇒ Boolean
When true, uses the current time as the departure time and takes current traffic conditions into account.
-
#departure_time ⇒ String
Determine areas that can be reached when departing at this time, taking into account predicted traffic conditions.
-
#destination ⇒ Array<Float>
An optional destination point, specified as ‘[longitude, latitude]` coordinates.
-
#destination_options ⇒ Types::IsolineDestinationOptions
Options that control how the destination point is matched to the road network and how routes can approach it.
-
#isoline_geometry_format ⇒ String
The format of the returned IsolineGeometry.
-
#isoline_granularity ⇒ Types::IsolineGranularityOptions
Controls the detail level of the generated isolines.
-
#key ⇒ String
An Amazon Location Service API Key with access to this action.
-
#optimize_isoline_for ⇒ String
Controls the trade-off between calculation speed and isoline precision.
-
#optimize_routing_for ⇒ String
Determines whether routes prioritize shortest travel time (‘FastestRoute`) or shortest physical distance (`ShortestRoute`) when calculating reachable areas.
-
#origin ⇒ Array<Float>
The starting point for isoline calculations, specified as ‘[longitude, latitude]` coordinates.
-
#origin_options ⇒ Types::IsolineOriginOptions
Options that control how the origin point is matched to the road network and how routes can depart from it.
-
#thresholds ⇒ Types::IsolineThresholds
The distance or time thresholds used to determine reachable areas.
-
#traffic ⇒ Types::IsolineTrafficOptions
Configures how real-time and historical traffic data affects isoline calculations.
-
#travel_mode ⇒ String
The mode of transportation to use for calculations.
-
#travel_mode_options ⇒ Types::IsolineTravelModeOptions
Additional attributes that refine how reachable areas are calculated based on specific vehicle characteristics.
Instance Attribute Details
#allow ⇒ Types::IsolineAllowOptions
Enables special road types or features that should be considered for routing even if they might be restricted by default for the selected travel mode. These include high-occupancy vehicle and toll lanes.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#arrival_time ⇒ String
Determine areas from which ‘Destination` can be reached by this time, taking into account predicted traffic conditions and working backward to account for congestion patterns. This attribute cannot be used together with `DepartureTime` or `DepartNow`. Specified as an ISO-8601 timestamp with timezone offset.
Time format: ‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`
Examples:
‘2020-04-22T17:57:24Z`
‘2020-04-22T17:57:24+02:00`
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#avoid ⇒ Types::IsolineAvoidanceOptions
Specifies road types, features, or areas to avoid (if possible) when calculating reachable areas. These are treated as preferences rather than strict constraints—if a route cannot be calculated without using an avoided feature, that avoidance preference may be ignored.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#depart_now ⇒ Boolean
When true, uses the current time as the departure time and takes current traffic conditions into account. This attribute cannot be used together with ‘DepartureTime` or `ArrivalTime`.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#departure_time ⇒ String
Determine areas that can be reached when departing at this time, taking into account predicted traffic conditions. This attribute cannot be used together with ‘ArrivalTime` or `DepartNow`. Specified as an ISO-8601 timestamp with timezone offset.
Time format:‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`
Examples:
‘2020-04-22T17:57:24Z`
‘2020-04-22T17:57:24+02:00`
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#destination ⇒ Array<Float>
An optional destination point, specified as ‘[longitude, latitude]` coordinates. When provided, the service calculates areas from which this destination can be reached within the specified thresholds. This reverses the usual isoline calculation to show areas that could reach your location, rather than areas you could reach from your location. Either `Origin` or `Destination` must be provided.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#destination_options ⇒ Types::IsolineDestinationOptions
Options that control how the destination point is matched to the road network and how routes can approach it. These options help improve travel time accuracy by accounting for real-world access to the destination.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#isoline_geometry_format ⇒ String
The format of the returned IsolineGeometry.
Default value:‘FlexiblePolyline`
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#isoline_granularity ⇒ Types::IsolineGranularityOptions
Controls the detail level of the generated isolines. Higher granularity produces smoother shapes but requires more processing time and results in larger responses.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#key ⇒ String
An Amazon Location Service API Key with access to this action. If omitted, the request must be signed using Signature Version 4.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#optimize_isoline_for ⇒ String
Controls the trade-off between calculation speed and isoline precision. Choose ‘ FastCalculation` for quicker results with less detail, `AccurateCalculation` for more precise results, or `BalancedCalculation` for a middle ground.
Default value: ‘BalancedCalculation`
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#optimize_routing_for ⇒ String
Determines whether routes prioritize shortest travel time (‘FastestRoute`) or shortest physical distance (`ShortestRoute`) when calculating reachable areas.
Default value: ‘FastestRoute`
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#origin ⇒ Array<Float>
The starting point for isoline calculations, specified as ‘[longitude, latitude]` coordinates. For example, this could be a store location, service center, or any point from which you want to calculate reachable areas. Either `Origin` or `Destination` must be provided.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#origin_options ⇒ Types::IsolineOriginOptions
Options that control how the origin point is matched to the road network and how routes can depart from it. These options help improve travel time accuracy by accounting for real-world access from the origin.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#thresholds ⇒ Types::IsolineThresholds
The distance or time thresholds used to determine reachable areas. You can specify up to five thresholds (which all must be the same type) to calculate multiple isolines in a single request. For example, to determine the areas that are reachable within 10 and 20 minutes of the origin, specify time thresholds of 600 and 1200 seconds.
You incur a calculation charge for each threshold. Using a large number of thresholds in a request can lead to unexpected charges. For more information, see [Routes pricing] in the *Amazon Location Service Developer Guide*.
[1]: docs.aws.amazon.com/location/latest/developerguide/routes-pricing.html
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#traffic ⇒ Types::IsolineTrafficOptions
Configures how real-time and historical traffic data affects isoline calculations. Traffic patterns can significantly impact reachable areas, especially during peak hours.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#travel_mode ⇒ String
The mode of transportation to use for calculations. This affects which road types or features can be used, estimated speed, and the traffic levels that are applied.
-
‘Car`—Standard passenger vehicle routing using roads accessible to cars
-
‘Pedestrian`—Walking routes using pedestrian paths, sidewalks, and crossings
-
‘Scooter`—Light two-wheeled vehicle routing using roads and paths accessible to scooters
-
‘Truck`—Commercial truck routing considering vehicle dimensions, weight restrictions, and hazardous material regulations
<note markdown=“1”> The mode ‘Scooter` also applies to motorcycles; set this to `Scooter` when calculating isolines for motorcycles.
</note>
Default value: ‘Car`
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |
#travel_mode_options ⇒ Types::IsolineTravelModeOptions
Additional attributes that refine how reachable areas are calculated based on specific vehicle characteristics. These options help produce more accurate results by accounting for real-world constraints and capabilities.
For example:
-
For trucks (‘Truck`), specify dimensions, weight limits, and hazardous cargo restrictions to ensure isolines only include roads that can physically and legally accommodate the vehicle
-
For cars (‘Car`), set maximum speed capabilities or indicate high-occupancy vehicle eligibility to better estimate reachable areas
-
For scooters (‘Scooter`), specify engine type and speed limitations to more accurately model their travel capabilities
Without these options, calculations use default assumptions that may not match your specific use case.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-georoutes/types.rb', line 217 class CalculateIsolinesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :isoline_geometry_format, :isoline_granularity, :key, :optimize_isoline_for, :optimize_routing_for, :origin, :origin_options, :thresholds, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :origin] include Aws::Structure end |