Class: Aws::GeoRoutes::Types::CalculateRouteMatrixRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::CalculateRouteMatrixRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:allow, :depart_now, :departure_time, :key]
Instance Attribute Summary collapse
-
#allow ⇒ Types::RouteMatrixAllowOptions
Features that are allowed while calculating a route.
-
#avoid ⇒ Types::RouteMatrixAvoidanceOptions
Features that are avoided while calculating a route.
-
#depart_now ⇒ Boolean
Uses the current time as the time of departure.
-
#departure_time ⇒ String
Time of departure from the origin.
-
#destinations ⇒ Array<Types::RouteMatrixDestination>
List of destinations for the route.
-
#exclude ⇒ Types::RouteMatrixExclusionOptions
Features to be strictly excluded while calculating the route.
-
#key ⇒ String
Optional: The API key to be used for authorization.
-
#optimize_routing_for ⇒ String
Controls the trade-off between finding the shortest travel time (‘FastestRoute`) and the shortest distance (`ShortestRoute`) when calculating reachable areas.
-
#origins ⇒ Array<Types::RouteMatrixOrigin>
The position for the origin in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#routing_boundary ⇒ Types::RouteMatrixBoundary
Boundary within which the matrix is to be calculated.
-
#traffic ⇒ Types::RouteMatrixTrafficOptions
Traffic related options.
-
#travel_mode ⇒ String
Specifies the mode of transport when calculating a route.
-
#travel_mode_options ⇒ Types::RouteMatrixTravelModeOptions
Travel mode related options for the provided travel mode.
Instance Attribute Details
#allow ⇒ Types::RouteMatrixAllowOptions
Features that are allowed while calculating a route.
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#avoid ⇒ Types::RouteMatrixAvoidanceOptions
Features that are avoided while calculating a route. Avoidance is on a best-case basis. If an avoidance can’t be satisfied for a particular case, it violates the avoidance and the returned response produces a notice for the violation. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only `TollRoads`, `Ferries`, and `ControlledAccessHighways`.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#depart_now ⇒ Boolean
Uses the current time as the time of departure.
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#departure_time ⇒ String
Time of departure from the origin.
Time format:‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`
Examples:
‘2020-04-22T17:57:24Z`
‘2020-04-22T17:57:24+02:00`
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#destinations ⇒ Array<Types::RouteMatrixDestination>
List of destinations for the route.
<note markdown=“1”> Route calculations are billed for each origin and destination pair. If you use a large matrix of origins and destinations, your costs will increase accordingly. For more information, see [Routes pricing] in the *Amazon Location Service Developer Guide*.
</note>
[1]: docs.aws.amazon.com/location/latest/developerguide/routes-pricing.html
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#exclude ⇒ Types::RouteMatrixExclusionOptions
Features to be strictly excluded while calculating the route. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#key ⇒ String
Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#optimize_routing_for ⇒ String
Controls the trade-off between finding the shortest travel time (‘FastestRoute`) and the shortest distance (`ShortestRoute`) when calculating reachable areas.
Default value: ‘FastestRoute`
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#origins ⇒ Array<Types::RouteMatrixOrigin>
The position for the origin in World Geodetic System (WGS 84) format: [longitude, latitude].
<note markdown=“1”> Route calculations are billed for each origin and destination pair. Using a large amount of Origins in a request can lead you to incur unexpected charges. For more information, see [Routes pricing] in the *Amazon Location Service Developer Guide*.
</note>
[1]: docs.aws.amazon.com/location/latest/developerguide/routes-pricing.html
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#routing_boundary ⇒ Types::RouteMatrixBoundary
Boundary within which the matrix is to be calculated. All data, origins and destinations outside the boundary are considered invalid. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only `Unbounded` set to `true`.
Default value: ‘Unbounded set to true`
<note markdown=“1”> When request routing boundary was set as AutoCircle, the response routing boundary will return Circle derived from the AutoCircle settings.
</note>
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#traffic ⇒ Types::RouteMatrixTrafficOptions
Traffic related options. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#travel_mode ⇒ String
Specifies the mode of transport when calculating a route. Used in estimating the speed of travel and road compatibility. For
- GrabMaps][1
-
customers, ‘ap-southeast-1` and `ap-southeast-5`
regions support only ‘Car`, `Pedestrian`, and `Scooter`.
Default value: ‘Car`
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |
#travel_mode_options ⇒ Types::RouteMatrixTravelModeOptions
Travel mode related options for the provided travel mode. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/aws-sdk-georoutes/types.rb', line 456 class CalculateRouteMatrixRequest < Struct.new( :allow, :avoid, :depart_now, :departure_time, :destinations, :exclude, :key, :optimize_routing_for, :origins, :routing_boundary, :traffic, :travel_mode, :travel_mode_options) SENSITIVE = [:allow, :depart_now, :departure_time, :key] include Aws::Structure end |