Class: Aws::GeoRoutes::Types::CalculateRouteMatrixResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::CalculateRouteMatrixResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_count ⇒ Integer
The count of error results in the route matrix.
-
#pricing_bucket ⇒ String
The pricing bucket for which the query is charged at.
-
#route_matrix ⇒ Array<Array<Types::RouteMatrixEntry>>
The calculated route matrix containing the results for all pairs of Origins to Destination positions.
-
#routing_boundary ⇒ Types::RouteMatrixBoundary
Boundary within which the matrix is to be calculated.
Instance Attribute Details
#error_count ⇒ Integer
The count of error results in the route matrix. If this number is 0, all routes were calculated successfully.
546 547 548 549 550 551 552 553 |
# File 'lib/aws-sdk-georoutes/types.rb', line 546 class CalculateRouteMatrixResponse < Struct.new( :error_count, :pricing_bucket, :route_matrix, :routing_boundary) SENSITIVE = [] include Aws::Structure end |
#pricing_bucket ⇒ String
The pricing bucket for which the query is charged at.
546 547 548 549 550 551 552 553 |
# File 'lib/aws-sdk-georoutes/types.rb', line 546 class CalculateRouteMatrixResponse < Struct.new( :error_count, :pricing_bucket, :route_matrix, :routing_boundary) SENSITIVE = [] include Aws::Structure end |
#route_matrix ⇒ Array<Array<Types::RouteMatrixEntry>>
The calculated route matrix containing the results for all pairs of Origins to Destination positions. Each row corresponds to one entry in Origins. Each entry in the row corresponds to the route from that entry in Origins to an entry in Destination positions.
546 547 548 549 550 551 552 553 |
# File 'lib/aws-sdk-georoutes/types.rb', line 546 class CalculateRouteMatrixResponse < Struct.new( :error_count, :pricing_bucket, :route_matrix, :routing_boundary) SENSITIVE = [] include Aws::Structure end |
#routing_boundary ⇒ Types::RouteMatrixBoundary
Boundary within which the matrix is to be calculated. All data, origins and destinations outside the boundary are considered invalid.
<note markdown=“1”> When ‘AutoCircle` is set in the request, the response routing boundary will return `Circle` derived from the `AutoCircle` settings.
</note>
546 547 548 549 550 551 552 553 |
# File 'lib/aws-sdk-georoutes/types.rb', line 546 class CalculateRouteMatrixResponse < Struct.new( :error_count, :pricing_bucket, :route_matrix, :routing_boundary) SENSITIVE = [] include Aws::Structure end |