Class: Aws::GeoRoutes::Types::CalculateRoutesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::CalculateRoutesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin]
Instance Attribute Summary collapse
-
#allow ⇒ Types::RouteAllowOptions
Features that are allowed while calculating a route.
-
#arrival_time ⇒ String
Time of arrival at the destination.
-
#avoid ⇒ Types::RouteAvoidanceOptions
Features that are avoided while calculating a route.
-
#depart_now ⇒ Boolean
Uses the current time as the time of departure.
-
#departure_time ⇒ String
Time of departure from the origin.
-
#destination ⇒ Array<Float>
The final position for the route.
-
#destination_options ⇒ Types::RouteDestinationOptions
Destination related options.
-
#driver ⇒ Types::RouteDriverOptions
Driver related options.
-
#exclude ⇒ Types::RouteExclusionOptions
Features to be strictly excluded while calculating the route.
-
#instructions_measurement_system ⇒ String
Measurement system to be used for instructions within steps in the response.
-
#key ⇒ String
Optional: The API key to be used for authorization.
-
#languages ⇒ Array<String>
List of languages for instructions within steps in the response.
-
#leg_additional_features ⇒ Array<String>
A list of optional additional parameters such as timezone that can be requested for each result.
-
#leg_geometry_format ⇒ String
Specifies the format of the geometry returned for each leg of the route.
-
#max_alternatives ⇒ Integer
Maximum number of alternative routes to be provided in the response, if available.
-
#optimize_routing_for ⇒ String
Controls the trade-off between achieving the shortest travel time (‘FastestRoute`) and achieving the shortest physical distance ((`ShortestRoute`) when calculating each route in the matrix.
-
#origin ⇒ Array<Float>
The start position for the route in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#origin_options ⇒ Types::RouteOriginOptions
Specifies how the origin point should be matched to the road network and any routing constraints that apply when the traveler is departing the origin.
-
#span_additional_features ⇒ Array<String>
A list of optional features such as ‘SpeedLimit` that can be requested for a Span.
-
#tolls ⇒ Types::RouteTollOptions
Toll related options.
-
#traffic ⇒ Types::RouteTrafficOptions
Traffic related options.
-
#travel_mode ⇒ String
Specifies the mode of transport when calculating a route.
-
#travel_mode_options ⇒ Types::RouteTravelModeOptions
Travel mode related options for the provided travel mode.
-
#travel_step_type ⇒ String
Type of step returned by the response.
-
#waypoints ⇒ Array<Types::RouteWaypoint>
List of waypoints between the Origin and Destination.
Instance Attribute Details
#allow ⇒ Types::RouteAllowOptions
Features that are allowed while calculating a route. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#arrival_time ⇒ String
Time of arrival at the destination. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
Time format:‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`
Examples:
‘2020-04-22T17:57:24Z`
‘2020-04-22T17:57:24+02:00`
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#avoid ⇒ Types::RouteAvoidanceOptions
Features that are avoided while calculating a route. Avoidance is on a best-case basis. If an avoidance can’t be satisfied for a particular case, it violates the avoidance and the returned response produces a notice for the violation. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only `ControlledAccessHighways`, `Ferries`, and `TollRoads`
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#depart_now ⇒ Boolean
Uses the current time as the time of departure.
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#departure_time ⇒ String
Time of departure from the origin.
Time format:‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`
Examples:
‘2020-04-22T17:57:24Z`
‘2020-04-22T17:57:24+02:00`
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#destination ⇒ Array<Float>
The final position for the route. In the World Geodetic System (WGS 84) format: ‘[longitude, latitude]`.
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#destination_options ⇒ Types::RouteDestinationOptions
Destination related options. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#driver ⇒ Types::RouteDriverOptions
Driver related options. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#exclude ⇒ Types::RouteExclusionOptions
Features to be strictly excluded while calculating the route. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#instructions_measurement_system ⇒ String
Measurement system to be used for instructions within steps in the response.
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#key ⇒ String
Optional: The API key to be used for authorization. Either an API key or valid SigV4 signature must be provided when making a request.
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#languages ⇒ Array<String>
List of languages for instructions within steps in the response. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
<note markdown=“1”> Instructions in the requested language are returned only if they are available.
</note>
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#leg_additional_features ⇒ Array<String>
A list of optional additional parameters such as timezone that can be requested for each result. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only `PassThroughWaypoints`, `Summary`, and `TravelStepInstructions`
-
‘Elevation`: Retrieves the elevation information for each location.
-
‘Incidents`: Provides information on traffic incidents along the route.
-
‘PassThroughWaypoints`: Indicates waypoints that are passed through without stopping.
-
‘Summary`: Returns a summary of the route, including distance and duration.
-
‘Tolls`: Supplies toll cost information along the route.
-
‘TravelStepInstructions`: Provides step-by-step instructions for travel along the route.
-
‘TruckRoadTypes`: Returns information about road types suitable for trucks.
-
‘TypicalDuration`: Gives typical travel duration based on historical data.
-
‘Zones`: Specifies the time zone information for each waypoint.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#leg_geometry_format ⇒ String
Specifies the format of the geometry returned for each leg of the route. You can choose between two different geometry encoding formats.
‘FlexiblePolyline`: A compact and precise encoding format for the leg geometry. For more information on the format, see the GitHub repository for [github.com/aws-geospatial/polyline][1].
‘Simple`: A less compact encoding, which is easier to decode but may be less precise and result in larger payloads.
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#max_alternatives ⇒ Integer
Maximum number of alternative routes to be provided in the response, if available. For [GrabMaps] customers, ‘ap-southeast-1` and `ap-southeast-5` regions support only up to 3 alternative routes.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#optimize_routing_for ⇒ String
Controls the trade-off between achieving the shortest travel time (‘FastestRoute`) and achieving the shortest physical distance ((`ShortestRoute`) when calculating each route in the matrix.
Default value: ‘FastestRoute`
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#origin ⇒ Array<Float>
The start position for the route in World Geodetic System (WGS 84) format: [longitude, latitude].
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#origin_options ⇒ Types::RouteOriginOptions
Specifies how the origin point should be matched to the road network and any routing constraints that apply when the traveler is departing the origin. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#span_additional_features ⇒ Array<String>
A list of optional features such as ‘SpeedLimit` that can be requested for a Span. A span is a section of a Leg for which the requested features have the same values. Not supported in `ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#tolls ⇒ Types::RouteTollOptions
Toll related options. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#traffic ⇒ Types::RouteTrafficOptions
Traffic related options. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#travel_mode ⇒ String
Specifies the mode of transport when calculating a route. Used in estimating the speed of travel and road compatibility. For
- GrabMaps][1
-
customers, ‘ap-southeast-1` and `ap-southeast-5`
regions support only ‘Car`, `Pedestrian`, and `Scooter` values.
Default value: ‘Car`
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#travel_mode_options ⇒ Types::RouteTravelModeOptions
Travel mode related options for the provided travel mode. For
- GrabMaps][1
-
customers, ‘ap-southeast-1` and `ap-southeast-5`
regions support only ‘Car` and `Pedestrian` travel mode options.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#travel_step_type ⇒ String
Type of step returned by the response. ‘Default` provides basic steps intended for web based applications. `TurnByTurn` provides detailed instructions with more granularity intended for a turn based navigation system. For [GrabMaps] customers, `ap-southeast-1` and `ap-southeast-5` regions `Default` does not return any steps.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |
#waypoints ⇒ Array<Types::RouteWaypoint>
List of waypoints between the Origin and Destination. For
- GrabMaps][1
-
customers, ‘ap-southeast-1` and `ap-southeast-5`
regions max length is ‘100`.
Max length: ‘23`
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/aws-sdk-georoutes/types.rb', line 839 class CalculateRoutesRequest < Struct.new( :allow, :arrival_time, :avoid, :depart_now, :departure_time, :destination, :destination_options, :driver, :exclude, :instructions_measurement_system, :key, :languages, :leg_additional_features, :leg_geometry_format, :max_alternatives, :optimize_routing_for, :origin, :origin_options, :span_additional_features, :tolls, :traffic, :travel_mode, :travel_mode_options, :travel_step_type, :waypoints) SENSITIVE = [:arrival_time, :depart_now, :departure_time, :destination, :key, :leg_additional_features, :origin] include Aws::Structure end |