Class: Aws::GeoRoutes::Types::Isoline
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::Isoline
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Represents a single reachable area calculated for a specific threshold.
Constant Summary collapse
- SENSITIVE =
[:distance_threshold, :time_threshold]
Instance Attribute Summary collapse
-
#connections ⇒ Array<Types::IsolineConnection>
Lines connecting separate parts of the reachable area that can be reached within the same threshold.
-
#distance_threshold ⇒ Integer
The travel distance in meters used to calculate this isoline, if distance-based thresholds were specified in the request.
-
#geometries ⇒ Array<Types::IsolineShapeGeometry>
The shapes that define the reachable area, provided in the requested geometry format.
-
#time_threshold ⇒ Integer
The travel time in seconds used to calculate this isoline, if time-based thresholds were specified in the request.
Instance Attribute Details
#connections ⇒ Array<Types::IsolineConnection>
Lines connecting separate parts of the reachable area that can be reached within the same threshold. These occur when areas are reachable but not contiguous, such as when separated by water or unroutable areas. When present, these lines represent actual transportation network segments (such as ferry routes or bridges) that connect the separated areas.
1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-georoutes/types.rb', line 1005 class Isoline < Struct.new( :connections, :distance_threshold, :geometries, :time_threshold) SENSITIVE = [:distance_threshold, :time_threshold] include Aws::Structure end |
#distance_threshold ⇒ Integer
The travel distance in meters used to calculate this isoline, if distance-based thresholds were specified in the request.
1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-georoutes/types.rb', line 1005 class Isoline < Struct.new( :connections, :distance_threshold, :geometries, :time_threshold) SENSITIVE = [:distance_threshold, :time_threshold] include Aws::Structure end |
#geometries ⇒ Array<Types::IsolineShapeGeometry>
The shapes that define the reachable area, provided in the requested geometry format.
1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-georoutes/types.rb', line 1005 class Isoline < Struct.new( :connections, :distance_threshold, :geometries, :time_threshold) SENSITIVE = [:distance_threshold, :time_threshold] include Aws::Structure end |
#time_threshold ⇒ Integer
The travel time in seconds used to calculate this isoline, if time-based thresholds were specified in the request.
1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/aws-sdk-georoutes/types.rb', line 1005 class Isoline < Struct.new( :connections, :distance_threshold, :geometries, :time_threshold) SENSITIVE = [:distance_threshold, :time_threshold] include Aws::Structure end |