Class: Aws::GeoRoutes::Types::RouteIntermodalOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteIntermodalOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Options related to intermodal routing.
<note markdown=“1”> Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
</note>
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
Constant Summary collapse
- SENSITIVE =
[:accessibility_attributes]
Instance Attribute Summary collapse
-
#accessibility_attributes ⇒ Array<String>
Accessibility attributes to consider when calculating the route.
-
#max_transfers ⇒ Integer
Maximum number of transfers allowed when calculating the route.
-
#pedestrian ⇒ Types::RouteIntermodalPedestrianOptions
Options for the pedestrian leg of the intermodal route.
-
#rental ⇒ Types::RouteIntermodalRentalOptions
Options for the rental leg of the intermodal route.
-
#taxi ⇒ Types::RouteIntermodalTaxiOptions
Options for the taxi leg of the intermodal route.
-
#transit ⇒ Types::RouteIntermodalTransitOptions
Options for the transit leg of the intermodal route.
-
#vehicle ⇒ Types::RouteIntermodalVehicleOptions
Options for the vehicle leg of the intermodal route.
Instance Attribute Details
#accessibility_attributes ⇒ Array<String>
Accessibility attributes to consider when calculating the route.
3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3457 class RouteIntermodalOptions < Struct.new( :accessibility_attributes, :max_transfers, :pedestrian, :rental, :taxi, :transit, :vehicle) SENSITIVE = [:accessibility_attributes] include Aws::Structure end |
#max_transfers ⇒ Integer
Maximum number of transfers allowed when calculating the route.
3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3457 class RouteIntermodalOptions < Struct.new( :accessibility_attributes, :max_transfers, :pedestrian, :rental, :taxi, :transit, :vehicle) SENSITIVE = [:accessibility_attributes] include Aws::Structure end |
#pedestrian ⇒ Types::RouteIntermodalPedestrianOptions
Options for the pedestrian leg of the intermodal route.
3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3457 class RouteIntermodalOptions < Struct.new( :accessibility_attributes, :max_transfers, :pedestrian, :rental, :taxi, :transit, :vehicle) SENSITIVE = [:accessibility_attributes] include Aws::Structure end |
#rental ⇒ Types::RouteIntermodalRentalOptions
Options for the rental leg of the intermodal route.
3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3457 class RouteIntermodalOptions < Struct.new( :accessibility_attributes, :max_transfers, :pedestrian, :rental, :taxi, :transit, :vehicle) SENSITIVE = [:accessibility_attributes] include Aws::Structure end |
#taxi ⇒ Types::RouteIntermodalTaxiOptions
Options for the taxi leg of the intermodal route.
3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3457 class RouteIntermodalOptions < Struct.new( :accessibility_attributes, :max_transfers, :pedestrian, :rental, :taxi, :transit, :vehicle) SENSITIVE = [:accessibility_attributes] include Aws::Structure end |
#transit ⇒ Types::RouteIntermodalTransitOptions
Options for the transit leg of the intermodal route.
3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3457 class RouteIntermodalOptions < Struct.new( :accessibility_attributes, :max_transfers, :pedestrian, :rental, :taxi, :transit, :vehicle) SENSITIVE = [:accessibility_attributes] include Aws::Structure end |
#vehicle ⇒ Types::RouteIntermodalVehicleOptions
Options for the vehicle leg of the intermodal route.
3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3457 class RouteIntermodalOptions < Struct.new( :accessibility_attributes, :max_transfers, :pedestrian, :rental, :taxi, :transit, :vehicle) SENSITIVE = [:accessibility_attributes] include Aws::Structure end |