Class: Aws::GeoRoutes::Types::RouteMatrixAutoCircle
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteMatrixAutoCircle
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
‘AutoCircle` requests the route matrix service to define a `Circle` boundary that best attempts to include most waypoints (`Origins` and `Destinations`) using the `AutoCircle` settings. Any waypoints outside of the auto-defined `Circle` boundary will be considered out of the routing boundary, which results in a route matrix entry error.
‘AutoCircle` is only used in the request to configure a `Circle` for the route calculation. The derived `Circle` will also be provided in the response.
Constant Summary collapse
- SENSITIVE =
[:margin, :max_radius]
Instance Attribute Summary collapse
-
#margin ⇒ Integer
The minimal distance, in meters, between any waypoint and the perimeter of the circle auto-defined for the boundary.
-
#max_radius ⇒ Integer
The maximum radius, in meters, that the auto-defined ‘Circle` boundary should have, before the `Margin` distance is added to the circle.
Instance Attribute Details
#margin ⇒ Integer
The minimal distance, in meters, between any waypoint and the perimeter of the circle auto-defined for the boundary. Some margin is usually recommended so that the routing has enough leeway to travel from one waypoint to another optimally without conflicting with the routing boundary.
The total of ‘MaxRadius` and `Margin` must be less than or equal to 200,000 meters.
3923 3924 3925 3926 3927 3928 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3923 class RouteMatrixAutoCircle < Struct.new( :margin, :max_radius) SENSITIVE = [:margin, :max_radius] include Aws::Structure end |
#max_radius ⇒ Integer
The maximum radius, in meters, that the auto-defined ‘Circle` boundary should have, before the `Margin` distance is added to the circle.
The total of ‘MaxRadius` and `Margin` must be less than or equal to 200,000 meters.
3923 3924 3925 3926 3927 3928 |
# File 'lib/aws-sdk-georoutes/types.rb', line 3923 class RouteMatrixAutoCircle < Struct.new( :margin, :max_radius) SENSITIVE = [:margin, :max_radius] include Aws::Structure end |