Class: Aws::GeoRoutes::Types::RouteMatrixBoundaryGeometry
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteMatrixBoundaryGeometry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Geometry of the routing boundary.
Constant Summary collapse
- SENSITIVE =
[:circle, :bounding_box]
Instance Attribute Summary collapse
-
#auto_circle ⇒ Types::RouteMatrixAutoCircle
‘AutoCircle` requests the route matrix service to define a `Circle` boundary that best attempts to include most waypoints (`Origins` and `Destinations`) using the `AutoCircle` settings.
-
#bounding_box ⇒ Array<Float>
Geometry defined as a bounding box.
-
#circle ⇒ Types::Circle
Geometry defined as a circle.
-
#polygon ⇒ Array<Array<Array<Float>>>
Geometry defined as a polygon with only one linear ring.
Instance Attribute Details
#auto_circle ⇒ Types::RouteMatrixAutoCircle
‘AutoCircle` requests the route matrix service to define a `Circle` boundary that best attempts to include most waypoints (`Origins` and `Destinations`) using the `AutoCircle` settings. Any waypoints outside of the auto-defined `Circle` boundary will be considered out of the routing boundary, which results in a route matrix entry error.
‘AutoCircle` is only used in the request to configure a `Circle` for the route calculation. The derived `Circle` will also be provided in the response.
4142 4143 4144 4145 4146 4147 4148 4149 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4142 class RouteMatrixBoundaryGeometry < Struct.new( :auto_circle, :circle, :bounding_box, :polygon) SENSITIVE = [:circle, :bounding_box] include Aws::Structure end |
#bounding_box ⇒ Array<Float>
Geometry defined as a bounding box. The first pair represents the X and Y coordinates (longitude and latitude,) of the southwest corner of the bounding box; the second pair represents the X and Y coordinates (longitude and latitude) of the northeast corner.
Diagonal distance of the bounding box must be less than or equal to 400,000 meters.
4142 4143 4144 4145 4146 4147 4148 4149 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4142 class RouteMatrixBoundaryGeometry < Struct.new( :auto_circle, :circle, :bounding_box, :polygon) SENSITIVE = [:circle, :bounding_box] include Aws::Structure end |
#circle ⇒ Types::Circle
Geometry defined as a circle. The circle defines the routing boundary area. Any waypoints outside the circle will result in a route matrix entry error.
You can specify a ‘Circle` directly in the request, or it will be auto-derived when `AutoCircle` is used. When `AutoCircle` is set in the request, the response routing boundary will return `Circle` derived from the `AutoCircle` settings.
4142 4143 4144 4145 4146 4147 4148 4149 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4142 class RouteMatrixBoundaryGeometry < Struct.new( :auto_circle, :circle, :bounding_box, :polygon) SENSITIVE = [:circle, :bounding_box] include Aws::Structure end |
#polygon ⇒ Array<Array<Array<Float>>>
Geometry defined as a polygon with only one linear ring. A linear ring is a closed sequence of four or more coordinates. The first and last coordinates are the same, forming a closed boundary. Each coordinate is a position in [longitude, latitude] format.
The structure is an array of linear rings (only 1 allowed). Each linear ring is an array of coordinates (minimum 4), and each coordinate is an array of two doubles [longitude, latitude].
Maximum distance between any two vertices must be less than or equal to 400,000 meters.
4142 4143 4144 4145 4146 4147 4148 4149 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4142 class RouteMatrixBoundaryGeometry < Struct.new( :auto_circle, :circle, :bounding_box, :polygon) SENSITIVE = [:circle, :bounding_box] include Aws::Structure end |