Class: Aws::GeoRoutes::Types::RouteMatrixTruckOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Travel mode options when the provided travel mode is ‘Truck`.

Constant Summary collapse

SENSITIVE =
[:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]

Instance Attribute Summary collapse

Instance Attribute Details

#axle_countInteger

Total number of axles of the vehicle.

Returns:

  • (Integer)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#gross_weightInteger

Gross weight of the vehicle including trailers, and goods at capacity.

Unit: ‘kilograms`

Returns:

  • (Integer)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#hazardous_cargosArray<String>

List of Hazardous cargo contained in the vehicle.

Returns:

  • (Array<String>)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#heightInteger

Height of the vehicle.

Unit: ‘centimeters`

Returns:

  • (Integer)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#kpra_lengthInteger

Kingpin to rear axle length of the vehicle

Unit: ‘centimeters`

Returns:

  • (Integer)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#lengthInteger

Length of the vehicle.

Unit: ‘centimeters`

Returns:

  • (Integer)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#license_plateTypes::RouteMatrixVehicleLicensePlate

The vehicle License Plate.



4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#max_speedFloat

Maximum speed

Unit: ‘kilometers per hour`

Returns:

  • (Float)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#occupancyInteger

The number of occupants in the vehicle.

Default value: ‘1`

Returns:

  • (Integer)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#payload_capacityInteger

Payload capacity of the vehicle and trailers attached.

Unit: ‘kilograms`

Returns:

  • (Integer)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#trailerTypes::RouteMatrixTrailerOptions

Trailer options corresponding to the vehicle.



4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#truck_typeString

The type of truck: ‘LightTruck` for smaller delivery vehicles, ` StraightTruck` for rigid body trucks, or `Tractor` for tractor-trailer combinations.

Returns:

  • (String)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#tunnel_restriction_codeString

The tunnel restriction code.

Tunnel categories in this list indicate the restrictions which apply to certain tunnels in Great Britain. They relate to the types of dangerous goods that can be transported through them.

  • *Tunnel Category B*

    • *Risk Level*: Limited risk

    • Restrictions: Few restrictions

  • *Tunnel Category C*

    • *Risk Level*: Medium risk

    • Restrictions: Some restrictions

  • *Tunnel Category D*

    • *Risk Level*: High risk

    • Restrictions: Many restrictions occur

  • *Tunnel Category E*

    • *Risk Level*: Very high risk

    • Restrictions: Restricted tunnel

Returns:

  • (String)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#weight_per_axleInteger

Heaviest weight per axle irrespective of the axle type or the axle group. Meant for usage in countries where the differences in axle types or axle groups are not distinguished.

Unit: ‘kilograms`

Returns:

  • (Integer)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#weight_per_axle_groupTypes::WeightPerAxleGroup

Specifies the total weight for the specified axle group. Meant for usage in countries that have different regulations based on the axle group type.



4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end

#widthInteger

Width of the vehicle.

Unit: ‘centimeters`

Returns:

  • (Integer)


4173
4174
4175
4176
4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/aws-sdk-georoutes/types.rb', line 4173

class RouteMatrixTruckOptions < Struct.new(
  :axle_count,
  :gross_weight,
  :hazardous_cargos,
  :height,
  :kpra_length,
  :length,
  :license_plate,
  :max_speed,
  :occupancy,
  :payload_capacity,
  :trailer,
  :truck_type,
  :tunnel_restriction_code,
  :weight_per_axle,
  :weight_per_axle_group,
  :width)
  SENSITIVE = [:axle_count, :gross_weight, :hazardous_cargos, :height, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
  include Aws::Structure
end