Class: Aws::GeoRoutes::Types::RoutePedestrianLegDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RoutePedestrianLegDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Details that are specific to a pedestrian leg.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_travel_steps ⇒ Array<Types::RoutePedestrianAfterTravelStep>
Steps of a leg that must be performed after the travel portion of the leg.
-
#arrival ⇒ Types::RoutePedestrianArrival
Details corresponding to the arrival for the leg.
-
#departure ⇒ Types::RoutePedestrianDeparture
Details corresponding to the departure for the leg.
-
#notices ⇒ Array<Types::RoutePedestrianNotice>
Notices are additional information returned that indicate issues that occurred during route calculation.
-
#pass_through_waypoints ⇒ Array<Types::RoutePassThroughWaypoint>
Waypoints that were passed through during the leg.
-
#spans ⇒ Array<Types::RoutePedestrianSpan>
Spans that were computed for the requested SpanAdditionalFeatures.
-
#summary ⇒ Types::RoutePedestrianSummary
Summarized details of the leg.
-
#travel_steps ⇒ Array<Types::RoutePedestrianTravelStep>
Steps of a leg that must be performed before the travel portion of the leg.
Instance Attribute Details
#after_travel_steps ⇒ Array<Types::RoutePedestrianAfterTravelStep>
Steps of a leg that must be performed after the travel portion of the leg.
4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4924 class RoutePedestrianLegDetails < Struct.new( :after_travel_steps, :arrival, :departure, :notices, :pass_through_waypoints, :spans, :summary, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#arrival ⇒ Types::RoutePedestrianArrival
Details corresponding to the arrival for the leg.
4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4924 class RoutePedestrianLegDetails < Struct.new( :after_travel_steps, :arrival, :departure, :notices, :pass_through_waypoints, :spans, :summary, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#departure ⇒ Types::RoutePedestrianDeparture
Details corresponding to the departure for the leg.
4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4924 class RoutePedestrianLegDetails < Struct.new( :after_travel_steps, :arrival, :departure, :notices, :pass_through_waypoints, :spans, :summary, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#notices ⇒ Array<Types::RoutePedestrianNotice>
Notices are additional information returned that indicate issues that occurred during route calculation. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4924 class RoutePedestrianLegDetails < Struct.new( :after_travel_steps, :arrival, :departure, :notices, :pass_through_waypoints, :spans, :summary, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#pass_through_waypoints ⇒ Array<Types::RoutePassThroughWaypoint>
Waypoints that were passed through during the leg. This includes the waypoints that were configured with the PassThrough option.
4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4924 class RoutePedestrianLegDetails < Struct.new( :after_travel_steps, :arrival, :departure, :notices, :pass_through_waypoints, :spans, :summary, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#spans ⇒ Array<Types::RoutePedestrianSpan>
Spans that were computed for the requested SpanAdditionalFeatures. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4924 class RoutePedestrianLegDetails < Struct.new( :after_travel_steps, :arrival, :departure, :notices, :pass_through_waypoints, :spans, :summary, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#summary ⇒ Types::RoutePedestrianSummary
Summarized details of the leg.
4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4924 class RoutePedestrianLegDetails < Struct.new( :after_travel_steps, :arrival, :departure, :notices, :pass_through_waypoints, :spans, :summary, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#travel_steps ⇒ Array<Types::RoutePedestrianTravelStep>
Steps of a leg that must be performed before the travel portion of the leg.
4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 |
# File 'lib/aws-sdk-georoutes/types.rb', line 4924 class RoutePedestrianLegDetails < Struct.new( :after_travel_steps, :arrival, :departure, :notices, :pass_through_waypoints, :spans, :summary, :travel_steps) SENSITIVE = [] include Aws::Structure end |