Class: Aws::GeoRoutes::Types::RouteRentalAfterTravelStep

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

A step that must be performed after the travel portion of the leg.

Constant Summary collapse

SENSITIVE =
[:duration, :instruction, :type]

Instance Attribute Summary collapse

Instance Attribute Details

#durationInteger

Duration of the step.

Unit: ‘seconds`

Returns:

  • (Integer)


5352
5353
5354
5355
5356
5357
5358
# File 'lib/aws-sdk-georoutes/types.rb', line 5352

class RouteRentalAfterTravelStep < Struct.new(
  :duration,
  :instruction,
  :type)
  SENSITIVE = [:duration, :instruction, :type]
  include Aws::Structure
end

#instructionString

Brief description of the step in the requested language.

Returns:

  • (String)


5352
5353
5354
5355
5356
5357
5358
# File 'lib/aws-sdk-georoutes/types.rb', line 5352

class RouteRentalAfterTravelStep < Struct.new(
  :duration,
  :instruction,
  :type)
  SENSITIVE = [:duration, :instruction, :type]
  include Aws::Structure
end

#typeString

Type of the step.

Returns:

  • (String)


5352
5353
5354
5355
5356
5357
5358
# File 'lib/aws-sdk-georoutes/types.rb', line 5352

class RouteRentalAfterTravelStep < Struct.new(
  :duration,
  :instruction,
  :type)
  SENSITIVE = [:duration, :instruction, :type]
  include Aws::Structure
end