Class: Aws::GeoRoutes::Types::RouteRentalTravelOnlySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteRentalTravelOnlySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Summary including duration and distance for the travel portion of the leg only.
Constant Summary collapse
- SENSITIVE =
[:duration]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
Duration of the travel portion of the rental leg.
Instance Attribute Details
#duration ⇒ Integer
Duration of the travel portion of the rental leg.
Unit: ‘seconds`
5660 5661 5662 5663 5664 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5660 class RouteRentalTravelOnlySummary < Struct.new( :duration) SENSITIVE = [:duration] include Aws::Structure end |