Class: Aws::GeoRoutes::Types::RouteTaxiLegDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTaxiLegDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Populated when the Leg type is Taxi, and provides additional information that is specific to taxi travel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#after_travel_steps ⇒ Array<Types::RouteTaxiAfterTravelStep>
Steps of a leg that must be performed after the travel portion of the leg.
-
#agency ⇒ Types::RouteTaxiAgency
Details about the taxi agency.
-
#arrival ⇒ Types::RouteTaxiArrival
Details corresponding to the arrival for the leg.
-
#attributions ⇒ Array<Types::RouteAttribution>
List of required attributions to display.
-
#before_travel_steps ⇒ Array<Types::RouteTaxiBeforeTravelStep>
Steps of a leg that must be performed before the travel portion of the leg.
-
#booking_web_links ⇒ Array<Types::RouteWebLink>
Web links to external ticket booking services for the taxi.
-
#departure ⇒ Types::RouteTaxiDeparture
Details corresponding to the departure for the leg.
-
#notices ⇒ Array<Types::RouteTaxiNotice>
List of notices that indicate issues that occurred during route calculation.
-
#summary ⇒ Types::RouteTaxiSummary
Summary of the taxi leg.
-
#transport ⇒ Types::RouteTaxiTransportModeDetails
Transport mode details for the taxi leg.
-
#travel_steps ⇒ Array<Types::RouteTaxiTravelStep>
Steps of a leg that must be performed during the travel portion of the leg.
Instance Attribute Details
#after_travel_steps ⇒ Array<Types::RouteTaxiAfterTravelStep>
Steps of a leg that must be performed after the travel portion of the leg.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#agency ⇒ Types::RouteTaxiAgency
Details about the taxi agency.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#arrival ⇒ Types::RouteTaxiArrival
Details corresponding to the arrival for the leg.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#attributions ⇒ Array<Types::RouteAttribution>
List of required attributions to display.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#before_travel_steps ⇒ Array<Types::RouteTaxiBeforeTravelStep>
Steps of a leg that must be performed before the travel portion of the leg.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#booking_web_links ⇒ Array<Types::RouteWebLink>
Web links to external ticket booking services for the taxi.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#departure ⇒ Types::RouteTaxiDeparture
Details corresponding to the departure for the leg.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#notices ⇒ Array<Types::RouteTaxiNotice>
List of notices that indicate issues that occurred during route calculation.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#summary ⇒ Types::RouteTaxiSummary
Summary of the taxi leg.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#transport ⇒ Types::RouteTaxiTransportModeDetails
Transport mode details for the taxi leg.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |
#travel_steps ⇒ Array<Types::RouteTaxiTravelStep>
Steps of a leg that must be performed during the travel portion of the leg.
6272 6273 6274 6275 6276 6277 6278 6279 6280 6281 6282 6283 6284 6285 6286 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6272 class RouteTaxiLegDetails < Struct.new( :after_travel_steps, :agency, :arrival, :attributions, :before_travel_steps, :booking_web_links, :departure, :notices, :summary, :transport, :travel_steps) SENSITIVE = [] include Aws::Structure end |