Class: Aws::GeoRoutes::Types::RouteTaxiNotice
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTaxiNotice
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
A notice that indicates an issue that occurred during route calculation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
Code corresponding to the issue.
-
#impact ⇒ String
Impact corresponding to the issue.
Instance Attribute Details
#code ⇒ String
Code corresponding to the issue.
6303 6304 6305 6306 6307 6308 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6303 class RouteTaxiNotice < Struct.new( :code, :impact) SENSITIVE = [] include Aws::Structure end |
#impact ⇒ String
Impact corresponding to the issue. While Low impact notices can be safely ignored, High impact notices must be evaluated further to determine the impact.
6303 6304 6305 6306 6307 6308 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6303 class RouteTaxiNotice < Struct.new( :code, :impact) SENSITIVE = [] include Aws::Structure end |