Class: Aws::GeoRoutes::Types::RouteTransitIncident
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTransitIncident
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
An incident describes disruptions on the transit route.
Constant Summary collapse
- SENSITIVE =
[:description, :effect, :end_time, :start_time, :type, :url]
Instance Attribute Summary collapse
-
#description ⇒ String
A human readable description of the incident.
-
#effect ⇒ String
The effect of the incident on the transit service.
-
#end_time ⇒ String
The end time of the incident.
-
#start_time ⇒ String
The start time of the incident.
-
#type ⇒ String
Type of the incident.
-
#url ⇒ String
URL to the original incident published at the agency website.
Instance Attribute Details
#description ⇒ String
A human readable description of the incident.
7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7101 class RouteTransitIncident < Struct.new( :description, :effect, :end_time, :start_time, :type, :url) SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url] include Aws::Structure end |
#effect ⇒ String
The effect of the incident on the transit service.
7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7101 class RouteTransitIncident < Struct.new( :description, :effect, :end_time, :start_time, :type, :url) SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url] include Aws::Structure end |
#end_time ⇒ String
The end time of the incident.
7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7101 class RouteTransitIncident < Struct.new( :description, :effect, :end_time, :start_time, :type, :url) SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url] include Aws::Structure end |
#start_time ⇒ String
The start time of the incident.
7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7101 class RouteTransitIncident < Struct.new( :description, :effect, :end_time, :start_time, :type, :url) SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url] include Aws::Structure end |
#type ⇒ String
Type of the incident.
7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7101 class RouteTransitIncident < Struct.new( :description, :effect, :end_time, :start_time, :type, :url) SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url] include Aws::Structure end |
#url ⇒ String
URL to the original incident published at the agency website.
7101 7102 7103 7104 7105 7106 7107 7108 7109 7110 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7101 class RouteTransitIncident < Struct.new( :description, :effect, :end_time, :start_time, :type, :url) SENSITIVE = [:description, :effect, :end_time, :start_time, :type, :url] include Aws::Structure end |