Class: Aws::GeoRoutes::Types::RouteTransitIntermediateStop
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTransitIntermediateStop
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
An intermediate stop between departure and destination of the transit route.
Constant Summary collapse
- SENSITIVE =
[:attributes, :duration]
Instance Attribute Summary collapse
-
#attributes ⇒ Array<String>
Attributes of the intermediate stop.
-
#departure ⇒ Types::RouteTransitDeparture
Departure details for the intermediate stop.
-
#duration ⇒ Integer
Duration of the stop.
-
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this stop.
-
#transport ⇒ Types::RouteTransitTransportModeDetails
Transport mode details at the intermediate stop.
Instance Attribute Details
#attributes ⇒ Array<String>
Attributes of the intermediate stop.
7139 7140 7141 7142 7143 7144 7145 7146 7147 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7139 class RouteTransitIntermediateStop < Struct.new( :attributes, :departure, :duration, :geometry_offset, :transport) SENSITIVE = [:attributes, :duration] include Aws::Structure end |
#departure ⇒ Types::RouteTransitDeparture
Departure details for the intermediate stop.
7139 7140 7141 7142 7143 7144 7145 7146 7147 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7139 class RouteTransitIntermediateStop < Struct.new( :attributes, :departure, :duration, :geometry_offset, :transport) SENSITIVE = [:attributes, :duration] include Aws::Structure end |
#duration ⇒ Integer
Duration of the stop.
Unit: ‘seconds`
7139 7140 7141 7142 7143 7144 7145 7146 7147 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7139 class RouteTransitIntermediateStop < Struct.new( :attributes, :departure, :duration, :geometry_offset, :transport) SENSITIVE = [:attributes, :duration] include Aws::Structure end |
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this stop.
7139 7140 7141 7142 7143 7144 7145 7146 7147 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7139 class RouteTransitIntermediateStop < Struct.new( :attributes, :departure, :duration, :geometry_offset, :transport) SENSITIVE = [:attributes, :duration] include Aws::Structure end |
#transport ⇒ Types::RouteTransitTransportModeDetails
Transport mode details at the intermediate stop.
7139 7140 7141 7142 7143 7144 7145 7146 7147 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7139 class RouteTransitIntermediateStop < Struct.new( :attributes, :departure, :duration, :geometry_offset, :transport) SENSITIVE = [:attributes, :duration] include Aws::Structure end |