Class: Aws::GeoRoutes::Types::RouteTransitSpan
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTransitSpan
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Span computed for the requested SpanAdditionalFeatures.
Constant Summary collapse
- SENSITIVE =
[:country, :distance, :duration, :region]
Instance Attribute Summary collapse
-
#country ⇒ String
3 letter Country code corresponding to the Span.
-
#distance ⇒ Integer
Distance of the computed span.
-
#duration ⇒ Integer
Duration of the computed span.
-
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this span.
-
#names ⇒ Array<Types::LocalizedString>
Names of the transit span in available languages.
-
#region ⇒ String
2-3 letter Region code corresponding to the Span.
Instance Attribute Details
#country ⇒ String
3 letter Country code corresponding to the Span.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7473 class RouteTransitSpan < Struct.new( :country, :distance, :duration, :geometry_offset, :names, :region) SENSITIVE = [:country, :distance, :duration, :region] include Aws::Structure end |
#distance ⇒ Integer
Distance of the computed span. This feature doesn’t split a span, but is always computed on a span split by other properties.
Unit: ‘meters`
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7473 class RouteTransitSpan < Struct.new( :country, :distance, :duration, :geometry_offset, :names, :region) SENSITIVE = [:country, :distance, :duration, :region] include Aws::Structure end |
#duration ⇒ Integer
Duration of the computed span. This feature doesn’t split a span, but is always computed on a span split by other properties.
Unit: ‘seconds`
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7473 class RouteTransitSpan < Struct.new( :country, :distance, :duration, :geometry_offset, :names, :region) SENSITIVE = [:country, :distance, :duration, :region] include Aws::Structure end |
#geometry_offset ⇒ Integer
Offset in the leg geometry corresponding to the start of this span.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7473 class RouteTransitSpan < Struct.new( :country, :distance, :duration, :geometry_offset, :names, :region) SENSITIVE = [:country, :distance, :duration, :region] include Aws::Structure end |
#names ⇒ Array<Types::LocalizedString>
Names of the transit span in available languages.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7473 class RouteTransitSpan < Struct.new( :country, :distance, :duration, :geometry_offset, :names, :region) SENSITIVE = [:country, :distance, :duration, :region] include Aws::Structure end |
#region ⇒ String
2-3 letter Region code corresponding to the Span. This is either a province or a state.
7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7473 class RouteTransitSpan < Struct.new( :country, :distance, :duration, :geometry_offset, :names, :region) SENSITIVE = [:country, :distance, :duration, :region] include Aws::Structure end |