Class: Aws::GeoRoutes::Types::RouteTransitTravelOnlySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTransitTravelOnlySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Summary including duration and distance for the travel portion of the leg only.
Constant Summary collapse
- SENSITIVE =
[:duration]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
Duration of the travel portion of the transit leg.
Instance Attribute Details
#duration ⇒ Integer
Duration of the travel portion of the transit leg.
Unit: ‘seconds`
7565 7566 7567 7568 7569 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7565 class RouteTransitTravelOnlySummary < Struct.new( :duration) SENSITIVE = [:duration] include Aws::Structure end |