Class: Aws::GeoRoutes::Types::RouteTransitTravelStep

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

A step that must be performed during the travel portion of the leg.

Constant Summary collapse

SENSITIVE =
[:distance, :duration, :instruction, :type]

Instance Attribute Summary collapse

Instance Attribute Details

#distanceInteger

Distance of the step.

Unit: ‘meters`

Returns:

  • (Integer)


7599
7600
7601
7602
7603
7604
7605
7606
7607
# File 'lib/aws-sdk-georoutes/types.rb', line 7599

class RouteTransitTravelStep < Struct.new(
  :distance,
  :duration,
  :geometry_offset,
  :instruction,
  :type)
  SENSITIVE = [:distance, :duration, :instruction, :type]
  include Aws::Structure
end

#durationInteger

Duration of the step.

Unit: ‘seconds`

Returns:

  • (Integer)


7599
7600
7601
7602
7603
7604
7605
7606
7607
# File 'lib/aws-sdk-georoutes/types.rb', line 7599

class RouteTransitTravelStep < Struct.new(
  :distance,
  :duration,
  :geometry_offset,
  :instruction,
  :type)
  SENSITIVE = [:distance, :duration, :instruction, :type]
  include Aws::Structure
end

#geometry_offsetInteger

Offset in the leg geometry corresponding to the start of this step.

Returns:

  • (Integer)


7599
7600
7601
7602
7603
7604
7605
7606
7607
# File 'lib/aws-sdk-georoutes/types.rb', line 7599

class RouteTransitTravelStep < Struct.new(
  :distance,
  :duration,
  :geometry_offset,
  :instruction,
  :type)
  SENSITIVE = [:distance, :duration, :instruction, :type]
  include Aws::Structure
end

#instructionString

Brief description of the step in the requested language.

Returns:

  • (String)


7599
7600
7601
7602
7603
7604
7605
7606
7607
# File 'lib/aws-sdk-georoutes/types.rb', line 7599

class RouteTransitTravelStep < Struct.new(
  :distance,
  :duration,
  :geometry_offset,
  :instruction,
  :type)
  SENSITIVE = [:distance, :duration, :instruction, :type]
  include Aws::Structure
end

#typeString

Type of the step.

Returns:

  • (String)


7599
7600
7601
7602
7603
7604
7605
7606
7607
# File 'lib/aws-sdk-georoutes/types.rb', line 7599

class RouteTransitTravelStep < Struct.new(
  :distance,
  :duration,
  :geometry_offset,
  :instruction,
  :type)
  SENSITIVE = [:distance, :duration, :instruction, :type]
  include Aws::Structure
end