Class: Aws::GeoRoutes::Types::RouteTravelModeOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTravelModeOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Travel mode related options for the provided travel mode.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#car ⇒ Types::RouteCarOptions
Travel mode options when the provided travel mode is ‘Car`.
-
#intermodal ⇒ Types::RouteIntermodalOptions
Travel mode options when the provided travel mode is ‘Intermodal`.
-
#pedestrian ⇒ Types::RoutePedestrianOptions
Travel mode options when the provided travel mode is ‘Pedestrian`.
-
#scooter ⇒ Types::RouteScooterOptions
Travel mode options when the provided travel mode is ‘Scooter`.
-
#transit ⇒ Types::RouteTransitOptions
Travel mode options when the provided travel mode is ‘Transit`.
-
#truck ⇒ Types::RouteTruckOptions
Travel mode options when the provided travel mode is ‘Truck`.
Instance Attribute Details
#car ⇒ Types::RouteCarOptions
Travel mode options when the provided travel mode is ‘Car`.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7674 class RouteTravelModeOptions < Struct.new( :car, :pedestrian, :scooter, :truck, :intermodal, :transit) SENSITIVE = [] include Aws::Structure end |
#intermodal ⇒ Types::RouteIntermodalOptions
Travel mode options when the provided travel mode is ‘Intermodal`.
<note markdown=“1”> Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
</note>
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7674 class RouteTravelModeOptions < Struct.new( :car, :pedestrian, :scooter, :truck, :intermodal, :transit) SENSITIVE = [] include Aws::Structure end |
#pedestrian ⇒ Types::RoutePedestrianOptions
Travel mode options when the provided travel mode is ‘Pedestrian`.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7674 class RouteTravelModeOptions < Struct.new( :car, :pedestrian, :scooter, :truck, :intermodal, :transit) SENSITIVE = [] include Aws::Structure end |
#scooter ⇒ Types::RouteScooterOptions
Travel mode options when the provided travel mode is ‘Scooter`.
<note markdown=“1”> When travel mode is set to ‘Scooter`, then the avoidance option `ControlledAccessHighways` defaults to `true`.
</note>
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7674 class RouteTravelModeOptions < Struct.new( :car, :pedestrian, :scooter, :truck, :intermodal, :transit) SENSITIVE = [] include Aws::Structure end |
#transit ⇒ Types::RouteTransitOptions
Travel mode options when the provided travel mode is ‘Transit`.
<note markdown=“1”> Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
</note>
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7674 class RouteTravelModeOptions < Struct.new( :car, :pedestrian, :scooter, :truck, :intermodal, :transit) SENSITIVE = [] include Aws::Structure end |
#truck ⇒ Types::RouteTruckOptions
Travel mode options when the provided travel mode is ‘Truck`.
7674 7675 7676 7677 7678 7679 7680 7681 7682 7683 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7674 class RouteTravelModeOptions < Struct.new( :car, :pedestrian, :scooter, :truck, :intermodal, :transit) SENSITIVE = [] include Aws::Structure end |