Class: Aws::GeoRoutes::Types::RouteTravelModeOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-georoutes/types.rb

Overview

Travel mode related options for the provided travel mode.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#carTypes::RouteCarOptions

Travel mode options when the provided travel mode is ‘Car`.



5590
5591
5592
5593
5594
5595
5596
5597
# File 'lib/aws-sdk-georoutes/types.rb', line 5590

class RouteTravelModeOptions < Struct.new(
  :car,
  :pedestrian,
  :scooter,
  :truck)
  SENSITIVE = []
  include Aws::Structure
end

#pedestrianTypes::RoutePedestrianOptions

Travel mode options when the provided travel mode is ‘Pedestrian`.



5590
5591
5592
5593
5594
5595
5596
5597
# File 'lib/aws-sdk-georoutes/types.rb', line 5590

class RouteTravelModeOptions < Struct.new(
  :car,
  :pedestrian,
  :scooter,
  :truck)
  SENSITIVE = []
  include Aws::Structure
end

#scooterTypes::RouteScooterOptions

Travel mode options when the provided travel mode is ‘Scooter`.

<note markdown=“1”> When travel mode is set to ‘Scooter`, then the avoidance option `ControlledAccessHighways` defaults to `true`.

</note>


5590
5591
5592
5593
5594
5595
5596
5597
# File 'lib/aws-sdk-georoutes/types.rb', line 5590

class RouteTravelModeOptions < Struct.new(
  :car,
  :pedestrian,
  :scooter,
  :truck)
  SENSITIVE = []
  include Aws::Structure
end

#truckTypes::RouteTruckOptions

Travel mode options when the provided travel mode is ‘Truck`.



5590
5591
5592
5593
5594
5595
5596
5597
# File 'lib/aws-sdk-georoutes/types.rb', line 5590

class RouteTravelModeOptions < Struct.new(
  :car,
  :pedestrian,
  :scooter,
  :truck)
  SENSITIVE = []
  include Aws::Structure
end