Class: Aws::GeoRoutes::Types::RouteTravelModeOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTravelModeOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Travel mode related options for the provided travel mode.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#car ⇒ Types::RouteCarOptions
Travel mode options when the provided travel mode is ‘Car`.
-
#pedestrian ⇒ Types::RoutePedestrianOptions
Travel mode options when the provided travel mode is ‘Pedestrian`.
-
#scooter ⇒ Types::RouteScooterOptions
Travel mode options when the provided travel mode is ‘Scooter`.
-
#truck ⇒ Types::RouteTruckOptions
Travel mode options when the provided travel mode is ‘Truck`.
Instance Attribute Details
#car ⇒ Types::RouteCarOptions
Travel mode options when the provided travel mode is ‘Car`.
5590 5591 5592 5593 5594 5595 5596 5597 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5590 class RouteTravelModeOptions < Struct.new( :car, :pedestrian, :scooter, :truck) SENSITIVE = [] include Aws::Structure end |
#pedestrian ⇒ Types::RoutePedestrianOptions
Travel mode options when the provided travel mode is ‘Pedestrian`.
5590 5591 5592 5593 5594 5595 5596 5597 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5590 class RouteTravelModeOptions < Struct.new( :car, :pedestrian, :scooter, :truck) SENSITIVE = [] include Aws::Structure end |
#scooter ⇒ Types::RouteScooterOptions
Travel mode options when the provided travel mode is ‘Scooter`.
<note markdown=“1”> When travel mode is set to ‘Scooter`, then the avoidance option `ControlledAccessHighways` defaults to `true`.
</note>
5590 5591 5592 5593 5594 5595 5596 5597 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5590 class RouteTravelModeOptions < Struct.new( :car, :pedestrian, :scooter, :truck) SENSITIVE = [] include Aws::Structure end |
#truck ⇒ Types::RouteTruckOptions
Travel mode options when the provided travel mode is ‘Truck`.
5590 5591 5592 5593 5594 5595 5596 5597 |
# File 'lib/aws-sdk-georoutes/types.rb', line 5590 class RouteTravelModeOptions < Struct.new( :car, :pedestrian, :scooter, :truck) SENSITIVE = [] include Aws::Structure end |