Class: Aws::GeoRoutes::Types::RouteTruckOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteTruckOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Travel mode options when the provided travel mode is ‘Truck`. Not supported in `ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
Constant Summary collapse
- SENSITIVE =
[:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width]
Instance Attribute Summary collapse
-
#axle_count ⇒ Integer
Total number of axles of the vehicle.
-
#engine_type ⇒ String
Engine type of the vehicle.
-
#gross_weight ⇒ Integer
Gross weight of the vehicle including trailers, and goods at capacity.
-
#hazardous_cargos ⇒ Array<String>
List of Hazardous cargo contained in the vehicle.
-
#height ⇒ Integer
Height of the vehicle.
-
#height_above_first_axle ⇒ Integer
Height of the vehicle above its first axle.
-
#kpra_length ⇒ Integer
Kingpin to rear axle length of the vehicle.
-
#length ⇒ Integer
Length of the vehicle.
-
#license_plate ⇒ Types::RouteVehicleLicensePlate
The vehicle License Plate.
-
#max_speed ⇒ Float
Maximum speed.
-
#occupancy ⇒ Integer
The number of occupants in the vehicle.
-
#payload_capacity ⇒ Integer
Payload capacity of the vehicle and trailers attached.
-
#tire_count ⇒ Integer
Number of tires on the vehicle.
-
#trailer ⇒ Types::RouteTrailerOptions
Trailer options corresponding to the vehicle.
-
#truck_type ⇒ String
The type of truck: ‘LightTruck` for smaller delivery vehicles, ` StraightTruck` for rigid body trucks, or `Tractor` for tractor-trailer combinations.
-
#tunnel_restriction_code ⇒ String
The tunnel restriction code.
-
#weight_per_axle ⇒ Integer
Heaviest weight per axle irrespective of the axle type or the axle group.
-
#weight_per_axle_group ⇒ Types::WeightPerAxleGroup
Specifies the total weight for the specified axle group.
-
#width ⇒ Integer
Width of the vehicle.
Instance Attribute Details
#axle_count ⇒ Integer
Total number of axles of the vehicle.
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#engine_type ⇒ String
Engine type of the vehicle.
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#gross_weight ⇒ Integer
Gross weight of the vehicle including trailers, and goods at capacity.
Unit: ‘kilograms`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#hazardous_cargos ⇒ Array<String>
List of Hazardous cargo contained in the vehicle.
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#height ⇒ Integer
Height of the vehicle.
Unit: ‘centimeters`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#height_above_first_axle ⇒ Integer
Height of the vehicle above its first axle.
Unit: ‘centimeters`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#kpra_length ⇒ Integer
Kingpin to rear axle length of the vehicle.
Unit: ‘centimeters`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#length ⇒ Integer
Length of the vehicle.
Unit: ‘c`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#license_plate ⇒ Types::RouteVehicleLicensePlate
The vehicle License Plate.
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#max_speed ⇒ Float
Maximum speed
Unit: ‘kilometers per hour`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#occupancy ⇒ Integer
The number of occupants in the vehicle.
Default value: ‘1`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#payload_capacity ⇒ Integer
Payload capacity of the vehicle and trailers attached.
Unit: ‘kilograms`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#tire_count ⇒ Integer
Number of tires on the vehicle.
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#trailer ⇒ Types::RouteTrailerOptions
Trailer options corresponding to the vehicle.
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#truck_type ⇒ String
The type of truck: ‘LightTruck` for smaller delivery vehicles, ` StraightTruck` for rigid body trucks, or `Tractor` for tractor-trailer combinations.
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#tunnel_restriction_code ⇒ String
The tunnel restriction code.
Tunnel categories in this list indicate the restrictions which apply to certain tunnels in Great Britain. They relate to the types of dangerous goods that can be transported through them.
-
*Tunnel Category B*
-
*Risk Level*: Limited risk
-
Restrictions: Few restrictions
-
-
*Tunnel Category C*
-
*Risk Level*: Medium risk
-
Restrictions: Some restrictions
-
-
*Tunnel Category D*
-
*Risk Level*: High risk
-
Restrictions: Many restrictions occur
-
-
*Tunnel Category E*
-
*Risk Level*: Very high risk
-
Restrictions: Restricted tunnel
-
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#weight_per_axle ⇒ Integer
Heaviest weight per axle irrespective of the axle type or the axle group. Meant for usage in countries where the differences in axle types or axle groups are not distinguished.
Unit: ‘kilograms`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#weight_per_axle_group ⇒ Types::WeightPerAxleGroup
Specifies the total weight for the specified axle group. Meant for usage in countries that have different regulations based on the axle group type.
Unit: ‘kilograms`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |
#width ⇒ Integer
Width of the vehicle.
Unit: ‘centimeters`
7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 7846 7847 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7825 class RouteTruckOptions < Struct.new( :axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :license_plate, :max_speed, :occupancy, :payload_capacity, :tire_count, :trailer, :truck_type, :tunnel_restriction_code, :weight_per_axle, :weight_per_axle_group, :width) SENSITIVE = [:axle_count, :engine_type, :gross_weight, :hazardous_cargos, :height, :height_above_first_axle, :kpra_length, :length, :max_speed, :occupancy, :payload_capacity, :tire_count, :truck_type, :tunnel_restriction_code, :weight_per_axle, :width] include Aws::Structure end |