Class: Aws::GeoRoutes::Types::RouteVehicleAfterTravelStep
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteVehicleAfterTravelStep
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Steps of a leg that must be performed after the travel portion of the leg.
Constant Summary collapse
- SENSITIVE =
[:duration, :instruction, :type]
Instance Attribute Summary collapse
-
#charge_step_details ⇒ Types::RouteChargeStepDetails
Details that are specific to a Charge step.
-
#duration ⇒ Integer
Duration of the step.
-
#instruction ⇒ String
Brief description of the step in the requested language.
-
#type ⇒ String
Type of the step.
Instance Attribute Details
#charge_step_details ⇒ Types::RouteChargeStepDetails
Details that are specific to a Charge step.
Unit: ‘KwH `
7936 7937 7938 7939 7940 7941 7942 7943 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7936 class RouteVehicleAfterTravelStep < Struct.new( :charge_step_details, :duration, :instruction, :type) SENSITIVE = [:duration, :instruction, :type] include Aws::Structure end |
#duration ⇒ Integer
Duration of the step.
Unit: ‘seconds`
7936 7937 7938 7939 7940 7941 7942 7943 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7936 class RouteVehicleAfterTravelStep < Struct.new( :charge_step_details, :duration, :instruction, :type) SENSITIVE = [:duration, :instruction, :type] include Aws::Structure end |
#instruction ⇒ String
Brief description of the step in the requested language.
<note markdown=“1”> Only available when the TravelStepType is Default.
</note>
7936 7937 7938 7939 7940 7941 7942 7943 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7936 class RouteVehicleAfterTravelStep < Struct.new( :charge_step_details, :duration, :instruction, :type) SENSITIVE = [:duration, :instruction, :type] include Aws::Structure end |
#type ⇒ String
Type of the step.
7936 7937 7938 7939 7940 7941 7942 7943 |
# File 'lib/aws-sdk-georoutes/types.rb', line 7936 class RouteVehicleAfterTravelStep < Struct.new( :charge_step_details, :duration, :instruction, :type) SENSITIVE = [:duration, :instruction, :type] include Aws::Structure end |