Class: Aws::GeoRoutes::Types::RouteViolatedConstraints
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteViolatedConstraints
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
This property contains a summary of violated constraints.
Constant Summary collapse
- SENSITIVE =
[:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code]
Instance Attribute Summary collapse
-
#all_hazards_restricted ⇒ Boolean
This restriction applies to truck cargo, where the resulting route excludes roads on which hazardous materials are prohibited from being transported.
-
#axle_count ⇒ Types::RouteNoticeDetailRange
Total number of axles of the vehicle.
-
#hazardous_cargos ⇒ Array<String>
List of Hazardous cargo contained in the vehicle.
-
#max_height ⇒ Integer
The maximum height of the vehicle.
-
#max_kpra_length ⇒ Integer
The maximum Kpra length of the vehicle.
-
#max_length ⇒ Integer
The maximum length of the vehicle.
-
#max_payload_capacity ⇒ Integer
The maximum load capacity of the vehicle.
-
#max_weight ⇒ Types::RouteWeightConstraint
The maximum weight of the route.
-
#max_weight_per_axle ⇒ Integer
The maximum weight per axle of the vehicle.
-
#max_weight_per_axle_group ⇒ Types::WeightPerAxleGroup
The maximum weight per axle group of the vehicle.
-
#max_width ⇒ Integer
The maximum width of the vehicle.
-
#occupancy ⇒ Types::RouteNoticeDetailRange
The number of occupants in the vehicle.
-
#restricted_times ⇒ String
Access radius restrictions based on time.
-
#time_dependent ⇒ Boolean
The time dependent constraint.
-
#trailer_count ⇒ Types::RouteNoticeDetailRange
Number of trailers attached to the vehicle.
-
#travel_mode ⇒ Boolean
Travel mode corresponding to the leg.
-
#truck_road_type ⇒ String
Truck road type identifiers.
-
#truck_type ⇒ String
The type of truck: ‘LightTruck` for smaller delivery vehicles, ` StraightTruck` for rigid body trucks, or `Tractor` for tractor-trailer combinations.
-
#tunnel_restriction_code ⇒ String
The tunnel restriction code.
Instance Attribute Details
#all_hazards_restricted ⇒ Boolean
This restriction applies to truck cargo, where the resulting route excludes roads on which hazardous materials are prohibited from being transported.
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#axle_count ⇒ Types::RouteNoticeDetailRange
Total number of axles of the vehicle.
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#hazardous_cargos ⇒ Array<String>
List of Hazardous cargo contained in the vehicle.
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#max_height ⇒ Integer
The maximum height of the vehicle.
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#max_kpra_length ⇒ Integer
The maximum Kpra length of the vehicle.
Unit: ‘centimeters`
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#max_length ⇒ Integer
The maximum length of the vehicle.
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#max_payload_capacity ⇒ Integer
The maximum load capacity of the vehicle.
Unit: ‘kilograms`
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#max_weight ⇒ Types::RouteWeightConstraint
The maximum weight of the route.
Unit: ‘kilograms`
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#max_weight_per_axle ⇒ Integer
The maximum weight per axle of the vehicle.
Unit: ‘kilograms`
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#max_weight_per_axle_group ⇒ Types::WeightPerAxleGroup
The maximum weight per axle group of the vehicle.
Unit: ‘kilograms`
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#max_width ⇒ Integer
The maximum width of the vehicle.
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#occupancy ⇒ Types::RouteNoticeDetailRange
The number of occupants in the vehicle.
Default value: ‘1`
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#restricted_times ⇒ String
Access radius restrictions based on time.
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#time_dependent ⇒ Boolean
The time dependent constraint.
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#trailer_count ⇒ Types::RouteNoticeDetailRange
Number of trailers attached to the vehicle.
Default value: ‘0`
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#travel_mode ⇒ Boolean
Travel mode corresponding to the leg.
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#truck_road_type ⇒ String
Truck road type identifiers. ‘BK1` through `BK4` apply only to Sweden. `A2,A4,B2,B4,C,D,ET2,ET4` apply only to Mexico.
<note markdown=“1”> There are currently no other supported values as of 26th April 2024.
</note>
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#truck_type ⇒ String
The type of truck: ‘LightTruck` for smaller delivery vehicles, ` StraightTruck` for rigid body trucks, or `Tractor` for tractor-trailer combinations.
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |
#tunnel_restriction_code ⇒ String
The tunnel restriction code.
Tunnel categories in this list indicate the restrictions which apply to certain tunnels in Great Britain. They relate to the types of dangerous goods that can be transported through them.
-
*Tunnel Category B*
-
*Risk Level*: Limited risk
-
Restrictions: Few restrictions
-
-
*Tunnel Category C*
-
*Risk Level*: Medium risk
-
Restrictions: Some restrictions
-
-
*Tunnel Category D*
-
*Risk Level*: High risk
-
Restrictions: Many restrictions occur
-
-
*Tunnel Category E*
-
*Risk Level*: Very high risk
-
Restrictions: Restricted tunnel
-
6615 6616 6617 6618 6619 6620 6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 6632 6633 6634 6635 6636 6637 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6615 class RouteViolatedConstraints < Struct.new( :all_hazards_restricted, :axle_count, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight, :max_weight_per_axle, :max_weight_per_axle_group, :max_width, :occupancy, :restricted_times, :time_dependent, :trailer_count, :travel_mode, :truck_road_type, :truck_type, :tunnel_restriction_code) SENSITIVE = [:all_hazards_restricted, :hazardous_cargos, :max_height, :max_kpra_length, :max_length, :max_payload_capacity, :max_weight_per_axle, :max_width, :time_dependent, :travel_mode, :truck_type, :tunnel_restriction_code] include Aws::Structure end |