Class: Aws::GeoRoutes::Types::RouteWaypoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::RouteWaypoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Waypoint between the Origin and Destination.
Constant Summary collapse
- SENSITIVE =
[:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration]
Instance Attribute Summary collapse
-
#avoid_actions_for_distance ⇒ Integer
Avoids actions for the provided distance.
-
#avoid_u_turns ⇒ Boolean
Avoid U-turns for calculation on highways and motorways.
-
#heading ⇒ Float
GPS Heading at the position.
-
#matching ⇒ Types::RouteMatchingOptions
Options to configure matching the provided position to the road network.
-
#pass_through ⇒ Boolean
If the waypoint should not be treated as a stop.
-
#position ⇒ Array<Float>
Position in World Geodetic System (WGS 84) format: [longitude, latitude].
-
#side_of_street ⇒ Types::RouteSideOfStreetOptions
Options to configure matching the provided position to a side of the street.
-
#stop_duration ⇒ Integer
Duration of the stop.
Instance Attribute Details
#avoid_actions_for_distance ⇒ Integer
Avoids actions for the provided distance. This is typically to consider for users in moving vehicles who may not have sufficient time to make an action at an origin or a destination. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6721 class RouteWaypoint < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :pass_through, :position, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration] include Aws::Structure end |
#avoid_u_turns ⇒ Boolean
Avoid U-turns for calculation on highways and motorways. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for
- GrabMaps][1
-
customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6721 class RouteWaypoint < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :pass_through, :position, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration] include Aws::Structure end |
#heading ⇒ Float
GPS Heading at the position. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6721 class RouteWaypoint < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :pass_through, :position, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration] include Aws::Structure end |
#matching ⇒ Types::RouteMatchingOptions
Options to configure matching the provided position to the road network. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6721 class RouteWaypoint < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :pass_through, :position, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration] include Aws::Structure end |
#pass_through ⇒ Boolean
If the waypoint should not be treated as a stop. If yes, the waypoint is passed through and doesn’t split the route into different legs. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6721 class RouteWaypoint < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :pass_through, :position, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration] include Aws::Structure end |
#position ⇒ Array<Float>
Position in World Geodetic System (WGS 84) format: [longitude, latitude].
6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6721 class RouteWaypoint < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :pass_through, :position, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration] include Aws::Structure end |
#side_of_street ⇒ Types::RouteSideOfStreetOptions
Options to configure matching the provided position to a side of the street. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6721 class RouteWaypoint < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :pass_through, :position, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration] include Aws::Structure end |
#stop_duration ⇒ Integer
Duration of the stop. Not supported in ‘ap-southeast-1` and `ap-southeast-5` regions for [GrabMaps] customers.
Unit: ‘seconds`
[1]: docs.aws.amazon.com/location/latest/developerguide/GrabMaps.html
6721 6722 6723 6724 6725 6726 6727 6728 6729 6730 6731 6732 |
# File 'lib/aws-sdk-georoutes/types.rb', line 6721 class RouteWaypoint < Struct.new( :avoid_actions_for_distance, :avoid_u_turns, :heading, :matching, :pass_through, :position, :side_of_street, :stop_duration) SENSITIVE = [:avoid_actions_for_distance, :avoid_u_turns, :heading, :pass_through, :position, :stop_duration] include Aws::Structure end |