Class: Aws::GeoRoutes::Types::WaypointOptimizationDriverOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::WaypointOptimizationDriverOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
Driver related options.
Constant Summary collapse
- SENSITIVE =
[:treat_service_time_as]
Instance Attribute Summary collapse
-
#rest_cycles ⇒ Types::WaypointOptimizationRestCycles
Driver work-rest schedules defined by a short and long cycle.
-
#rest_profile ⇒ Types::WaypointOptimizationRestProfile
Pre defined rest profiles for a driver schedule.
-
#treat_service_time_as ⇒ String
If the service time provided at a waypoint/destination should be considered as rest or work.
Instance Attribute Details
#rest_cycles ⇒ Types::WaypointOptimizationRestCycles
Driver work-rest schedules defined by a short and long cycle. A rest needs to be taken after the short work duration. The short cycle can be repeated until you hit the long work duration, at which point the long rest duration should be taken before restarting.
9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9348 class WaypointOptimizationDriverOptions < Struct.new( :rest_cycles, :rest_profile, :treat_service_time_as) SENSITIVE = [:treat_service_time_as] include Aws::Structure end |
#rest_profile ⇒ Types::WaypointOptimizationRestProfile
Pre defined rest profiles for a driver schedule. The only currently supported profile is EU.
9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9348 class WaypointOptimizationDriverOptions < Struct.new( :rest_cycles, :rest_profile, :treat_service_time_as) SENSITIVE = [:treat_service_time_as] include Aws::Structure end |
#treat_service_time_as ⇒ String
If the service time provided at a waypoint/destination should be considered as rest or work. This contributes to the total time breakdown returned within the response.
9348 9349 9350 9351 9352 9353 9354 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9348 class WaypointOptimizationDriverOptions < Struct.new( :rest_cycles, :rest_profile, :treat_service_time_as) SENSITIVE = [:treat_service_time_as] include Aws::Structure end |