Class: Aws::GeoRoutes::Types::WaypointOptimizationOptimizedWaypoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::GeoRoutes::Types::WaypointOptimizationOptimizedWaypoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-georoutes/types.rb
Overview
The optimized waypoint.
Constant Summary collapse
- SENSITIVE =
[:arrival_time, :departure_time, :position]
Instance Attribute Summary collapse
-
#arrival_time ⇒ String
Estimated time of arrival at the destination.
-
#cluster_index ⇒ Integer
Index of the cluster the waypoint is associated with.
-
#departure_time ⇒ String
Estimated time of departure from the origin.
-
#id ⇒ String
The waypoint Id.
-
#position ⇒ Array<Float>
Position in World Geodetic System (WGS 84) format: [longitude, latitude].
Instance Attribute Details
#arrival_time ⇒ String
Estimated time of arrival at the destination.
Time format:‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`
Examples:
‘2020-04-22T17:57:24Z`
‘2020-04-22T17:57:24+02:00`
9477 9478 9479 9480 9481 9482 9483 9484 9485 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9477 class WaypointOptimizationOptimizedWaypoint < Struct.new( :arrival_time, :cluster_index, :departure_time, :id, :position) SENSITIVE = [:arrival_time, :departure_time, :position] include Aws::Structure end |
#cluster_index ⇒ Integer
Index of the cluster the waypoint is associated with. The index is included in the response only if clustering was performed while processing the request.
9477 9478 9479 9480 9481 9482 9483 9484 9485 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9477 class WaypointOptimizationOptimizedWaypoint < Struct.new( :arrival_time, :cluster_index, :departure_time, :id, :position) SENSITIVE = [:arrival_time, :departure_time, :position] include Aws::Structure end |
#departure_time ⇒ String
Estimated time of departure from the origin.
Time format:‘YYYY-MM-DDThh:mm:ss.sssZ | YYYY-MM-DDThh:mm:ss.sss+hh:mm`
Examples:
‘2020-04-22T17:57:24Z`
‘2020-04-22T17:57:24+02:00`
9477 9478 9479 9480 9481 9482 9483 9484 9485 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9477 class WaypointOptimizationOptimizedWaypoint < Struct.new( :arrival_time, :cluster_index, :departure_time, :id, :position) SENSITIVE = [:arrival_time, :departure_time, :position] include Aws::Structure end |
#id ⇒ String
The waypoint Id.
9477 9478 9479 9480 9481 9482 9483 9484 9485 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9477 class WaypointOptimizationOptimizedWaypoint < Struct.new( :arrival_time, :cluster_index, :departure_time, :id, :position) SENSITIVE = [:arrival_time, :departure_time, :position] include Aws::Structure end |
#position ⇒ Array<Float>
Position in World Geodetic System (WGS 84) format: [longitude, latitude].
9477 9478 9479 9480 9481 9482 9483 9484 9485 |
# File 'lib/aws-sdk-georoutes/types.rb', line 9477 class WaypointOptimizationOptimizedWaypoint < Struct.new( :arrival_time, :cluster_index, :departure_time, :id, :position) SENSITIVE = [:arrival_time, :departure_time, :position] include Aws::Structure end |